####Focal Points, Dissident Calendars, and Preemptive Repression - R Analysis File####
###Rory Truex, Assistant Professor, Princeton University Department of Politics and Woodrow Wilson School of Public and International Affairs, rtruex@princeton.edu###

setwd('/Users/rtruex/Dropbox/Repression/Focal Points, Dissident Calendars, and Preemptive Repression - JCR Replication Files')
rm(list=ls(all=TRUE))

####LOAD DATA AND PACKAGES####
#install.packages("arm")
#install.packages("foreign")
#install.packages("Zelig")
#install.packages("MASS")
#install.packages("stargazer")
#install.packages("pscl")
#install.packages("sandwich")
#install.packages("lubridate")
#install.packages("depmixS4")
#install.packages("maps")
#install.packages("mapdata")
#install.packages("maptools")
#install.packages("raster")
#install.packages("sp")
#install.packages("ggmap")
#install.packages("rworldmap")
#install.packages("maps")
#install.packages("Hmisc")
#install.packages("stringr")
#install.packages("waterfall")

library("arm")
library("foreign")
library(Zelig)
library(MASS)
library("stargazer")
library("pscl")
library("sandwich")
library("lubridate")
library("depmixS4")
library("maps")
library("mapdata")
library("maptools")
library("raster")
library("sp")
library("ggmap")
library("rworldmap")
library("maps")
library("Hmisc")
library("stringr")
library("waterfall")

data.month<-read.csv("monthly.data.v12-19-17.csv")
cecc<-read.csv("cecc.raw.csv")
chrd<-read.csv("CHRD.csv")

####DATA CLEANING####

cecc$year<- substr(cecc$date.of.detention, 1, 4)
cecc$month<- substr(cecc$date.of.detention, 6, 7)
cecc$month<- as.numeric(cecc$month)
cecc$day<- substr(cecc$date.of.detention, 9, 10)
cecc <- within(cecc, month.label<-paste(year, "m", month, sep=""))

cecc$issue.flg<-0
cecc$issue.flg[grepl("FG", cecc$issue.category)==TRUE]<-1
cecc$issue.flg<-as.numeric(cecc$issue.flg)
sum(cecc$issue.flg)

cecc$issue.ethtib<-0
cecc$issue.ethtib[grepl("Tibetan", cecc$ethnic.group)==TRUE]<-1
cecc$issue.ethtib<-as.numeric(cecc$issue.ethtib)
sum(cecc$issue.ethtib)

cecc$issue.ethuyg<-0
cecc$issue.ethuyg[grepl("Uyghur", cecc$ethnic.group)==TRUE]<-1
cecc$issue.ethuyg<-as.numeric(cecc$issue.ethuyg)
sum(cecc$issue.ethuyg)

cecc$issue.dem<-0
cecc$issue.dem[grepl("dem", cecc$issue.category)==TRUE]<-1
cecc$issue.dem<-as.numeric(cecc$issue.dem)
sum(cecc$issue.dem)

cecc$issue.dem.ext1<-0
cecc$issue.dem.ext1[grepl("dem", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext1[grepl("6489", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext1<-as.numeric(cecc$issue.dem.ext1)
sum(cecc$issue.dem.ext1)

cecc$issue.dem.ext2<-0
cecc$issue.dem.ext2[grepl("dem", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("6489", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("spch", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("civil", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("info", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("assoc", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("Uyghur", cecc$ethnic.group)==TRUE]<-0
cecc$issue.dem.ext2[grepl("Tibetan", cecc$ethnic.group)==TRUE]<-0
cecc$issue.dem.ext2[grepl("FG", cecc$issue.category)==TRUE]<-0
cecc$issue.dem.ext2<-as.numeric(cecc$issue.dem.ext2)
sum(cecc$issue.dem.ext2)

cecc.inc<-subset(cecc, cecc$month!="mm" & cecc$year>1997 & cecc$year<2015)

issue.dem<-subset(cecc.inc, cecc.inc$issue.dem==1)
issue.dem<-data.frame(ftable(issue.dem$month.label))
colnames(issue.dem)<-c("month.label","issue.issue.dem.ext1.det")
data<-merge(data.month,issue.dem,by.x="month.label",all=TRUE)

issue.dem.ext1<-subset(cecc.inc, cecc.inc$issue.dem.ext1==1)
issue.dem.ext1<-data.frame(ftable(issue.dem.ext1$month.label))
colnames(issue.dem.ext1)<-c("month.label","issue.dem.ext1.det")
data<-merge(data,issue.dem.ext1,by.x="month.label",all=TRUE)

issue.dem.ext2<-subset(cecc.inc, cecc.inc$issue.dem.ext2==1)
issue.dem.ext2<-data.frame(ftable(issue.dem.ext2$month.label))
colnames(issue.dem.ext2)<-c("month.label","issue.dem.ext2.det")
data<-merge(data,issue.dem.ext2,by.x="month.label",all=TRUE)

issue.flg<-subset(cecc.inc, cecc.inc$issue.flg==1)
issue.flg<-data.frame(ftable(issue.flg$month.label))
colnames(issue.flg)<-c("month.label","issue.flg.det")
data<-merge(data,issue.flg,by.x="month.label",all=TRUE)

issue.ethtib<-subset(cecc.inc, cecc.inc$issue.ethtib==1)
issue.ethtib<-data.frame(ftable(issue.ethtib$month.label))
colnames(issue.ethtib)<-c("month.label","issue.ethtib.det")
data<-merge(data,issue.ethtib,by.x="month.label",all=TRUE)

issue.ethuyg<-subset(cecc.inc, cecc.inc$issue.ethuyg==1)
issue.ethuyg<-data.frame(ftable(issue.ethuyg$month.label))
colnames(issue.ethuyg)<-c("month.label","issue.ethuyg.det")
data<-merge(data,issue.ethuyg,by.x="month.label",all=TRUE)

data$issue.issue.dem.ext1.det[is.na(data$issue.issue.dem.ext1.det)] <- 0
data$issue.dem.ext1.det[is.na(data$issue.dem.ext1.det)] <- 0
data$issue.dem.ext2.det[is.na(data$issue.dem.ext2.det)] <- 0
data$issue.flg.det[is.na(data$issue.flg.det)] <- 0
data$issue.ethtib.det[is.na(data$issue.ethtib.det)] <- 0
data$issue.ethuyg.det[is.na(data$issue.ethuyg.det)] <- 0

data <- data[order(data$t),] 
data$t2 <-data$t^2
data$t3 <-data$t^3

####ANALYSIS - DEMOCRACY DETENTIONS####

#Figure A1: Autocorrelation Function#
pdf('fig1-timeseries-dem.pdf', width=10, height=4.5)
years<-c("1998","1999","2000","2001","2002","2003","2004","2005","2006","2007","2008","2009","2010","2011","2012","2013","2014")
t<-c(1,13,25,37,49,61,73,85,97,109,121,133,145,157,169,181,193)
par(mfcol=c(1,2))
par(cex.axis=1.15)
par(cex.lab=1.15)
par(cex.main=1.15)
plot(data$t,data$issue.dem.ext1.det,type="l",xaxt="n", lty=1, lwd=0, main="Dissident Detentions", ylim=c(-.5,30),ylab="Count", xlab="")
axis(1, at=t, labels=years, las=2, cex=.6)
lines(data$t,data$issue.dem.ext1.det, lwd=1.5)
par(cex.axis=1.15)
par(cex.lab=1.15)
par(cex.main=1.15)
acf(data$issue.dem.ext1.det, lag.max=20, plot=TRUE, main="Autocorrelation Function",lwd=1.5)
dev.off()

#Table 1: Interrupted Time Series Estimates#
c1<-glm.nb(issue.dem.ext1.det~focal.gen.win3, data=data)
c2<-glm.nb(issue.dem.ext1.det~focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win12, data=data)
c3<-glm.nb(issue.dem.ext1.det~focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + t + t2 + t3, data=data)
c4<-glm.nb(issue.dem.ext2.det~focal.gen.win3, data=data)
c5<-glm.nb(issue.dem.ext2.det~focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win12, data=data)
c6<-glm.nb(issue.dem.ext2.det~focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + t + t2 + t3, data=data)

summary(c1)
summary(c2)
summary(c3)
summary(c4)
summary(c5)
summary(c6)

c1.est<-cbind(Estimate = coef(c1), confint(c1))
exp(c1.est)

c2.est<-cbind(Estimate = coef(c2), confint(c2))
exp(c2.est)

c3.est<-cbind(Estimate = coef(c3), confint(c3))
exp(c3.est)

c4.est<-cbind(Estimate = coef(c4), confint(c4))
exp(c4.est)

c5.est<-cbind(Estimate = coef(c5), confint(c5))
exp(c5.est)

c6.est<-cbind(Estimate = coef(c6), confint(c6))
exp(c6.est)

#Table A1: Interrupted Time Series Estimates (focal event month excluded)#

c1a<-glm.nb(issue.dem.ext1.det~focal.gen.win3.alt, data=data)
c2a<-glm.nb(issue.dem.ext1.det~focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12, data=data)
c3a<-glm.nb(issue.dem.ext1.det~focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + t + t2 + t3, data=data)
c4a<-glm.nb(issue.dem.ext2.det~focal.gen.win3.alt, data=data)
c5a<-glm.nb(issue.dem.ext2.det~focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12, data=data)
c6a<-glm.nb(issue.dem.ext2.det~focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + t + t2 + t3, data=data)

summary(c1a)
summary(c2a)
summary(c3a)
summary(c4a)
summary(c5a)
summary(c6a)

c1.est<-cbind(Estimate = coef(c1), confint(c1))
exp(c1.est)

c2.est<-cbind(Estimate = coef(c2), confint(c2))
exp(c2.est)

c3.est<-cbind(Estimate = coef(c3), confint(c3))
exp(c3.est)

c4.est<-cbind(Estimate = coef(c4), confint(c4))
exp(c4.est)

c5.est<-cbind(Estimate = coef(c5), confint(c5))
exp(c5.est)

c6.est<-cbind(Estimate = coef(c6), confint(c6))
exp(c6.est)

#Figure 2: Results of Sensitivity Analysis# 
tlr.models <- read.csv("tlr.models.csv")

m1 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  +  +  + 1,data=data)
m2 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  +  + transition.win15 + 1, data=data)
m3 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  +  + transition.win9 + 1, data=data)
m4 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  +  + transition.win12 + 1, data=data)
m5 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win4 +  + 1, data=data)
m6 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win4 + transition.win15 + 1, data=data)
m7 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win4 + transition.win9 + 1, data=data)
m8 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win4 + transition.win12 + 1, data=data)
m9 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win2 +  + 1, data=data)
m10 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win2 + transition.win15 + 1, data=data)
m11 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win2 + transition.win9 + 1, data=data)
m12 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win2 + transition.win12 + 1, data=data)
m13 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win3 +  + 1, data=data)
m14 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win3 + transition.win15 + 1, data=data)
m15 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win3 + transition.win9 + 1, data=data)
m16 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  +  + extmob.win3 + transition.win12 + 1, data=data)
m17 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 +  +  + 1, data=data)
m18 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 +  + transition.win15 + 1, data=data)
m19 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 +  + transition.win9 + 1, data=data)
m20 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 +  + transition.win12 + 1, data=data)
m21 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win4 +  + 1, data=data)
m22 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m23 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m24 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m25 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win2 +  + 1, data=data)
m26 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m27 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m28 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m29 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win3 +  + 1, data=data)
m30 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m31 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m32 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m33 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 +  +  + 1, data=data)
m34 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 +  + transition.win15 + 1, data=data)
m35 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 +  + transition.win9 + 1, data=data)
m36 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 +  + transition.win12 + 1, data=data)
m37 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win4 +  + 1, data=data)
m38 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m39 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m40 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m41 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win2 +  + 1, data=data)
m42 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m43 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m44 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m45 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win3 +  + 1, data=data)
m46 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m47 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m48 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m49 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 +  +  + 1, data=data)
m50 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 +  + transition.win15 + 1, data=data)
m51 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 +  + transition.win9 + 1, data=data)
m52 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 +  + transition.win12 + 1, data=data)
m53 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win4 +  + 1, data=data)
m54 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m55 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m56 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m57 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win2 +  + 1, data=data)
m58 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m59 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m60 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m61 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win3 +  + 1, data=data)
m62 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m63 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m64 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m65 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  +  +  + 1, data=data)
m66 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  +  + transition.win15 + 1, data=data)
m67 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  +  + transition.win9 + 1, data=data)
m68 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  +  + transition.win12 + 1, data=data)
m69 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win4 +  + 1, data=data)
m70 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win15 + 1, data=data)
m71 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win9 + 1, data=data)
m72 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win12 + 1, data=data)
m73 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win2 +  + 1, data=data)
m74 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win15 + 1, data=data)
m75 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win9 + 1, data=data)
m76 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win12 + 1, data=data)
m77 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win3 +  + 1, data=data)
m78 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win15 + 1, data=data)
m79 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win9 + 1, data=data)
m80 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win12 + 1, data=data)
m81 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 +  +  + 1, data=data)
m82 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win15 + 1, data=data)
m83 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win9 + 1, data=data)
m84 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win12 + 1, data=data)
m85 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 +  + 1, data=data)
m86 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m87 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m88 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m89 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 +  + 1, data=data)
m90 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m91 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m92 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m93 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 +  + 1, data=data)
m94 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m95 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m96 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m97 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 +  +  + 1, data=data)
m98 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win15 + 1, data=data)
m99 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win9 + 1, data=data)
m100 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win12 + 1, data=data)
m101 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 +  + 1, data=data)
m102 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m103 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m104 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m105 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 +  + 1, data=data)
m106 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m107 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m108 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m109 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 +  + 1, data=data)
m110 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m111 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m112 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m113 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 +  +  + 1, data=data)
m114 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win15 + 1, data=data)
m115 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win9 + 1, data=data)
m116 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win12 + 1, data=data)
m117 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 +  + 1, data=data)
m118 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m119 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m120 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m121 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 +  + 1, data=data)
m122 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m123 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m124 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m125 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 +  + 1, data=data)
m126 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m127 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m128 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m129 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  +  +  + 1, data=data)
m130 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  +  + transition.win15 + 1, data=data)
m131 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  +  + transition.win9 + 1, data=data)
m132 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  +  + transition.win12 + 1, data=data)
m133 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win4 +  + 1, data=data)
m134 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win15 + 1, data=data)
m135 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win9 + 1, data=data)
m136 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win12 + 1, data=data)
m137 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win2 +  + 1, data=data)
m138 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win15 + 1, data=data)
m139 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win9 + 1, data=data)
m140 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win12 + 1, data=data)
m141 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win3 +  + 1, data=data)
m142 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win15 + 1, data=data)
m143 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win9 + 1, data=data)
m144 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win12 + 1, data=data)
m145 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 +  +  + 1, data=data)
m146 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win15 + 1, data=data)
m147 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win9 + 1, data=data)
m148 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win12 + 1, data=data)
m149 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 +  + 1, data=data)
m150 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m151 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m152 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m153 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 +  + 1, data=data)
m154 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m155 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m156 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m157 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 +  + 1, data=data)
m158 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m159 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m160 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m161 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 +  +  + 1, data=data)
m162 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win15 + 1, data=data)
m163 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win9 + 1, data=data)
m164 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win12 + 1, data=data)
m165 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 +  + 1, data=data)
m166 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m167 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m168 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m169 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 +  + 1, data=data)
m170 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m171 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m172 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m173 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 +  + 1, data=data)
m174 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m175 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m176 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m177 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 +  +  + 1, data=data)
m178 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win15 + 1, data=data)
m179 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win9 + 1, data=data)
m180 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win12 + 1, data=data)
m181 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 +  + 1, data=data)
m182 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m183 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m184 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m185 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 +  + 1, data=data)
m186 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m187 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m188 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m189 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 +  + 1, data=data)
m190 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m191 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m192 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m193 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  +  +  + 1, data=data)
m194 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  +  + transition.win15 + 1, data=data)
m195 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  +  + transition.win9 + 1, data=data)
m196 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  +  + transition.win12 + 1, data=data)
m197 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win4 +  + 1, data=data)
m198 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win15 + 1, data=data)
m199 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win9 + 1, data=data)
m200 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win12 + 1, data=data)
m201 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win2 +  + 1, data=data)
m202 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win15 + 1, data=data)
m203 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win9 + 1, data=data)
m204 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win12 + 1, data=data)
m205 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win3 +  + 1, data=data)
m206 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win15 + 1, data=data)
m207 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win9 + 1, data=data)
m208 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win12 + 1, data=data)
m209 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 +  +  + 1, data=data)
m210 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win15 + 1, data=data)
m211 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win9 + 1, data=data)
m212 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win12 + 1, data=data)
m213 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 +  + 1, data=data)
m214 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m215 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m216 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m217 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 +  + 1, data=data)
m218 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m219 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m220 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m221 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 +  + 1, data=data)
m222 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m223 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m224 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m225 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 +  +  + 1, data=data)
m226 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win15 + 1, data=data)
m227 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win9 + 1, data=data)
m228 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win12 + 1, data=data)
m229 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 +  + 1, data=data)
m230 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m231 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m232 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m233 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 +  + 1, data=data)
m234 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m235 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m236 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m237 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 +  + 1, data=data)
m238 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m239 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m240 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m241 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 +  +  + 1, data=data)
m242 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win15 + 1, data=data)
m243 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win9 + 1, data=data)
m244 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win12 + 1, data=data)
m245 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 +  + 1, data=data)
m246 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m247 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m248 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m249 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 +  + 1, data=data)
m250 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m251 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m252 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m253 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 +  + 1, data=data)
m254 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m255 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m256 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m257 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  +  +  + 1, data=data)
m258 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  +  + transition.win15 + 1, data=data)
m259 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  +  + transition.win9 + 1, data=data)
m260 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  +  + transition.win12 + 1, data=data)
m261 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win4 +  + 1, data=data)
m262 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win4 + transition.win15 + 1, data=data)
m263 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win4 + transition.win9 + 1, data=data)
m264 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win4 + transition.win12 + 1, data=data)
m265 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win2 +  + 1, data=data)
m266 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win2 + transition.win15 + 1, data=data)
m267 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win2 + transition.win9 + 1, data=data)
m268 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win2 + transition.win12 + 1, data=data)
m269 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win3 +  + 1, data=data)
m270 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win3 + transition.win15 + 1, data=data)
m271 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win3 + transition.win9 + 1, data=data)
m272 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  +  + extmob.win3 + transition.win12 + 1, data=data)
m273 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 +  +  + 1, data=data)
m274 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 +  + transition.win15 + 1, data=data)
m275 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 +  + transition.win9 + 1, data=data)
m276 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 +  + transition.win12 + 1, data=data)
m277 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win4 +  + 1, data=data)
m278 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m279 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m280 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m281 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win2 +  + 1, data=data)
m282 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m283 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m284 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m285 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win3 +  + 1, data=data)
m286 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m287 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m288 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m289 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 +  +  + 1, data=data)
m290 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 +  + transition.win15 + 1, data=data)
m291 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 +  + transition.win9 + 1, data=data)
m292 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 +  + transition.win12 + 1, data=data)
m293 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win4 +  + 1, data=data)
m294 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m295 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m296 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m297 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win2 +  + 1, data=data)
m298 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m299 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m300 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m301 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win3 +  + 1, data=data)
m302 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m303 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m304 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m305 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 +  +  + 1, data=data)
m306 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 +  + transition.win15 + 1, data=data)
m307 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 +  + transition.win9 + 1, data=data)
m308 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 +  + transition.win12 + 1, data=data)
m309 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win4 +  + 1, data=data)
m310 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m311 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m312 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m313 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win2 +  + 1, data=data)
m314 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m315 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m316 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m317 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win3 +  + 1, data=data)
m318 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m319 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m320 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m321 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  +  +  + 1, data=data)
m322 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  +  + transition.win15 + 1, data=data)
m323 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  +  + transition.win9 + 1, data=data)
m324 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  +  + transition.win12 + 1, data=data)
m325 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win4 +  + 1, data=data)
m326 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win15 + 1, data=data)
m327 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win9 + 1, data=data)
m328 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win12 + 1, data=data)
m329 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win2 +  + 1, data=data)
m330 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win15 + 1, data=data)
m331 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win9 + 1, data=data)
m332 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win12 + 1, data=data)
m333 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win3 +  + 1, data=data)
m334 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win15 + 1, data=data)
m335 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win9 + 1, data=data)
m336 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win12 + 1, data=data)
m337 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 +  +  + 1, data=data)
m338 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win15 + 1, data=data)
m339 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win9 + 1, data=data)
m340 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win12 + 1, data=data)
m341 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 +  + 1, data=data)
m342 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m343 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m344 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m345 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 +  + 1, data=data)
m346 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m347 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m348 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m349 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 +  + 1, data=data)
m350 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m351 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m352 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m353 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 +  +  + 1, data=data)
m354 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win15 + 1, data=data)
m355 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win9 + 1, data=data)
m356 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win12 + 1, data=data)
m357 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 +  + 1, data=data)
m358 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m359 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m360 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m361 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 +  + 1, data=data)
m362 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m363 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m364 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m365 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 +  + 1, data=data)
m366 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m367 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m368 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m369 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 +  +  + 1, data=data)
m370 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win15 + 1, data=data)
m371 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win9 + 1, data=data)
m372 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win12 + 1, data=data)
m373 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 +  + 1, data=data)
m374 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m375 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m376 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m377 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 +  + 1, data=data)
m378 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m379 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m380 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m381 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 +  + 1, data=data)
m382 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m383 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m384 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m385 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  +  +  + 1, data=data)
m386 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  +  + transition.win15 + 1, data=data)
m387 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  +  + transition.win9 + 1, data=data)
m388 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  +  + transition.win12 + 1, data=data)
m389 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win4 +  + 1, data=data)
m390 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win15 + 1, data=data)
m391 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win9 + 1, data=data)
m392 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win12 + 1, data=data)
m393 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win2 +  + 1, data=data)
m394 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win15 + 1, data=data)
m395 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win9 + 1, data=data)
m396 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win12 + 1, data=data)
m397 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win3 +  + 1, data=data)
m398 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win15 + 1, data=data)
m399 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win9 + 1, data=data)
m400 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win12 + 1, data=data)
m401 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 +  +  + 1, data=data)
m402 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win15 + 1, data=data)
m403 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win9 + 1, data=data)
m404 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win12 + 1, data=data)
m405 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 +  + 1, data=data)
m406 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m407 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m408 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m409 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 +  + 1, data=data)
m410 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m411 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m412 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m413 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 +  + 1, data=data)
m414 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m415 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m416 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m417 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 +  +  + 1, data=data)
m418 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win15 + 1, data=data)
m419 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win9 + 1, data=data)
m420 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win12 + 1, data=data)
m421 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 +  + 1, data=data)
m422 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m423 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m424 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m425 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 +  + 1, data=data)
m426 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m427 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m428 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m429 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 +  + 1, data=data)
m430 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m431 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m432 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m433 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 +  +  + 1, data=data)
m434 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win15 + 1, data=data)
m435 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win9 + 1, data=data)
m436 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win12 + 1, data=data)
m437 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 +  + 1, data=data)
m438 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m439 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m440 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m441 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 +  + 1, data=data)
m442 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m443 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m444 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m445 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 +  + 1, data=data)
m446 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m447 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m448 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m449 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  +  +  + 1, data=data)
m450 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  +  + transition.win15 + 1, data=data)
m451 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  +  + transition.win9 + 1, data=data)
m452 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  +  + transition.win12 + 1, data=data)
m453 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win4 +  + 1, data=data)
m454 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win15 + 1, data=data)
m455 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win9 + 1, data=data)
m456 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win12 + 1, data=data)
m457 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win2 +  + 1, data=data)
m458 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win15 + 1, data=data)
m459 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win9 + 1, data=data)
m460 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win12 + 1, data=data)
m461 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win3 +  + 1, data=data)
m462 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win15 + 1, data=data)
m463 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win9 + 1, data=data)
m464 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win12 + 1, data=data)
m465 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 +  +  + 1, data=data)
m466 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win15 + 1, data=data)
m467 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win9 + 1, data=data)
m468 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win12 + 1, data=data)
m469 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 +  + 1, data=data)
m470 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m471 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m472 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m473 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 +  + 1, data=data)
m474 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m475 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m476 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m477 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 +  + 1, data=data)
m478 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m479 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m480 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m481 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 +  +  + 1, data=data)
m482 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win15 + 1, data=data)
m483 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win9 + 1, data=data)
m484 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win12 + 1, data=data)
m485 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 +  + 1, data=data)
m486 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m487 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m488 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m489 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 +  + 1, data=data)
m490 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m491 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m492 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m493 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 +  + 1, data=data)
m494 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m495 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m496 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m497 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 +  +  + 1, data=data)
m498 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win15 + 1, data=data)
m499 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win9 + 1, data=data)
m500 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win12 + 1, data=data)
m501 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 +  + 1, data=data)
m502 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m503 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m504 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m505 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 +  + 1, data=data)
m506 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m507 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m508 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m509 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 +  + 1, data=data)
m510 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m511 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m512 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m513 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  +  +  + 1, data=data)
m514 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  +  + transition.win15 + 1, data=data)
m515 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  +  + transition.win9 + 1, data=data)
m516 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  +  + transition.win12 + 1, data=data)
m517 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win4 +  + 1, data=data)
m518 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win4 + transition.win15 + 1, data=data)
m519 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win4 + transition.win9 + 1, data=data)
m520 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win4 + transition.win12 + 1, data=data)
m521 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win2 +  + 1, data=data)
m522 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win2 + transition.win15 + 1, data=data)
m523 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win2 + transition.win9 + 1, data=data)
m524 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win2 + transition.win12 + 1, data=data)
m525 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win3 +  + 1, data=data)
m526 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win3 + transition.win15 + 1, data=data)
m527 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win3 + transition.win9 + 1, data=data)
m528 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  +  + extmob.win3 + transition.win12 + 1, data=data)
m529 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 +  +  + 1, data=data)
m530 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 +  + transition.win15 + 1, data=data)
m531 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 +  + transition.win9 + 1, data=data)
m532 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 +  + transition.win12 + 1, data=data)
m533 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win4 +  + 1, data=data)
m534 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m535 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m536 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m537 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win2 +  + 1, data=data)
m538 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m539 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m540 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m541 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win3 +  + 1, data=data)
m542 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m543 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m544 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m545 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 +  +  + 1, data=data)
m546 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 +  + transition.win15 + 1, data=data)
m547 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 +  + transition.win9 + 1, data=data)
m548 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 +  + transition.win12 + 1, data=data)
m549 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win4 +  + 1, data=data)
m550 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m551 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m552 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m553 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win2 +  + 1, data=data)
m554 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m555 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m556 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m557 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win3 +  + 1, data=data)
m558 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m559 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m560 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m561 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 +  +  + 1, data=data)
m562 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 +  + transition.win15 + 1, data=data)
m563 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 +  + transition.win9 + 1, data=data)
m564 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 +  + transition.win12 + 1, data=data)
m565 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win4 +  + 1, data=data)
m566 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m567 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m568 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m569 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win2 +  + 1, data=data)
m570 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m571 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m572 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m573 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win3 +  + 1, data=data)
m574 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m575 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m576 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m577 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  +  +  + 1, data=data)
m578 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  +  + transition.win15 + 1, data=data)
m579 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  +  + transition.win9 + 1, data=data)
m580 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  +  + transition.win12 + 1, data=data)
m581 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win4 +  + 1, data=data)
m582 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win15 + 1, data=data)
m583 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win9 + 1, data=data)
m584 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win12 + 1, data=data)
m585 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win2 +  + 1, data=data)
m586 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win15 + 1, data=data)
m587 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win9 + 1, data=data)
m588 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win12 + 1, data=data)
m589 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win3 +  + 1, data=data)
m590 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win15 + 1, data=data)
m591 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win9 + 1, data=data)
m592 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win12 + 1, data=data)
m593 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 +  +  + 1, data=data)
m594 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win15 + 1, data=data)
m595 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win9 + 1, data=data)
m596 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win12 + 1, data=data)
m597 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 +  + 1, data=data)
m598 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m599 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m600 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m601 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 +  + 1, data=data)
m602 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m603 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m604 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m605 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 +  + 1, data=data)
m606 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m607 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m608 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m609 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 +  +  + 1, data=data)
m610 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win15 + 1, data=data)
m611 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win9 + 1, data=data)
m612 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win12 + 1, data=data)
m613 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 +  + 1, data=data)
m614 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m615 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m616 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m617 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 +  + 1, data=data)
m618 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m619 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m620 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m621 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 +  + 1, data=data)
m622 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m623 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m624 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m625 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 +  +  + 1, data=data)
m626 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win15 + 1, data=data)
m627 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win9 + 1, data=data)
m628 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win12 + 1, data=data)
m629 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 +  + 1, data=data)
m630 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m631 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m632 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m633 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 +  + 1, data=data)
m634 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m635 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m636 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m637 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 +  + 1, data=data)
m638 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m639 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m640 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m641 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  +  +  + 1, data=data)
m642 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  +  + transition.win15 + 1, data=data)
m643 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  +  + transition.win9 + 1, data=data)
m644 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  +  + transition.win12 + 1, data=data)
m645 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win4 +  + 1, data=data)
m646 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win15 + 1, data=data)
m647 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win9 + 1, data=data)
m648 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win12 + 1, data=data)
m649 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win2 +  + 1, data=data)
m650 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win15 + 1, data=data)
m651 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win9 + 1, data=data)
m652 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win12 + 1, data=data)
m653 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win3 +  + 1, data=data)
m654 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win15 + 1, data=data)
m655 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win9 + 1, data=data)
m656 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win12 + 1, data=data)
m657 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 +  +  + 1, data=data)
m658 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win15 + 1, data=data)
m659 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win9 + 1, data=data)
m660 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win12 + 1, data=data)
m661 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 +  + 1, data=data)
m662 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m663 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m664 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m665 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 +  + 1, data=data)
m666 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m667 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m668 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m669 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 +  + 1, data=data)
m670 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m671 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m672 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m673 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 +  +  + 1, data=data)
m674 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win15 + 1, data=data)
m675 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win9 + 1, data=data)
m676 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win12 + 1, data=data)
m677 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 +  + 1, data=data)
m678 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m679 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m680 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m681 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 +  + 1, data=data)
m682 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m683 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m684 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m685 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 +  + 1, data=data)
m686 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m687 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m688 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m689 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 +  +  + 1, data=data)
m690 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win15 + 1, data=data)
m691 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win9 + 1, data=data)
m692 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win12 + 1, data=data)
m693 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 +  + 1, data=data)
m694 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m695 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m696 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m697 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 +  + 1, data=data)
m698 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m699 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m700 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m701 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 +  + 1, data=data)
m702 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m703 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m704 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m705 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  +  +  + 1, data=data)
m706 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  +  + transition.win15 + 1, data=data)
m707 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  +  + transition.win9 + 1, data=data)
m708 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  +  + transition.win12 + 1, data=data)
m709 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win4 +  + 1, data=data)
m710 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win15 + 1, data=data)
m711 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win9 + 1, data=data)
m712 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win12 + 1, data=data)
m713 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win2 +  + 1, data=data)
m714 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win15 + 1, data=data)
m715 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win9 + 1, data=data)
m716 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win12 + 1, data=data)
m717 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win3 +  + 1, data=data)
m718 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win15 + 1, data=data)
m719 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win9 + 1, data=data)
m720 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win12 + 1, data=data)
m721 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 +  +  + 1, data=data)
m722 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win15 + 1, data=data)
m723 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win9 + 1, data=data)
m724 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win12 + 1, data=data)
m725 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 +  + 1, data=data)
m726 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m727 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m728 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m729 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 +  + 1, data=data)
m730 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m731 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m732 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m733 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 +  + 1, data=data)
m734 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m735 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m736 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m737 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 +  +  + 1, data=data)
m738 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win15 + 1, data=data)
m739 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win9 + 1, data=data)
m740 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win12 + 1, data=data)
m741 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 +  + 1, data=data)
m742 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m743 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m744 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m745 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 +  + 1, data=data)
m746 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m747 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m748 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m749 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 +  + 1, data=data)
m750 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m751 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m752 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m753 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 +  +  + 1, data=data)
m754 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win15 + 1, data=data)
m755 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win9 + 1, data=data)
m756 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win12 + 1, data=data)
m757 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 +  + 1, data=data)
m758 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m759 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m760 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m761 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 +  + 1, data=data)
m762 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m763 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m764 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m765 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 +  + 1, data=data)
m766 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m767 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m768 <-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m769 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  +  +  + 1, data=data)
m770 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  +  + transition.win15 + 1, data=data)
m771 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  +  + transition.win9 + 1, data=data)
m772 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  +  + transition.win12 + 1, data=data)
m773 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win4 +  + 1, data=data)
m774 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win4 + transition.win15 + 1, data=data)
m775 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win4 + transition.win9 + 1, data=data)
m776 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win4 + transition.win12 + 1, data=data)
m777 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win2 +  + 1, data=data)
m778 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win2 + transition.win15 + 1, data=data)
m779 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win2 + transition.win9 + 1, data=data)
m780 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win2 + transition.win12 + 1, data=data)
m781 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win3 +  + 1, data=data)
m782 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win3 + transition.win15 + 1, data=data)
m783 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win3 + transition.win9 + 1, data=data)
m784 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  +  + extmob.win3 + transition.win12 + 1, data=data)
m785 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 +  +  + 1, data=data)
m786 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 +  + transition.win15 + 1, data=data)
m787 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 +  + transition.win9 + 1, data=data)
m788 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 +  + transition.win12 + 1, data=data)
m789 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win4 +  + 1, data=data)
m790 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m791 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m792 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m793 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win2 +  + 1, data=data)
m794 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m795 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m796 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m797 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win3 +  + 1, data=data)
m798 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m799 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m800 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m801 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 +  +  + 1, data=data)
m802 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 +  + transition.win15 + 1, data=data)
m803 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 +  + transition.win9 + 1, data=data)
m804 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 +  + transition.win12 + 1, data=data)
m805 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win4 +  + 1, data=data)
m806 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m807 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m808 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m809 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win2 +  + 1, data=data)
m810 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m811 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m812 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m813 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win3 +  + 1, data=data)
m814 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m815 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m816 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m817 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 +  +  + 1, data=data)
m818 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 +  + transition.win15 + 1, data=data)
m819 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 +  + transition.win9 + 1, data=data)
m820 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 +  + transition.win12 + 1, data=data)
m821 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win4 +  + 1, data=data)
m822 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m823 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m824 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m825 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win2 +  + 1, data=data)
m826 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m827 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m828 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m829 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win3 +  + 1, data=data)
m830 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m831 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m832 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m833 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  +  +  + 1, data=data)
m834 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  +  + transition.win15 + 1, data=data)
m835 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  +  + transition.win9 + 1, data=data)
m836 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  +  + transition.win12 + 1, data=data)
m837 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win4 +  + 1, data=data)
m838 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win15 + 1, data=data)
m839 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win9 + 1, data=data)
m840 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win12 + 1, data=data)
m841 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win2 +  + 1, data=data)
m842 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win15 + 1, data=data)
m843 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win9 + 1, data=data)
m844 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win12 + 1, data=data)
m845 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win3 +  + 1, data=data)
m846 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win15 + 1, data=data)
m847 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win9 + 1, data=data)
m848 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win12 + 1, data=data)
m849 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 +  +  + 1, data=data)
m850 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win15 + 1, data=data)
m851 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win9 + 1, data=data)
m852 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win12 + 1, data=data)
m853 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 +  + 1, data=data)
m854 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m855 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m856 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m857 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 +  + 1, data=data)
m858 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m859 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m860 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m861 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 +  + 1, data=data)
m862 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m863 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m864 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m865 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 +  +  + 1, data=data)
m866 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win15 + 1, data=data)
m867 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win9 + 1, data=data)
m868 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win12 + 1, data=data)
m869 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 +  + 1, data=data)
m870 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m871 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m872 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m873 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 +  + 1, data=data)
m874 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m875 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m876 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m877 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 +  + 1, data=data)
m878 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m879 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m880 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m881 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 +  +  + 1, data=data)
m882 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win15 + 1, data=data)
m883 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win9 + 1, data=data)
m884 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win12 + 1, data=data)
m885 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 +  + 1, data=data)
m886 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m887 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m888 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m889 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 +  + 1, data=data)
m890 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m891 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m892 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m893 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 +  + 1, data=data)
m894 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m895 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m896 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m897 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  +  +  + 1, data=data)
m898 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  +  + transition.win15 + 1, data=data)
m899 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  +  + transition.win9 + 1, data=data)
m900 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  +  + transition.win12 + 1, data=data)
m901 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win4 +  + 1, data=data)
m902 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win15 + 1, data=data)
m903 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win9 + 1, data=data)
m904 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win12 + 1, data=data)
m905 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win2 +  + 1, data=data)
m906 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win15 + 1, data=data)
m907 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win9 + 1, data=data)
m908 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win12 + 1, data=data)
m909 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win3 +  + 1, data=data)
m910 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win15 + 1, data=data)
m911 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win9 + 1, data=data)
m912 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win12 + 1, data=data)
m913 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 +  +  + 1, data=data)
m914 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win15 + 1, data=data)
m915 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win9 + 1, data=data)
m916 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win12 + 1, data=data)
m917 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 +  + 1, data=data)
m918 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m919 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m920 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m921 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 +  + 1, data=data)
m922 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m923 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m924 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m925 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 +  + 1, data=data)
m926 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m927 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m928 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m929 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 +  +  + 1, data=data)
m930 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win15 + 1, data=data)
m931 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win9 + 1, data=data)
m932 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win12 + 1, data=data)
m933 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 +  + 1, data=data)
m934 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m935 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m936 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m937 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 +  + 1, data=data)
m938 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m939 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m940 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m941 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 +  + 1, data=data)
m942 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m943 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m944 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m945 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 +  +  + 1, data=data)
m946 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win15 + 1, data=data)
m947 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win9 + 1, data=data)
m948 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win12 + 1, data=data)
m949 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 +  + 1, data=data)
m950 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m951 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m952 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m953 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 +  + 1, data=data)
m954 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m955 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m956 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m957 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 +  + 1, data=data)
m958 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m959 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m960 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m961 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  +  +  + 1, data=data)
m962 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  +  + transition.win15 + 1, data=data)
m963 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  +  + transition.win9 + 1, data=data)
m964 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  +  + transition.win12 + 1, data=data)
m965 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win4 +  + 1, data=data)
m966 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win15 + 1, data=data)
m967 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win9 + 1, data=data)
m968 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win12 + 1, data=data)
m969 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win2 +  + 1, data=data)
m970 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win15 + 1, data=data)
m971 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win9 + 1, data=data)
m972 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win12 + 1, data=data)
m973 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win3 +  + 1, data=data)
m974 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win15 + 1, data=data)
m975 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win9 + 1, data=data)
m976 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win12 + 1, data=data)
m977 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 +  +  + 1, data=data)
m978 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win15 + 1, data=data)
m979 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win9 + 1, data=data)
m980 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win12 + 1, data=data)
m981 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 +  + 1, data=data)
m982 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m983 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m984 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m985 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 +  + 1, data=data)
m986 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m987 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m988 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m989 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 +  + 1, data=data)
m990 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m991 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m992 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m993 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 +  +  + 1, data=data)
m994 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win15 + 1, data=data)
m995 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win9 + 1, data=data)
m996 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win12 + 1, data=data)
m997 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 +  + 1, data=data)
m998 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m999 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1000 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1001 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 +  + 1, data=data)
m1002 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1003 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1004 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1005 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 +  + 1, data=data)
m1006 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1007 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1008 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1009 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 +  +  + 1, data=data)
m1010 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win15 + 1, data=data)
m1011 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win9 + 1, data=data)
m1012 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win12 + 1, data=data)
m1013 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 +  + 1, data=data)
m1014 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1015 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1016 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1017 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 +  + 1, data=data)
m1018 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1019 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1020 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1021 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 +  + 1, data=data)
m1022 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1023 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1024 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1025 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  +  +  + 1, data=data)
m1026 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  +  + transition.win15 + 1, data=data)
m1027 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  +  + transition.win9 + 1, data=data)
m1028 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  +  + transition.win12 + 1, data=data)
m1029 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win4 +  + 1, data=data)
m1030 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win4 + transition.win15 + 1, data=data)
m1031 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win4 + transition.win9 + 1, data=data)
m1032 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win4 + transition.win12 + 1, data=data)
m1033 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win2 +  + 1, data=data)
m1034 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win2 + transition.win15 + 1, data=data)
m1035 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win2 + transition.win9 + 1, data=data)
m1036 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win2 + transition.win12 + 1, data=data)
m1037 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win3 +  + 1, data=data)
m1038 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win3 + transition.win15 + 1, data=data)
m1039 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win3 + transition.win9 + 1, data=data)
m1040 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  +  + extmob.win3 + transition.win12 + 1, data=data)
m1041 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 +  +  + 1, data=data)
m1042 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 +  + transition.win15 + 1, data=data)
m1043 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 +  + transition.win9 + 1, data=data)
m1044 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 +  + transition.win12 + 1, data=data)
m1045 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win4 +  + 1, data=data)
m1046 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m1047 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m1048 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m1049 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win2 +  + 1, data=data)
m1050 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m1051 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m1052 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m1053 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win3 +  + 1, data=data)
m1054 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m1055 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m1056 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m1057 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 +  +  + 1, data=data)
m1058 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 +  + transition.win15 + 1, data=data)
m1059 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 +  + transition.win9 + 1, data=data)
m1060 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 +  + transition.win12 + 1, data=data)
m1061 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win4 +  + 1, data=data)
m1062 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m1063 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1064 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1065 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win2 +  + 1, data=data)
m1066 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1067 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1068 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1069 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win3 +  + 1, data=data)
m1070 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1071 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1072 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1073 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 +  +  + 1, data=data)
m1074 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 +  + transition.win15 + 1, data=data)
m1075 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 +  + transition.win9 + 1, data=data)
m1076 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 +  + transition.win12 + 1, data=data)
m1077 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win4 +  + 1, data=data)
m1078 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1079 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1080 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1081 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win2 +  + 1, data=data)
m1082 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1083 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1084 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1085 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win3 +  + 1, data=data)
m1086 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1087 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1088 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1089 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  +  +  + 1, data=data)
m1090 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  +  + transition.win15 + 1, data=data)
m1091 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  +  + transition.win9 + 1, data=data)
m1092 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  +  + transition.win12 + 1, data=data)
m1093 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win4 +  + 1, data=data)
m1094 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win15 + 1, data=data)
m1095 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win9 + 1, data=data)
m1096 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win12 + 1, data=data)
m1097 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win2 +  + 1, data=data)
m1098 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win15 + 1, data=data)
m1099 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win9 + 1, data=data)
m1100 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win12 + 1, data=data)
m1101 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win3 +  + 1, data=data)
m1102 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win15 + 1, data=data)
m1103 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win9 + 1, data=data)
m1104 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win12 + 1, data=data)
m1105 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 +  +  + 1, data=data)
m1106 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win15 + 1, data=data)
m1107 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win9 + 1, data=data)
m1108 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win12 + 1, data=data)
m1109 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 +  + 1, data=data)
m1110 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m1111 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m1112 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m1113 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 +  + 1, data=data)
m1114 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m1115 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m1116 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m1117 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 +  + 1, data=data)
m1118 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m1119 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m1120 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m1121 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 +  +  + 1, data=data)
m1122 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win15 + 1, data=data)
m1123 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win9 + 1, data=data)
m1124 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win12 + 1, data=data)
m1125 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 +  + 1, data=data)
m1126 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m1127 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1128 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1129 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 +  + 1, data=data)
m1130 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1131 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1132 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1133 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 +  + 1, data=data)
m1134 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1135 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1136 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1137 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 +  +  + 1, data=data)
m1138 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win15 + 1, data=data)
m1139 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win9 + 1, data=data)
m1140 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win12 + 1, data=data)
m1141 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 +  + 1, data=data)
m1142 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1143 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1144 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1145 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 +  + 1, data=data)
m1146 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1147 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1148 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1149 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 +  + 1, data=data)
m1150 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1151 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1152 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1153 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  +  +  + 1, data=data)
m1154 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  +  + transition.win15 + 1, data=data)
m1155 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  +  + transition.win9 + 1, data=data)
m1156 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  +  + transition.win12 + 1, data=data)
m1157 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win4 +  + 1, data=data)
m1158 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win15 + 1, data=data)
m1159 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win9 + 1, data=data)
m1160 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win12 + 1, data=data)
m1161 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win2 +  + 1, data=data)
m1162 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win15 + 1, data=data)
m1163 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win9 + 1, data=data)
m1164 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win12 + 1, data=data)
m1165 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win3 +  + 1, data=data)
m1166 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win15 + 1, data=data)
m1167 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win9 + 1, data=data)
m1168 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win12 + 1, data=data)
m1169 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 +  +  + 1, data=data)
m1170 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win15 + 1, data=data)
m1171 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win9 + 1, data=data)
m1172 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win12 + 1, data=data)
m1173 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 +  + 1, data=data)
m1174 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m1175 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m1176 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m1177 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 +  + 1, data=data)
m1178 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m1179 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m1180 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m1181 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 +  + 1, data=data)
m1182 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m1183 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m1184 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m1185 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 +  +  + 1, data=data)
m1186 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win15 + 1, data=data)
m1187 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win9 + 1, data=data)
m1188 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win12 + 1, data=data)
m1189 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 +  + 1, data=data)
m1190 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m1191 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1192 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1193 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 +  + 1, data=data)
m1194 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1195 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1196 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1197 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 +  + 1, data=data)
m1198 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1199 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1200 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1201 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 +  +  + 1, data=data)
m1202 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win15 + 1, data=data)
m1203 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win9 + 1, data=data)
m1204 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win12 + 1, data=data)
m1205 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 +  + 1, data=data)
m1206 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1207 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1208 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1209 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 +  + 1, data=data)
m1210 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1211 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1212 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1213 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 +  + 1, data=data)
m1214 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1215 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1216 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1217 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  +  +  + 1, data=data)
m1218 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  +  + transition.win15 + 1, data=data)
m1219 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  +  + transition.win9 + 1, data=data)
m1220 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  +  + transition.win12 + 1, data=data)
m1221 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win4 +  + 1, data=data)
m1222 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win15 + 1, data=data)
m1223 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win9 + 1, data=data)
m1224 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win12 + 1, data=data)
m1225 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win2 +  + 1, data=data)
m1226 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win15 + 1, data=data)
m1227 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win9 + 1, data=data)
m1228 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win12 + 1, data=data)
m1229 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win3 +  + 1, data=data)
m1230 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win15 + 1, data=data)
m1231 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win9 + 1, data=data)
m1232 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win12 + 1, data=data)
m1233 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 +  +  + 1, data=data)
m1234 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win15 + 1, data=data)
m1235 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win9 + 1, data=data)
m1236 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win12 + 1, data=data)
m1237 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 +  + 1, data=data)
m1238 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m1239 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m1240 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m1241 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 +  + 1, data=data)
m1242 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m1243 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m1244 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m1245 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 +  + 1, data=data)
m1246 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m1247 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m1248 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m1249 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 +  +  + 1, data=data)
m1250 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win15 + 1, data=data)
m1251 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win9 + 1, data=data)
m1252 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win12 + 1, data=data)
m1253 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 +  + 1, data=data)
m1254 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m1255 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1256 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1257 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 +  + 1, data=data)
m1258 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1259 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1260 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1261 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 +  + 1, data=data)
m1262 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1263 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1264 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1265 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 +  +  + 1, data=data)
m1266 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win15 + 1, data=data)
m1267 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win9 + 1, data=data)
m1268 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win12 + 1, data=data)
m1269 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 +  + 1, data=data)
m1270 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1271 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1272 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1273 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 +  + 1, data=data)
m1274 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1275 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1276 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1277 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 +  + 1, data=data)
m1278 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1279 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1280 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1281 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  +  +  + 1, data=data)
m1282 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  +  + transition.win15 + 1, data=data)
m1283 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  +  + transition.win9 + 1, data=data)
m1284 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  +  + transition.win12 + 1, data=data)
m1285 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win4 +  + 1, data=data)
m1286 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win4 + transition.win15 + 1, data=data)
m1287 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win4 + transition.win9 + 1, data=data)
m1288 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win4 + transition.win12 + 1, data=data)
m1289 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win2 +  + 1, data=data)
m1290 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win2 + transition.win15 + 1, data=data)
m1291 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win2 + transition.win9 + 1, data=data)
m1292 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win2 + transition.win12 + 1, data=data)
m1293 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win3 +  + 1, data=data)
m1294 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win3 + transition.win15 + 1, data=data)
m1295 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win3 + transition.win9 + 1, data=data)
m1296 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  +  + extmob.win3 + transition.win12 + 1, data=data)
m1297 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 +  +  + 1, data=data)
m1298 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 +  + transition.win15 + 1, data=data)
m1299 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 +  + transition.win9 + 1, data=data)
m1300 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 +  + transition.win12 + 1, data=data)
m1301 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win4 +  + 1, data=data)
m1302 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m1303 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m1304 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m1305 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win2 +  + 1, data=data)
m1306 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m1307 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m1308 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m1309 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win3 +  + 1, data=data)
m1310 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m1311 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m1312 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m1313 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 +  +  + 1, data=data)
m1314 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 +  + transition.win15 + 1, data=data)
m1315 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 +  + transition.win9 + 1, data=data)
m1316 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 +  + transition.win12 + 1, data=data)
m1317 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win4 +  + 1, data=data)
m1318 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m1319 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1320 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1321 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win2 +  + 1, data=data)
m1322 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1323 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1324 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1325 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win3 +  + 1, data=data)
m1326 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1327 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1328 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1329 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 +  +  + 1, data=data)
m1330 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 +  + transition.win15 + 1, data=data)
m1331 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 +  + transition.win9 + 1, data=data)
m1332 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 +  + transition.win12 + 1, data=data)
m1333 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win4 +  + 1, data=data)
m1334 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1335 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1336 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1337 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win2 +  + 1, data=data)
m1338 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1339 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1340 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1341 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win3 +  + 1, data=data)
m1342 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1343 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1344 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1345 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  +  +  + 1, data=data)
m1346 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  +  + transition.win15 + 1, data=data)
m1347 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  +  + transition.win9 + 1, data=data)
m1348 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  +  + transition.win12 + 1, data=data)
m1349 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win4 +  + 1, data=data)
m1350 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win15 + 1, data=data)
m1351 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win9 + 1, data=data)
m1352 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win12 + 1, data=data)
m1353 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win2 +  + 1, data=data)
m1354 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win15 + 1, data=data)
m1355 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win9 + 1, data=data)
m1356 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win12 + 1, data=data)
m1357 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win3 +  + 1, data=data)
m1358 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win15 + 1, data=data)
m1359 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win9 + 1, data=data)
m1360 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win12 + 1, data=data)
m1361 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 +  +  + 1, data=data)
m1362 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win15 + 1, data=data)
m1363 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win9 + 1, data=data)
m1364 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win12 + 1, data=data)
m1365 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 +  + 1, data=data)
m1366 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m1367 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m1368 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m1369 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 +  + 1, data=data)
m1370 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m1371 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m1372 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m1373 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 +  + 1, data=data)
m1374 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m1375 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m1376 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m1377 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 +  +  + 1, data=data)
m1378 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win15 + 1, data=data)
m1379 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win9 + 1, data=data)
m1380 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win12 + 1, data=data)
m1381 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 +  + 1, data=data)
m1382 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m1383 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1384 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1385 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 +  + 1, data=data)
m1386 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1387 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1388 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1389 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 +  + 1, data=data)
m1390 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1391 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1392 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1393 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 +  +  + 1, data=data)
m1394 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win15 + 1, data=data)
m1395 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win9 + 1, data=data)
m1396 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win12 + 1, data=data)
m1397 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 +  + 1, data=data)
m1398 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1399 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1400 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1401 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 +  + 1, data=data)
m1402 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1403 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1404 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1405 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 +  + 1, data=data)
m1406 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1407 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1408 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1409 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  +  +  + 1, data=data)
m1410 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  +  + transition.win15 + 1, data=data)
m1411 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  +  + transition.win9 + 1, data=data)
m1412 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  +  + transition.win12 + 1, data=data)
m1413 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win4 +  + 1, data=data)
m1414 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win15 + 1, data=data)
m1415 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win9 + 1, data=data)
m1416 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win12 + 1, data=data)
m1417 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win2 +  + 1, data=data)
m1418 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win15 + 1, data=data)
m1419 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win9 + 1, data=data)
m1420 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win12 + 1, data=data)
m1421 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win3 +  + 1, data=data)
m1422 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win15 + 1, data=data)
m1423 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win9 + 1, data=data)
m1424 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win12 + 1, data=data)
m1425 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 +  +  + 1, data=data)
m1426 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win15 + 1, data=data)
m1427 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win9 + 1, data=data)
m1428 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win12 + 1, data=data)
m1429 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 +  + 1, data=data)
m1430 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m1431 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m1432 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m1433 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 +  + 1, data=data)
m1434 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m1435 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m1436 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m1437 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 +  + 1, data=data)
m1438 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m1439 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m1440 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m1441 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 +  +  + 1, data=data)
m1442 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win15 + 1, data=data)
m1443 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win9 + 1, data=data)
m1444 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win12 + 1, data=data)
m1445 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 +  + 1, data=data)
m1446 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m1447 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1448 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1449 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 +  + 1, data=data)
m1450 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1451 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1452 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1453 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 +  + 1, data=data)
m1454 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1455 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1456 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1457 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 +  +  + 1, data=data)
m1458 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win15 + 1, data=data)
m1459 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win9 + 1, data=data)
m1460 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win12 + 1, data=data)
m1461 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 +  + 1, data=data)
m1462 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1463 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1464 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1465 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 +  + 1, data=data)
m1466 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1467 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1468 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1469 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 +  + 1, data=data)
m1470 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1471 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1472 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1473 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  +  +  + 1, data=data)
m1474 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  +  + transition.win15 + 1, data=data)
m1475 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  +  + transition.win9 + 1, data=data)
m1476 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  +  + transition.win12 + 1, data=data)
m1477 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win4 +  + 1, data=data)
m1478 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win15 + 1, data=data)
m1479 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win9 + 1, data=data)
m1480 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win12 + 1, data=data)
m1481 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win2 +  + 1, data=data)
m1482 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win15 + 1, data=data)
m1483 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win9 + 1, data=data)
m1484 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win12 + 1, data=data)
m1485 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win3 +  + 1, data=data)
m1486 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win15 + 1, data=data)
m1487 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win9 + 1, data=data)
m1488 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win12 + 1, data=data)
m1489 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 +  +  + 1, data=data)
m1490 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win15 + 1, data=data)
m1491 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win9 + 1, data=data)
m1492 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win12 + 1, data=data)
m1493 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 +  + 1, data=data)
m1494 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1, data=data)
m1495 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1, data=data)
m1496 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1, data=data)
m1497 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 +  + 1, data=data)
m1498 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1, data=data)
m1499 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1, data=data)
m1500 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1, data=data)
m1501 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 +  + 1, data=data)
m1502 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1, data=data)
m1503 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1, data=data)
m1504 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1, data=data)
m1505 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 +  +  + 1, data=data)
m1506 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win15 + 1, data=data)
m1507 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win9 + 1, data=data)
m1508 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win12 + 1, data=data)
m1509 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 +  + 1, data=data)
m1510 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1, data=data)
m1511 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1, data=data)
m1512 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1, data=data)
m1513 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 +  + 1, data=data)
m1514 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1, data=data)
m1515 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1, data=data)
m1516 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1, data=data)
m1517 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 +  + 1, data=data)
m1518 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1, data=data)
m1519 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1, data=data)
m1520 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1, data=data)
m1521 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 +  +  + 1, data=data)
m1522 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win15 + 1, data=data)
m1523 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win9 + 1, data=data)
m1524 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win12 + 1, data=data)
m1525 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 +  + 1, data=data)
m1526 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1, data=data)
m1527 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1, data=data)
m1528 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1, data=data)
m1529 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 +  + 1, data=data)
m1530 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1, data=data)
m1531 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1, data=data)
m1532 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1, data=data)
m1533 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 +  + 1, data=data)
m1534 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1, data=data)
m1535 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1, data=data)
m1536 <-glm.nb(issue.dem.ext1.det ~t+t2+t3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1, data=data)
m1537<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  +  +  + 1,1,data=data)
m1538<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  +  + transition.win15 + 1,data=data)
m1539<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  +  + transition.win9 + 1,data=data)
m1540<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  +  + transition.win12 + 1,data=data)
m1541<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win4 +  + 1,data=data)
m1542<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m1543<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m1544<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m1545<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win2 +  + 1,data=data)
m1546<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m1547<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m1548<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m1549<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win3 +  + 1,data=data)
m1550<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m1551<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m1552<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m1553<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 +  +  + 1,data=data)
m1554<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 +  + transition.win15 + 1,data=data)
m1555<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 +  + transition.win9 + 1,data=data)
m1556<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 +  + transition.win12 + 1,data=data)
m1557<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win4 +  + 1,data=data)
m1558<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1559<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1560<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1561<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win2 +  + 1,data=data)
m1562<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1563<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1564<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1565<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win3 +  + 1,data=data)
m1566<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1567<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1568<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1569<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 +  +  + 1,data=data)
m1570<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 +  + transition.win15 + 1,data=data)
m1571<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 +  + transition.win9 + 1,data=data)
m1572<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 +  + transition.win12 + 1,data=data)
m1573<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win4 +  + 1,data=data)
m1574<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1575<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1576<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1577<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win2 +  + 1,data=data)
m1578<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1579<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1580<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1581<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win3 +  + 1,data=data)
m1582<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1583<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1584<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1585<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 +  +  + 1,data=data)
m1586<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 +  + transition.win15 + 1,data=data)
m1587<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 +  + transition.win9 + 1,data=data)
m1588<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 +  + transition.win12 + 1,data=data)
m1589<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win4 +  + 1,data=data)
m1590<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1591<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1592<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1593<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win2 +  + 1,data=data)
m1594<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1595<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1596<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1597<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win3 +  + 1,data=data)
m1598<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1599<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1600<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1601<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  +  +  + 1,data=data)
m1602<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  +  + transition.win15 + 1,data=data)
m1603<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  +  + transition.win9 + 1,data=data)
m1604<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  +  + transition.win12 + 1,data=data)
m1605<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win4 +  + 1,data=data)
m1606<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m1607<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m1608<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m1609<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win2 +  + 1,data=data)
m1610<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m1611<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m1612<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m1613<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win3 +  + 1,data=data)
m1614<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m1615<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m1616<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m1617<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 +  +  + 1,data=data)
m1618<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m1619<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m1620<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m1621<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m1622<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1623<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1624<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1625<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m1626<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1627<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1628<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1629<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m1630<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1631<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1632<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1633<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 +  +  + 1,data=data)
m1634<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m1635<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m1636<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m1637<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m1638<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1639<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1640<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1641<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m1642<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1643<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1644<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1645<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m1646<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1647<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1648<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1649<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 +  +  + 1,data=data)
m1650<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m1651<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m1652<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m1653<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m1654<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1655<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1656<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1657<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m1658<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1659<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1660<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1661<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m1662<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1663<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1664<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1665<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  +  +  + 1,data=data)
m1666<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  +  + transition.win15 + 1,data=data)
m1667<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  +  + transition.win9 + 1,data=data)
m1668<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  +  + transition.win12 + 1,data=data)
m1669<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win4 +  + 1,data=data)
m1670<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m1671<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m1672<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m1673<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win2 +  + 1,data=data)
m1674<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m1675<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m1676<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m1677<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win3 +  + 1,data=data)
m1678<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m1679<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m1680<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m1681<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 +  +  + 1,data=data)
m1682<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m1683<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m1684<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m1685<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m1686<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1687<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1688<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1689<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m1690<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1691<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1692<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1693<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m1694<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1695<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1696<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1697<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 +  +  + 1,data=data)
m1698<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m1699<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m1700<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m1701<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m1702<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1703<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1704<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1705<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m1706<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1707<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1708<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1709<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m1710<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1711<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1712<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1713<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 +  +  + 1,data=data)
m1714<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m1715<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m1716<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m1717<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m1718<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1719<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1720<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1721<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m1722<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1723<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1724<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1725<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m1726<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1727<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1728<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1729<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  +  +  + 1,data=data)
m1730<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  +  + transition.win15 + 1,data=data)
m1731<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  +  + transition.win9 + 1,data=data)
m1732<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  +  + transition.win12 + 1,data=data)
m1733<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win4 +  + 1,data=data)
m1734<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m1735<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m1736<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m1737<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win2 +  + 1,data=data)
m1738<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m1739<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m1740<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m1741<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win3 +  + 1,data=data)
m1742<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m1743<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m1744<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m1745<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 +  +  + 1,data=data)
m1746<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m1747<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m1748<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m1749<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m1750<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1751<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1752<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1753<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m1754<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1755<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1756<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1757<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m1758<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1759<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1760<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1761<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 +  +  + 1,data=data)
m1762<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m1763<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m1764<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m1765<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m1766<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1767<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1768<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1769<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m1770<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1771<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1772<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1773<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m1774<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1775<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1776<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1777<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 +  +  + 1,data=data)
m1778<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m1779<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m1780<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m1781<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m1782<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1783<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1784<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1785<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m1786<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1787<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1788<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1789<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m1790<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1791<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1792<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1793<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  +  +  + 1,data=data)
m1794<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  +  + transition.win15 + 1,data=data)
m1795<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  +  + transition.win9 + 1,data=data)
m1796<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  +  + transition.win12 + 1,data=data)
m1797<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win4 +  + 1,data=data)
m1798<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m1799<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m1800<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m1801<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win2 +  + 1,data=data)
m1802<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m1803<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m1804<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m1805<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win3 +  + 1,data=data)
m1806<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m1807<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m1808<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m1809<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 +  +  + 1,data=data)
m1810<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 +  + transition.win15 + 1,data=data)
m1811<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 +  + transition.win9 + 1,data=data)
m1812<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 +  + transition.win12 + 1,data=data)
m1813<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win4 +  + 1,data=data)
m1814<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1815<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1816<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1817<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win2 +  + 1,data=data)
m1818<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1819<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1820<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1821<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win3 +  + 1,data=data)
m1822<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1823<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1824<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1825<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 +  +  + 1,data=data)
m1826<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 +  + transition.win15 + 1,data=data)
m1827<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 +  + transition.win9 + 1,data=data)
m1828<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 +  + transition.win12 + 1,data=data)
m1829<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win4 +  + 1,data=data)
m1830<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1831<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1832<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1833<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win2 +  + 1,data=data)
m1834<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1835<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1836<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1837<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win3 +  + 1,data=data)
m1838<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1839<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1840<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1841<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 +  +  + 1,data=data)
m1842<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 +  + transition.win15 + 1,data=data)
m1843<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 +  + transition.win9 + 1,data=data)
m1844<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 +  + transition.win12 + 1,data=data)
m1845<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win4 +  + 1,data=data)
m1846<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1847<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1848<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1849<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win2 +  + 1,data=data)
m1850<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1851<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1852<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1853<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win3 +  + 1,data=data)
m1854<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1855<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1856<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1857<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  +  +  + 1,data=data)
m1858<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  +  + transition.win15 + 1,data=data)
m1859<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  +  + transition.win9 + 1,data=data)
m1860<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  +  + transition.win12 + 1,data=data)
m1861<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win4 +  + 1,data=data)
m1862<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m1863<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m1864<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m1865<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win2 +  + 1,data=data)
m1866<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m1867<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m1868<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m1869<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win3 +  + 1,data=data)
m1870<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m1871<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m1872<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m1873<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 +  +  + 1,data=data)
m1874<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m1875<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m1876<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m1877<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m1878<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1879<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1880<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1881<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m1882<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1883<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1884<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1885<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m1886<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1887<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1888<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1889<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 +  +  + 1,data=data)
m1890<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m1891<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m1892<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m1893<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m1894<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1895<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1896<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1897<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m1898<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1899<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1900<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1901<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m1902<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1903<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1904<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1905<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 +  +  + 1,data=data)
m1906<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m1907<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m1908<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m1909<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m1910<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1911<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1912<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1913<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m1914<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1915<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1916<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1917<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m1918<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1919<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1920<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1921<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  +  +  + 1,data=data)
m1922<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  +  + transition.win15 + 1,data=data)
m1923<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  +  + transition.win9 + 1,data=data)
m1924<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  +  + transition.win12 + 1,data=data)
m1925<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win4 +  + 1,data=data)
m1926<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m1927<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m1928<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m1929<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win2 +  + 1,data=data)
m1930<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m1931<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m1932<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m1933<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win3 +  + 1,data=data)
m1934<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m1935<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m1936<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m1937<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 +  +  + 1,data=data)
m1938<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m1939<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m1940<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m1941<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m1942<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1943<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1944<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1945<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m1946<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1947<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1948<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1949<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m1950<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1951<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1952<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1953<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 +  +  + 1,data=data)
m1954<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m1955<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m1956<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m1957<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m1958<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1959<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1960<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1961<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m1962<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1963<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1964<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1965<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m1966<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1967<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1968<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1969<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 +  +  + 1,data=data)
m1970<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m1971<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m1972<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m1973<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m1974<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1975<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1976<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1977<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m1978<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1979<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1980<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1981<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m1982<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1983<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1984<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1985<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  +  +  + 1,data=data)
m1986<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  +  + transition.win15 + 1,data=data)
m1987<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  +  + transition.win9 + 1,data=data)
m1988<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  +  + transition.win12 + 1,data=data)
m1989<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win4 +  + 1,data=data)
m1990<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m1991<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m1992<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m1993<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win2 +  + 1,data=data)
m1994<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m1995<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m1996<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m1997<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win3 +  + 1,data=data)
m1998<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m1999<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m2000<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m2001<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 +  +  + 1,data=data)
m2002<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m2003<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m2004<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m2005<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m2006<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2007<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2008<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2009<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m2010<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2011<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2012<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2013<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m2014<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2015<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2016<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2017<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 +  +  + 1,data=data)
m2018<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m2019<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m2020<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m2021<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m2022<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2023<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2024<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2025<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m2026<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2027<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2028<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2029<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m2030<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2031<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2032<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2033<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 +  +  + 1,data=data)
m2034<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m2035<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m2036<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m2037<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m2038<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2039<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2040<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2041<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m2042<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2043<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2044<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2045<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m2046<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2047<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2048<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2049<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  +  +  + 1,data=data)
m2050<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  +  + transition.win15 + 1,data=data)
m2051<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  +  + transition.win9 + 1,data=data)
m2052<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  +  + transition.win12 + 1,data=data)
m2053<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win4 +  + 1,data=data)
m2054<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m2055<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m2056<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m2057<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win2 +  + 1,data=data)
m2058<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m2059<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m2060<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m2061<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win3 +  + 1,data=data)
m2062<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m2063<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m2064<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m2065<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 +  +  + 1,data=data)
m2066<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 +  + transition.win15 + 1,data=data)
m2067<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 +  + transition.win9 + 1,data=data)
m2068<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 +  + transition.win12 + 1,data=data)
m2069<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win4 +  + 1,data=data)
m2070<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2071<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2072<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2073<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win2 +  + 1,data=data)
m2074<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2075<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2076<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2077<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win3 +  + 1,data=data)
m2078<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2079<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2080<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2081<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 +  +  + 1,data=data)
m2082<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 +  + transition.win15 + 1,data=data)
m2083<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 +  + transition.win9 + 1,data=data)
m2084<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 +  + transition.win12 + 1,data=data)
m2085<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win4 +  + 1,data=data)
m2086<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2087<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2088<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2089<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win2 +  + 1,data=data)
m2090<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2091<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2092<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2093<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win3 +  + 1,data=data)
m2094<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2095<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2096<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2097<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 +  +  + 1,data=data)
m2098<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 +  + transition.win15 + 1,data=data)
m2099<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 +  + transition.win9 + 1,data=data)
m2100<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 +  + transition.win12 + 1,data=data)
m2101<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win4 +  + 1,data=data)
m2102<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2103<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2104<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2105<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win2 +  + 1,data=data)
m2106<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2107<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2108<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2109<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win3 +  + 1,data=data)
m2110<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2111<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2112<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2113<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  +  +  + 1,data=data)
m2114<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  +  + transition.win15 + 1,data=data)
m2115<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  +  + transition.win9 + 1,data=data)
m2116<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  +  + transition.win12 + 1,data=data)
m2117<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win4 +  + 1,data=data)
m2118<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m2119<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m2120<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m2121<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win2 +  + 1,data=data)
m2122<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m2123<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m2124<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m2125<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win3 +  + 1,data=data)
m2126<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m2127<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m2128<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m2129<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 +  +  + 1,data=data)
m2130<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m2131<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m2132<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m2133<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m2134<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2135<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2136<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2137<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m2138<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2139<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2140<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2141<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m2142<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2143<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2144<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2145<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 +  +  + 1,data=data)
m2146<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m2147<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m2148<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m2149<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m2150<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2151<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2152<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2153<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m2154<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2155<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2156<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2157<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m2158<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2159<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2160<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2161<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 +  +  + 1,data=data)
m2162<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m2163<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m2164<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m2165<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m2166<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2167<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2168<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2169<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m2170<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2171<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2172<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2173<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m2174<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2175<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2176<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2177<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  +  +  + 1,data=data)
m2178<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  +  + transition.win15 + 1,data=data)
m2179<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  +  + transition.win9 + 1,data=data)
m2180<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  +  + transition.win12 + 1,data=data)
m2181<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win4 +  + 1,data=data)
m2182<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m2183<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m2184<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m2185<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win2 +  + 1,data=data)
m2186<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m2187<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m2188<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m2189<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win3 +  + 1,data=data)
m2190<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m2191<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m2192<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m2193<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 +  +  + 1,data=data)
m2194<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m2195<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m2196<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m2197<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m2198<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2199<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2200<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2201<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m2202<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2203<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2204<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2205<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m2206<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2207<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2208<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2209<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 +  +  + 1,data=data)
m2210<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m2211<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m2212<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m2213<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m2214<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2215<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2216<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2217<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m2218<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2219<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2220<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2221<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m2222<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2223<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2224<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2225<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 +  +  + 1,data=data)
m2226<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m2227<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m2228<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m2229<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m2230<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2231<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2232<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2233<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m2234<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2235<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2236<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2237<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m2238<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2239<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2240<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2241<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  +  +  + 1,data=data)
m2242<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  +  + transition.win15 + 1,data=data)
m2243<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  +  + transition.win9 + 1,data=data)
m2244<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  +  + transition.win12 + 1,data=data)
m2245<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win4 +  + 1,data=data)
m2246<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m2247<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m2248<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m2249<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win2 +  + 1,data=data)
m2250<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m2251<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m2252<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m2253<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win3 +  + 1,data=data)
m2254<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m2255<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m2256<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m2257<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 +  +  + 1,data=data)
m2258<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m2259<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m2260<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m2261<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m2262<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2263<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2264<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2265<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m2266<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2267<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2268<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2269<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m2270<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2271<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2272<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2273<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 +  +  + 1,data=data)
m2274<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m2275<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m2276<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m2277<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m2278<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2279<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2280<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2281<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m2282<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2283<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2284<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2285<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m2286<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2287<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2288<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2289<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 +  +  + 1,data=data)
m2290<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m2291<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m2292<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m2293<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m2294<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2295<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2296<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2297<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m2298<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2299<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2300<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2301<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m2302<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2303<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2304<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2305<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  +  +  + 1,data=data)
m2306<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  +  + transition.win15 + 1,data=data)
m2307<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  +  + transition.win9 + 1,data=data)
m2308<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  +  + transition.win12 + 1,data=data)
m2309<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win4 +  + 1,data=data)
m2310<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m2311<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m2312<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m2313<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win2 +  + 1,data=data)
m2314<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m2315<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m2316<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m2317<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win3 +  + 1,data=data)
m2318<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m2319<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m2320<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m2321<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 +  +  + 1,data=data)
m2322<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 +  + transition.win15 + 1,data=data)
m2323<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 +  + transition.win9 + 1,data=data)
m2324<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 +  + transition.win12 + 1,data=data)
m2325<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win4 +  + 1,data=data)
m2326<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2327<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2328<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2329<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win2 +  + 1,data=data)
m2330<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2331<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2332<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2333<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win3 +  + 1,data=data)
m2334<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2335<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2336<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2337<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 +  +  + 1,data=data)
m2338<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 +  + transition.win15 + 1,data=data)
m2339<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 +  + transition.win9 + 1,data=data)
m2340<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 +  + transition.win12 + 1,data=data)
m2341<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win4 +  + 1,data=data)
m2342<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2343<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2344<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2345<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win2 +  + 1,data=data)
m2346<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2347<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2348<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2349<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win3 +  + 1,data=data)
m2350<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2351<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2352<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2353<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 +  +  + 1,data=data)
m2354<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 +  + transition.win15 + 1,data=data)
m2355<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 +  + transition.win9 + 1,data=data)
m2356<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 +  + transition.win12 + 1,data=data)
m2357<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win4 +  + 1,data=data)
m2358<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2359<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2360<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2361<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win2 +  + 1,data=data)
m2362<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2363<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2364<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2365<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win3 +  + 1,data=data)
m2366<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2367<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2368<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2369<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  +  +  + 1,data=data)
m2370<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  +  + transition.win15 + 1,data=data)
m2371<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  +  + transition.win9 + 1,data=data)
m2372<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  +  + transition.win12 + 1,data=data)
m2373<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win4 +  + 1,data=data)
m2374<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m2375<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m2376<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m2377<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win2 +  + 1,data=data)
m2378<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m2379<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m2380<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m2381<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win3 +  + 1,data=data)
m2382<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m2383<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m2384<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m2385<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 +  +  + 1,data=data)
m2386<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m2387<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m2388<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m2389<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m2390<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2391<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2392<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2393<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m2394<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2395<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2396<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2397<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m2398<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2399<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2400<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2401<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 +  +  + 1,data=data)
m2402<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m2403<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m2404<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m2405<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m2406<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2407<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2408<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2409<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m2410<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2411<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2412<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2413<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m2414<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2415<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2416<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2417<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 +  +  + 1,data=data)
m2418<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m2419<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m2420<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m2421<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m2422<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2423<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2424<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2425<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m2426<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2427<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2428<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2429<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m2430<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2431<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2432<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2433<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  +  +  + 1,data=data)
m2434<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  +  + transition.win15 + 1,data=data)
m2435<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  +  + transition.win9 + 1,data=data)
m2436<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  +  + transition.win12 + 1,data=data)
m2437<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win4 +  + 1,data=data)
m2438<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m2439<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m2440<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m2441<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win2 +  + 1,data=data)
m2442<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m2443<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m2444<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m2445<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win3 +  + 1,data=data)
m2446<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m2447<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m2448<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m2449<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 +  +  + 1,data=data)
m2450<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m2451<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m2452<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m2453<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m2454<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2455<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2456<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2457<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m2458<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2459<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2460<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2461<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m2462<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2463<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2464<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2465<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 +  +  + 1,data=data)
m2466<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m2467<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m2468<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m2469<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m2470<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2471<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2472<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2473<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m2474<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2475<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2476<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2477<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m2478<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2479<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2480<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2481<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 +  +  + 1,data=data)
m2482<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m2483<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m2484<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m2485<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m2486<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2487<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2488<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2489<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m2490<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2491<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2492<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2493<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m2494<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2495<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2496<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2497<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  +  +  + 1,data=data)
m2498<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  +  + transition.win15 + 1,data=data)
m2499<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  +  + transition.win9 + 1,data=data)
m2500<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  +  + transition.win12 + 1,data=data)
m2501<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win4 +  + 1,data=data)
m2502<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m2503<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m2504<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m2505<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win2 +  + 1,data=data)
m2506<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m2507<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m2508<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m2509<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win3 +  + 1,data=data)
m2510<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m2511<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m2512<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m2513<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 +  +  + 1,data=data)
m2514<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m2515<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m2516<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m2517<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m2518<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2519<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2520<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2521<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m2522<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2523<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2524<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2525<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m2526<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2527<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2528<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2529<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 +  +  + 1,data=data)
m2530<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m2531<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m2532<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m2533<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m2534<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2535<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2536<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2537<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m2538<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2539<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2540<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2541<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m2542<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2543<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2544<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2545<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 +  +  + 1,data=data)
m2546<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m2547<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m2548<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m2549<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m2550<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2551<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2552<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2553<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m2554<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2555<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2556<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2557<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m2558<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2559<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2560<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2561<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  +  +  + 1,data=data)
m2562<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  +  + transition.win15 + 1,data=data)
m2563<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  +  + transition.win9 + 1,data=data)
m2564<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  +  + transition.win12 + 1,data=data)
m2565<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win4 +  + 1,data=data)
m2566<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m2567<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m2568<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m2569<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win2 +  + 1,data=data)
m2570<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m2571<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m2572<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m2573<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win3 +  + 1,data=data)
m2574<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m2575<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m2576<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m2577<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 +  +  + 1,data=data)
m2578<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 +  + transition.win15 + 1,data=data)
m2579<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 +  + transition.win9 + 1,data=data)
m2580<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 +  + transition.win12 + 1,data=data)
m2581<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win4 +  + 1,data=data)
m2582<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2583<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2584<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2585<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win2 +  + 1,data=data)
m2586<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2587<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2588<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2589<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win3 +  + 1,data=data)
m2590<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2591<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2592<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2593<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 +  +  + 1,data=data)
m2594<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 +  + transition.win15 + 1,data=data)
m2595<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 +  + transition.win9 + 1,data=data)
m2596<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 +  + transition.win12 + 1,data=data)
m2597<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win4 +  + 1,data=data)
m2598<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2599<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2600<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2601<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win2 +  + 1,data=data)
m2602<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2603<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2604<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2605<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win3 +  + 1,data=data)
m2606<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2607<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2608<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2609<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 +  +  + 1,data=data)
m2610<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 +  + transition.win15 + 1,data=data)
m2611<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 +  + transition.win9 + 1,data=data)
m2612<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 +  + transition.win12 + 1,data=data)
m2613<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win4 +  + 1,data=data)
m2614<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2615<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2616<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2617<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win2 +  + 1,data=data)
m2618<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2619<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2620<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2621<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win3 +  + 1,data=data)
m2622<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2623<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2624<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2625<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  +  +  + 1,data=data)
m2626<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  +  + transition.win15 + 1,data=data)
m2627<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  +  + transition.win9 + 1,data=data)
m2628<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  +  + transition.win12 + 1,data=data)
m2629<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win4 +  + 1,data=data)
m2630<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m2631<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m2632<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m2633<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win2 +  + 1,data=data)
m2634<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m2635<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m2636<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m2637<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win3 +  + 1,data=data)
m2638<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m2639<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m2640<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m2641<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 +  +  + 1,data=data)
m2642<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m2643<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m2644<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m2645<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m2646<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2647<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2648<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2649<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m2650<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2651<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2652<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2653<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m2654<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2655<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2656<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2657<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 +  +  + 1,data=data)
m2658<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m2659<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m2660<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m2661<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m2662<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2663<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2664<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2665<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m2666<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2667<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2668<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2669<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m2670<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2671<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2672<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2673<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 +  +  + 1,data=data)
m2674<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m2675<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m2676<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m2677<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m2678<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2679<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2680<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2681<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m2682<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2683<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2684<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2685<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m2686<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2687<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2688<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2689<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  +  +  + 1,data=data)
m2690<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  +  + transition.win15 + 1,data=data)
m2691<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  +  + transition.win9 + 1,data=data)
m2692<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  +  + transition.win12 + 1,data=data)
m2693<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win4 +  + 1,data=data)
m2694<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m2695<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m2696<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m2697<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win2 +  + 1,data=data)
m2698<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m2699<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m2700<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m2701<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win3 +  + 1,data=data)
m2702<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m2703<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m2704<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m2705<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 +  +  + 1,data=data)
m2706<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m2707<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m2708<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m2709<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m2710<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2711<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2712<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2713<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m2714<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2715<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2716<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2717<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m2718<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2719<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2720<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2721<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 +  +  + 1,data=data)
m2722<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m2723<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m2724<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m2725<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m2726<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2727<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2728<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2729<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m2730<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2731<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2732<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2733<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m2734<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2735<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2736<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2737<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 +  +  + 1,data=data)
m2738<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m2739<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m2740<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m2741<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m2742<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2743<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2744<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2745<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m2746<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2747<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2748<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2749<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m2750<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2751<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2752<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2753<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  +  +  + 1,data=data)
m2754<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  +  + transition.win15 + 1,data=data)
m2755<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  +  + transition.win9 + 1,data=data)
m2756<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  +  + transition.win12 + 1,data=data)
m2757<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win4 +  + 1,data=data)
m2758<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m2759<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m2760<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m2761<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win2 +  + 1,data=data)
m2762<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m2763<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m2764<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m2765<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win3 +  + 1,data=data)
m2766<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m2767<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m2768<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m2769<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 +  +  + 1,data=data)
m2770<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m2771<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m2772<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m2773<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m2774<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2775<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2776<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2777<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m2778<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2779<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2780<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2781<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m2782<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2783<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2784<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2785<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 +  +  + 1,data=data)
m2786<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m2787<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m2788<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m2789<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m2790<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2791<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2792<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2793<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m2794<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2795<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2796<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2797<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m2798<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2799<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2800<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2801<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 +  +  + 1,data=data)
m2802<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m2803<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m2804<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m2805<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m2806<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2807<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2808<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2809<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m2810<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2811<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2812<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2813<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m2814<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2815<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2816<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2817<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  +  +  + 1,data=data)
m2818<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  +  + transition.win15 + 1,data=data)
m2819<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  +  + transition.win9 + 1,data=data)
m2820<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  +  + transition.win12 + 1,data=data)
m2821<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win4 +  + 1,data=data)
m2822<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m2823<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m2824<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m2825<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win2 +  + 1,data=data)
m2826<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m2827<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m2828<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m2829<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win3 +  + 1,data=data)
m2830<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m2831<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m2832<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m2833<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 +  +  + 1,data=data)
m2834<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 +  + transition.win15 + 1,data=data)
m2835<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 +  + transition.win9 + 1,data=data)
m2836<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 +  + transition.win12 + 1,data=data)
m2837<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win4 +  + 1,data=data)
m2838<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2839<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2840<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2841<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win2 +  + 1,data=data)
m2842<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2843<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2844<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2845<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win3 +  + 1,data=data)
m2846<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2847<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2848<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2849<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 +  +  + 1,data=data)
m2850<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 +  + transition.win15 + 1,data=data)
m2851<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 +  + transition.win9 + 1,data=data)
m2852<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 +  + transition.win12 + 1,data=data)
m2853<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win4 +  + 1,data=data)
m2854<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2855<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2856<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2857<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win2 +  + 1,data=data)
m2858<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2859<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2860<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2861<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win3 +  + 1,data=data)
m2862<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2863<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2864<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2865<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 +  +  + 1,data=data)
m2866<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 +  + transition.win15 + 1,data=data)
m2867<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 +  + transition.win9 + 1,data=data)
m2868<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 +  + transition.win12 + 1,data=data)
m2869<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win4 +  + 1,data=data)
m2870<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2871<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2872<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2873<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win2 +  + 1,data=data)
m2874<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2875<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2876<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2877<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win3 +  + 1,data=data)
m2878<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2879<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2880<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2881<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  +  +  + 1,data=data)
m2882<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  +  + transition.win15 + 1,data=data)
m2883<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  +  + transition.win9 + 1,data=data)
m2884<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  +  + transition.win12 + 1,data=data)
m2885<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win4 +  + 1,data=data)
m2886<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m2887<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m2888<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m2889<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win2 +  + 1,data=data)
m2890<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m2891<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m2892<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m2893<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win3 +  + 1,data=data)
m2894<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m2895<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m2896<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m2897<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 +  +  + 1,data=data)
m2898<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m2899<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m2900<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m2901<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m2902<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2903<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2904<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2905<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m2906<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2907<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2908<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2909<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m2910<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2911<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2912<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2913<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 +  +  + 1,data=data)
m2914<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m2915<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m2916<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m2917<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m2918<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2919<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2920<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2921<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m2922<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2923<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2924<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2925<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m2926<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2927<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2928<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2929<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 +  +  + 1,data=data)
m2930<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m2931<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m2932<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m2933<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m2934<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2935<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m2936<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m2937<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m2938<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m2939<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m2940<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m2941<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m2942<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m2943<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m2944<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m2945<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  +  +  + 1,data=data)
m2946<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  +  + transition.win15 + 1,data=data)
m2947<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  +  + transition.win9 + 1,data=data)
m2948<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  +  + transition.win12 + 1,data=data)
m2949<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win4 +  + 1,data=data)
m2950<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m2951<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m2952<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m2953<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win2 +  + 1,data=data)
m2954<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m2955<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m2956<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m2957<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win3 +  + 1,data=data)
m2958<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m2959<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m2960<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m2961<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 +  +  + 1,data=data)
m2962<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m2963<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m2964<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m2965<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m2966<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m2967<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m2968<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m2969<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m2970<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m2971<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m2972<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m2973<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m2974<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m2975<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m2976<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m2977<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 +  +  + 1,data=data)
m2978<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m2979<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m2980<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m2981<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m2982<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m2983<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m2984<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m2985<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m2986<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m2987<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m2988<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m2989<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m2990<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m2991<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m2992<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m2993<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 +  +  + 1,data=data)
m2994<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m2995<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m2996<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m2997<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m2998<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m2999<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3000<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3001<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m3002<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3003<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3004<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3005<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m3006<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3007<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3008<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3009<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  +  +  + 1,data=data)
m3010<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  +  + transition.win15 + 1,data=data)
m3011<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  +  + transition.win9 + 1,data=data)
m3012<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  +  + transition.win12 + 1,data=data)
m3013<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win4 +  + 1,data=data)
m3014<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m3015<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m3016<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m3017<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win2 +  + 1,data=data)
m3018<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m3019<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m3020<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m3021<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win3 +  + 1,data=data)
m3022<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m3023<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m3024<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m3025<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 +  +  + 1,data=data)
m3026<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m3027<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m3028<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m3029<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m3030<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3031<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3032<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3033<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m3034<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3035<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3036<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3037<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m3038<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3039<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3040<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3041<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 +  +  + 1,data=data)
m3042<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m3043<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m3044<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m3045<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m3046<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3047<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3048<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3049<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m3050<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3051<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3052<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3053<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m3054<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3055<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3056<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3057<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 +  +  + 1,data=data)
m3058<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m3059<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m3060<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m3061<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m3062<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3063<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3064<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3065<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m3066<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3067<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3068<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3069<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m3070<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3071<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3072<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3 + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3073<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  +  +  + 1,data=data)
m3074<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  +  + transition.win15 + 1,data=data)
m3075<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  +  + transition.win9 + 1,data=data)
m3076<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  +  + transition.win12 + 1,data=data)
m3077<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win4 +  + 1,data=data)
m3078<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m3079<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m3080<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m3081<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win2 +  + 1,data=data)
m3082<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m3083<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m3084<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m3085<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win3 +  + 1,data=data)
m3086<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m3087<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m3088<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m3089<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 +  +  + 1,data=data)
m3090<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m3091<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m3092<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m3093<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m3094<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3095<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3096<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3097<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m3098<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3099<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3100<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3101<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m3102<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3103<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3104<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3105<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 +  +  + 1,data=data)
m3106<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m3107<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m3108<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m3109<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m3110<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3111<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3112<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3113<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m3114<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3115<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3116<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3117<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m3118<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3119<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3120<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3121<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 +  +  + 1,data=data)
m3122<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m3123<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m3124<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m3125<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m3126<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3127<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3128<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3129<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m3130<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3131<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3132<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3133<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m3134<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3135<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3136<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3137<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  +  +  + 1,data=data)
m3138<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m3139<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m3140<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m3141<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m3142<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m3143<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m3144<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m3145<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m3146<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m3147<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m3148<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m3149<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m3150<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m3151<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m3152<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m3153<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m3154<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m3155<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m3156<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m3157<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m3158<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3159<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3160<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3161<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m3162<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3163<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3164<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3165<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m3166<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3167<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3168<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3169<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m3170<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m3171<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m3172<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m3173<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m3174<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3175<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3176<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3177<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m3178<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3179<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3180<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3181<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m3182<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3183<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3184<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3185<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m3186<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m3187<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m3188<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m3189<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m3190<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3191<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3192<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3193<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m3194<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3195<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3196<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3197<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m3198<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3199<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3200<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3201<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  +  +  + 1,data=data)
m3202<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m3203<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m3204<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m3205<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m3206<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m3207<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m3208<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m3209<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m3210<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m3211<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m3212<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m3213<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m3214<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m3215<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m3216<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m3217<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m3218<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m3219<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m3220<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m3221<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m3222<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3223<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3224<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3225<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m3226<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3227<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3228<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3229<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m3230<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3231<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3232<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3233<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m3234<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m3235<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m3236<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m3237<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m3238<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3239<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3240<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3241<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m3242<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3243<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3244<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3245<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m3246<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3247<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3248<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3249<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m3250<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m3251<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m3252<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m3253<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m3254<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3255<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3256<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3257<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m3258<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3259<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3260<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3261<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m3262<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3263<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3264<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3265<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  +  +  + 1,data=data)
m3266<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m3267<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m3268<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m3269<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m3270<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m3271<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m3272<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m3273<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m3274<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m3275<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m3276<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m3277<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m3278<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m3279<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m3280<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m3281<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m3282<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m3283<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m3284<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m3285<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m3286<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3287<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3288<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3289<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m3290<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3291<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3292<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3293<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m3294<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3295<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3296<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3297<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m3298<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m3299<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m3300<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m3301<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m3302<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3303<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3304<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3305<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m3306<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3307<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3308<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3309<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m3310<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3311<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3312<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3313<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m3314<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m3315<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m3316<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m3317<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m3318<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3319<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3320<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3321<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m3322<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3323<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3324<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3325<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m3326<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3327<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3328<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3329<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  +  +  + 1,data=data)
m3330<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  +  + transition.win15 + 1,data=data)
m3331<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  +  + transition.win9 + 1,data=data)
m3332<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  +  + transition.win12 + 1,data=data)
m3333<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win4 +  + 1,data=data)
m3334<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m3335<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m3336<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m3337<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win2 +  + 1,data=data)
m3338<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m3339<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m3340<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m3341<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win3 +  + 1,data=data)
m3342<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m3343<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m3344<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m3345<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 +  +  + 1,data=data)
m3346<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m3347<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m3348<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m3349<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m3350<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3351<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3352<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3353<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m3354<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3355<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3356<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3357<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m3358<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3359<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3360<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3361<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 +  +  + 1,data=data)
m3362<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m3363<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m3364<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m3365<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m3366<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3367<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3368<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3369<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m3370<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3371<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3372<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3373<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m3374<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3375<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3376<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3377<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 +  +  + 1,data=data)
m3378<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m3379<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m3380<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m3381<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m3382<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3383<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3384<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3385<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m3386<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3387<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3388<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3389<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m3390<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3391<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3392<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3393<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  +  +  + 1,data=data)
m3394<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m3395<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m3396<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m3397<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m3398<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m3399<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m3400<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m3401<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m3402<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m3403<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m3404<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m3405<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m3406<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m3407<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m3408<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m3409<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m3410<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m3411<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m3412<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m3413<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m3414<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3415<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3416<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3417<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m3418<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3419<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3420<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3421<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m3422<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3423<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3424<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3425<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m3426<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m3427<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m3428<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m3429<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m3430<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3431<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3432<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3433<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m3434<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3435<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3436<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3437<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m3438<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3439<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3440<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3441<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m3442<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m3443<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m3444<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m3445<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m3446<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3447<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3448<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3449<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m3450<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3451<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3452<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3453<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m3454<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3455<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3456<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3457<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  +  +  + 1,data=data)
m3458<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m3459<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m3460<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m3461<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m3462<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m3463<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m3464<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m3465<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m3466<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m3467<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m3468<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m3469<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m3470<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m3471<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m3472<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m3473<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m3474<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m3475<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m3476<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m3477<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m3478<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3479<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3480<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3481<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m3482<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3483<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3484<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3485<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m3486<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3487<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3488<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3489<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m3490<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m3491<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m3492<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m3493<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m3494<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3495<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3496<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3497<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m3498<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3499<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3500<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3501<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m3502<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3503<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3504<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3505<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m3506<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m3507<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m3508<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m3509<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m3510<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3511<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3512<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3513<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m3514<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3515<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3516<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3517<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m3518<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3519<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3520<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3521<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  +  +  + 1,data=data)
m3522<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m3523<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m3524<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m3525<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m3526<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m3527<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m3528<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m3529<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m3530<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m3531<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m3532<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m3533<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m3534<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m3535<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m3536<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m3537<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m3538<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m3539<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m3540<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m3541<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m3542<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3543<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3544<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3545<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m3546<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3547<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3548<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3549<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m3550<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3551<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3552<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3553<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m3554<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m3555<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m3556<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m3557<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m3558<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3559<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3560<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3561<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m3562<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3563<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3564<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3565<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m3566<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3567<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3568<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3569<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m3570<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m3571<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m3572<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m3573<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m3574<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3575<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3576<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3577<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m3578<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3579<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3580<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3581<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m3582<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3583<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3584<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3585<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  +  +  + 1,data=data)
m3586<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  +  + transition.win15 + 1,data=data)
m3587<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  +  + transition.win9 + 1,data=data)
m3588<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  +  + transition.win12 + 1,data=data)
m3589<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win4 +  + 1,data=data)
m3590<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m3591<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m3592<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m3593<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win2 +  + 1,data=data)
m3594<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m3595<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m3596<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m3597<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win3 +  + 1,data=data)
m3598<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m3599<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m3600<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m3601<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 +  +  + 1,data=data)
m3602<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m3603<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m3604<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m3605<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m3606<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3607<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3608<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3609<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m3610<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3611<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3612<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3613<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m3614<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3615<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3616<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3617<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 +  +  + 1,data=data)
m3618<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m3619<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m3620<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m3621<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m3622<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3623<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3624<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3625<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m3626<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3627<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3628<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3629<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m3630<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3631<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3632<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3633<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 +  +  + 1,data=data)
m3634<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m3635<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m3636<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m3637<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m3638<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3639<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3640<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3641<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m3642<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3643<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3644<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3645<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m3646<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3647<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3648<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3649<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  +  +  + 1,data=data)
m3650<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m3651<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m3652<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m3653<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m3654<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m3655<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m3656<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m3657<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m3658<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m3659<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m3660<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m3661<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m3662<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m3663<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m3664<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m3665<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m3666<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m3667<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m3668<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m3669<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m3670<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3671<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3672<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3673<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m3674<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3675<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3676<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3677<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m3678<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3679<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3680<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3681<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m3682<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m3683<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m3684<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m3685<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m3686<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3687<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3688<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3689<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m3690<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3691<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3692<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3693<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m3694<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3695<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3696<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3697<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m3698<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m3699<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m3700<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m3701<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m3702<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3703<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3704<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3705<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m3706<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3707<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3708<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3709<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m3710<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3711<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3712<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3713<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  +  +  + 1,data=data)
m3714<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m3715<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m3716<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m3717<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m3718<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m3719<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m3720<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m3721<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m3722<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m3723<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m3724<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m3725<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m3726<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m3727<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m3728<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m3729<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m3730<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m3731<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m3732<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m3733<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m3734<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3735<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3736<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3737<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m3738<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3739<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3740<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3741<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m3742<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3743<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3744<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3745<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m3746<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m3747<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m3748<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m3749<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m3750<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3751<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3752<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3753<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m3754<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3755<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3756<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3757<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m3758<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3759<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3760<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3761<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m3762<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m3763<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m3764<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m3765<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m3766<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3767<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3768<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3769<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m3770<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3771<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3772<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3773<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m3774<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3775<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3776<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3777<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  +  +  + 1,data=data)
m3778<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m3779<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m3780<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m3781<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m3782<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m3783<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m3784<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m3785<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m3786<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m3787<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m3788<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m3789<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m3790<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m3791<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m3792<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m3793<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m3794<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m3795<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m3796<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m3797<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m3798<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3799<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3800<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3801<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m3802<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3803<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3804<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3805<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m3806<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3807<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3808<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3809<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m3810<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m3811<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m3812<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m3813<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m3814<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3815<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3816<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3817<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m3818<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3819<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3820<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3821<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m3822<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3823<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3824<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3825<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m3826<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m3827<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m3828<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m3829<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m3830<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3831<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3832<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3833<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m3834<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3835<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3836<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3837<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m3838<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3839<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3840<-glm.nb(issue.dem.ext1.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3841<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  +  +  + 1,data=data)
m3842<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  +  + transition.win15 + 1,data=data)
m3843<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  +  + transition.win9 + 1,data=data)
m3844<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  +  + transition.win12 + 1,data=data)
m3845<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win4 +  + 1,data=data)
m3846<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m3847<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m3848<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m3849<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win2 +  + 1,data=data)
m3850<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m3851<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m3852<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m3853<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win3 +  + 1,data=data)
m3854<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m3855<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m3856<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m3857<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 +  +  + 1,data=data)
m3858<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m3859<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m3860<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m3861<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m3862<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3863<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3864<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3865<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m3866<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3867<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3868<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3869<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m3870<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3871<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3872<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3873<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 +  +  + 1,data=data)
m3874<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m3875<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m3876<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m3877<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m3878<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3879<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3880<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3881<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m3882<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3883<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3884<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3885<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m3886<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3887<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3888<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3889<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 +  +  + 1,data=data)
m3890<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m3891<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m3892<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m3893<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m3894<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3895<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3896<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3897<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m3898<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3899<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3900<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3901<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m3902<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3903<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3904<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3905<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  +  +  + 1,data=data)
m3906<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m3907<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m3908<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m3909<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m3910<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m3911<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m3912<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m3913<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m3914<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m3915<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m3916<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m3917<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m3918<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m3919<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m3920<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m3921<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m3922<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m3923<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m3924<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m3925<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m3926<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3927<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3928<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3929<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m3930<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3931<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3932<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3933<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m3934<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3935<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m3936<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m3937<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m3938<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m3939<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m3940<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m3941<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m3942<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m3943<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m3944<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m3945<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m3946<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m3947<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m3948<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m3949<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m3950<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m3951<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m3952<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m3953<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m3954<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m3955<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m3956<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m3957<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m3958<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m3959<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m3960<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m3961<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m3962<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m3963<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m3964<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m3965<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m3966<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m3967<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m3968<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m3969<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  +  +  + 1,data=data)
m3970<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m3971<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m3972<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m3973<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m3974<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m3975<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m3976<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m3977<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m3978<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m3979<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m3980<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m3981<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m3982<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m3983<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m3984<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m3985<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m3986<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m3987<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m3988<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m3989<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m3990<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m3991<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m3992<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m3993<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m3994<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m3995<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m3996<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m3997<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m3998<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m3999<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4000<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4001<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m4002<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m4003<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m4004<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m4005<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m4006<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4007<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4008<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4009<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m4010<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4011<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4012<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4013<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m4014<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4015<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4016<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4017<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m4018<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m4019<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m4020<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m4021<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m4022<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4023<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4024<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4025<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m4026<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4027<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4028<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4029<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m4030<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4031<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4032<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4033<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  +  +  + 1,data=data)
m4034<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m4035<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m4036<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m4037<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m4038<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m4039<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m4040<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m4041<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m4042<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m4043<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m4044<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m4045<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m4046<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m4047<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m4048<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m4049<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m4050<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m4051<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m4052<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m4053<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m4054<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4055<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4056<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4057<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m4058<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4059<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4060<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4061<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m4062<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4063<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4064<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4065<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m4066<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m4067<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m4068<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m4069<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m4070<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4071<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4072<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4073<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m4074<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4075<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4076<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4077<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m4078<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4079<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4080<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4081<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m4082<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m4083<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m4084<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m4085<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m4086<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4087<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4088<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4089<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m4090<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4091<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4092<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4093<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m4094<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4095<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4096<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4097<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  +  +  + 1,data=data)
m4098<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  +  + transition.win15 + 1,data=data)
m4099<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  +  + transition.win9 + 1,data=data)
m4100<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  +  + transition.win12 + 1,data=data)
m4101<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win4 +  + 1,data=data)
m4102<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m4103<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m4104<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m4105<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win2 +  + 1,data=data)
m4106<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m4107<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m4108<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m4109<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win3 +  + 1,data=data)
m4110<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m4111<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m4112<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m4113<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 +  +  + 1,data=data)
m4114<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m4115<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m4116<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m4117<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m4118<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4119<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4120<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4121<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m4122<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4123<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4124<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4125<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m4126<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4127<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4128<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4129<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 +  +  + 1,data=data)
m4130<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m4131<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m4132<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m4133<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m4134<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4135<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4136<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4137<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m4138<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4139<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4140<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4141<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m4142<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4143<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4144<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4145<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 +  +  + 1,data=data)
m4146<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m4147<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m4148<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m4149<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m4150<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4151<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4152<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4153<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m4154<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4155<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4156<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4157<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m4158<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4159<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4160<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4161<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  +  +  + 1,data=data)
m4162<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m4163<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m4164<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m4165<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m4166<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m4167<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m4168<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m4169<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m4170<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m4171<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m4172<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m4173<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m4174<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m4175<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m4176<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m4177<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m4178<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m4179<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m4180<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m4181<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m4182<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4183<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4184<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4185<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m4186<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4187<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4188<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4189<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m4190<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4191<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4192<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4193<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m4194<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m4195<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m4196<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m4197<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m4198<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4199<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4200<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4201<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m4202<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4203<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4204<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4205<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m4206<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4207<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4208<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4209<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m4210<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m4211<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m4212<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m4213<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m4214<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4215<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4216<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4217<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m4218<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4219<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4220<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4221<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m4222<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4223<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4224<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4225<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  +  +  + 1,data=data)
m4226<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m4227<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m4228<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m4229<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m4230<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m4231<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m4232<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m4233<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m4234<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m4235<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m4236<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m4237<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m4238<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m4239<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m4240<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m4241<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m4242<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m4243<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m4244<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m4245<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m4246<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4247<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4248<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4249<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m4250<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4251<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4252<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4253<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m4254<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4255<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4256<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4257<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m4258<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m4259<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m4260<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m4261<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m4262<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4263<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4264<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4265<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m4266<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4267<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4268<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4269<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m4270<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4271<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4272<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4273<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m4274<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m4275<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m4276<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m4277<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m4278<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4279<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4280<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4281<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m4282<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4283<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4284<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4285<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m4286<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4287<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4288<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4289<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  +  +  + 1,data=data)
m4290<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m4291<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m4292<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m4293<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m4294<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m4295<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m4296<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m4297<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m4298<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m4299<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m4300<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m4301<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m4302<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m4303<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m4304<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m4305<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m4306<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m4307<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m4308<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m4309<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m4310<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4311<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4312<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4313<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m4314<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4315<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4316<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4317<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m4318<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4319<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4320<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4321<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m4322<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m4323<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m4324<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m4325<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m4326<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4327<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4328<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4329<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m4330<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4331<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4332<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4333<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m4334<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4335<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4336<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4337<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m4338<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m4339<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m4340<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m4341<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m4342<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4343<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4344<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4345<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m4346<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4347<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4348<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4349<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m4350<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4351<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4352<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4353<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  +  +  + 1,data=data)
m4354<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  +  + transition.win15 + 1,data=data)
m4355<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  +  + transition.win9 + 1,data=data)
m4356<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  +  + transition.win12 + 1,data=data)
m4357<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win4 +  + 1,data=data)
m4358<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m4359<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m4360<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m4361<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win2 +  + 1,data=data)
m4362<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m4363<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m4364<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m4365<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win3 +  + 1,data=data)
m4366<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m4367<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m4368<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m4369<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 +  +  + 1,data=data)
m4370<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m4371<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m4372<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m4373<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m4374<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4375<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4376<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4377<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m4378<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4379<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4380<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4381<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m4382<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4383<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4384<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4385<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 +  +  + 1,data=data)
m4386<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m4387<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m4388<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m4389<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m4390<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4391<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4392<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4393<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m4394<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4395<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4396<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4397<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m4398<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4399<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4400<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4401<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 +  +  + 1,data=data)
m4402<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m4403<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m4404<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m4405<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m4406<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4407<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4408<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4409<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m4410<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4411<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4412<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4413<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m4414<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4415<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4416<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4417<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  +  +  + 1,data=data)
m4418<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m4419<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m4420<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m4421<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m4422<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m4423<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m4424<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m4425<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m4426<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m4427<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m4428<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m4429<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m4430<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m4431<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m4432<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m4433<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m4434<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m4435<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m4436<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m4437<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m4438<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4439<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4440<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4441<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m4442<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4443<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4444<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4445<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m4446<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4447<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4448<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4449<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m4450<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m4451<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m4452<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m4453<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m4454<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4455<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4456<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4457<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m4458<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4459<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4460<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4461<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m4462<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4463<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4464<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4465<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m4466<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m4467<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m4468<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m4469<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m4470<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4471<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4472<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4473<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m4474<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4475<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4476<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4477<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m4478<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4479<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4480<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4481<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  +  +  + 1,data=data)
m4482<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m4483<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m4484<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m4485<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m4486<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m4487<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m4488<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m4489<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m4490<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m4491<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m4492<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m4493<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m4494<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m4495<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m4496<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m4497<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m4498<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m4499<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m4500<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m4501<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m4502<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4503<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4504<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4505<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m4506<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4507<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4508<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4509<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m4510<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4511<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4512<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4513<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m4514<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m4515<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m4516<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m4517<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m4518<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4519<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4520<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4521<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m4522<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4523<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4524<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4525<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m4526<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4527<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4528<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4529<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m4530<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m4531<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m4532<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m4533<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m4534<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4535<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4536<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4537<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m4538<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4539<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4540<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4541<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m4542<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4543<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4544<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4545<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  +  +  + 1,data=data)
m4546<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m4547<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m4548<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m4549<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m4550<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m4551<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m4552<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m4553<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m4554<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m4555<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m4556<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m4557<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m4558<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m4559<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m4560<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m4561<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m4562<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m4563<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m4564<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m4565<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m4566<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4567<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4568<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4569<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m4570<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4571<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4572<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4573<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m4574<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4575<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4576<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4577<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m4578<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m4579<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m4580<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m4581<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m4582<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4583<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4584<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4585<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m4586<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4587<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4588<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4589<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m4590<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4591<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4592<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4593<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m4594<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m4595<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m4596<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m4597<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m4598<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4599<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4600<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4601<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m4602<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4603<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4604<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4605<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m4606<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4607<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4608<-glm.nb(issue.dem.ext1.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4609<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  +  +  + 1,data=data)
m4610<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  +  + transition.win15 + 1,data=data)
m4611<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  +  + transition.win9 + 1,data=data)
m4612<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  +  + transition.win12 + 1,data=data)
m4613<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win4 +  + 1,data=data)
m4614<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m4615<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m4616<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m4617<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win2 +  + 1,data=data)
m4618<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m4619<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m4620<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m4621<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win3 +  + 1,data=data)
m4622<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m4623<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m4624<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m4625<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 +  +  + 1,data=data)
m4626<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m4627<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m4628<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m4629<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m4630<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4631<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4632<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4633<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m4634<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4635<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4636<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4637<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m4638<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4639<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4640<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4641<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 +  +  + 1,data=data)
m4642<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m4643<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m4644<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m4645<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m4646<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4647<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4648<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4649<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m4650<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4651<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4652<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4653<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m4654<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4655<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4656<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4657<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 +  +  + 1,data=data)
m4658<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m4659<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m4660<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m4661<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m4662<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4663<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4664<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4665<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m4666<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4667<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4668<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4669<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m4670<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4671<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4672<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4673<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  +  +  + 1,data=data)
m4674<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m4675<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m4676<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m4677<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m4678<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m4679<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m4680<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m4681<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m4682<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m4683<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m4684<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m4685<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m4686<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m4687<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m4688<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m4689<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m4690<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m4691<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m4692<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m4693<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m4694<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4695<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4696<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4697<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m4698<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4699<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4700<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4701<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m4702<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4703<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4704<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4705<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m4706<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m4707<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m4708<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m4709<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m4710<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4711<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4712<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4713<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m4714<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4715<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4716<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4717<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m4718<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4719<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4720<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4721<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m4722<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m4723<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m4724<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m4725<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m4726<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4727<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4728<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4729<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m4730<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4731<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4732<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4733<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m4734<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4735<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4736<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4737<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  +  +  + 1,data=data)
m4738<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m4739<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m4740<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m4741<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m4742<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m4743<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m4744<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m4745<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m4746<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m4747<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m4748<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m4749<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m4750<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m4751<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m4752<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m4753<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m4754<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m4755<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m4756<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m4757<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m4758<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4759<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4760<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4761<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m4762<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4763<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4764<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4765<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m4766<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4767<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4768<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4769<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m4770<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m4771<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m4772<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m4773<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m4774<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4775<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4776<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4777<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m4778<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4779<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4780<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4781<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m4782<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4783<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4784<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4785<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m4786<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m4787<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m4788<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m4789<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m4790<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4791<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4792<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4793<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m4794<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4795<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4796<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4797<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m4798<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4799<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4800<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4801<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  +  +  + 1,data=data)
m4802<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m4803<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m4804<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m4805<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m4806<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m4807<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m4808<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m4809<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m4810<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m4811<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m4812<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m4813<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m4814<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m4815<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m4816<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m4817<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m4818<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m4819<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m4820<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m4821<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m4822<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4823<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4824<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4825<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m4826<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4827<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4828<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4829<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m4830<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4831<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4832<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4833<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m4834<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m4835<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m4836<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m4837<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m4838<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4839<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4840<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4841<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m4842<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4843<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4844<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4845<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m4846<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4847<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4848<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4849<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m4850<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m4851<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m4852<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m4853<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m4854<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4855<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4856<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4857<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m4858<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4859<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4860<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4861<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m4862<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4863<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4864<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4865<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  +  +  + 1,data=data)
m4866<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  +  + transition.win15 + 1,data=data)
m4867<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  +  + transition.win9 + 1,data=data)
m4868<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  +  + transition.win12 + 1,data=data)
m4869<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win4 +  + 1,data=data)
m4870<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m4871<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m4872<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m4873<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win2 +  + 1,data=data)
m4874<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m4875<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m4876<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m4877<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win3 +  + 1,data=data)
m4878<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m4879<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m4880<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m4881<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 +  +  + 1,data=data)
m4882<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m4883<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m4884<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m4885<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m4886<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4887<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4888<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4889<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m4890<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4891<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4892<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4893<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m4894<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4895<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4896<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4897<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 +  +  + 1,data=data)
m4898<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m4899<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m4900<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m4901<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m4902<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4903<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4904<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4905<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m4906<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4907<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4908<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4909<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m4910<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4911<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4912<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4913<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 +  +  + 1,data=data)
m4914<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m4915<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m4916<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m4917<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m4918<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4919<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4920<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4921<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m4922<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4923<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4924<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4925<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m4926<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4927<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4928<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4929<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  +  +  + 1,data=data)
m4930<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m4931<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m4932<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m4933<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m4934<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m4935<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m4936<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m4937<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m4938<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m4939<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m4940<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m4941<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m4942<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m4943<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m4944<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m4945<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m4946<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m4947<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m4948<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m4949<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m4950<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m4951<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m4952<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m4953<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m4954<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m4955<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m4956<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m4957<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m4958<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m4959<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m4960<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m4961<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m4962<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m4963<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m4964<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m4965<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m4966<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m4967<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m4968<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m4969<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m4970<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m4971<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m4972<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m4973<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m4974<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m4975<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m4976<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m4977<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m4978<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m4979<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m4980<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m4981<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m4982<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m4983<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m4984<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m4985<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m4986<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m4987<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m4988<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m4989<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m4990<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m4991<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m4992<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m4993<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  +  +  + 1,data=data)
m4994<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m4995<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m4996<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m4997<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m4998<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m4999<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m5000<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m5001<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m5002<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m5003<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m5004<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m5005<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m5006<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m5007<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m5008<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m5009<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m5010<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m5011<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m5012<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m5013<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m5014<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5015<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5016<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5017<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m5018<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5019<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5020<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5021<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m5022<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5023<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5024<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5025<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m5026<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m5027<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m5028<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m5029<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m5030<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5031<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5032<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5033<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m5034<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5035<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5036<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5037<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m5038<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5039<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5040<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5041<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m5042<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m5043<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m5044<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m5045<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m5046<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5047<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5048<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5049<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m5050<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5051<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5052<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5053<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m5054<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5055<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5056<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5057<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  +  +  + 1,data=data)
m5058<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m5059<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m5060<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m5061<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m5062<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m5063<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m5064<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m5065<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m5066<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m5067<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m5068<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m5069<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m5070<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m5071<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m5072<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m5073<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m5074<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m5075<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m5076<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m5077<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m5078<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5079<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5080<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5081<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m5082<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5083<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5084<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5085<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m5086<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5087<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5088<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5089<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m5090<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m5091<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m5092<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m5093<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m5094<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5095<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5096<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5097<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m5098<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5099<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5100<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5101<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m5102<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5103<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5104<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5105<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m5106<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m5107<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m5108<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m5109<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m5110<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5111<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5112<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5113<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m5114<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5115<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5116<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5117<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m5118<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5119<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5120<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5121<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  +  +  + 1,data=data)
m5122<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  +  + transition.win15 + 1,data=data)
m5123<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  +  + transition.win9 + 1,data=data)
m5124<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  +  + transition.win12 + 1,data=data)
m5125<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win4 +  + 1,data=data)
m5126<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m5127<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m5128<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m5129<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win2 +  + 1,data=data)
m5130<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m5131<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m5132<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m5133<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win3 +  + 1,data=data)
m5134<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m5135<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m5136<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m5137<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 +  +  + 1,data=data)
m5138<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m5139<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m5140<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m5141<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m5142<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5143<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5144<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5145<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m5146<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5147<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5148<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5149<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m5150<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5151<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5152<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5153<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 +  +  + 1,data=data)
m5154<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m5155<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m5156<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m5157<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m5158<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5159<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5160<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5161<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m5162<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5163<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5164<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5165<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m5166<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5167<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5168<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5169<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 +  +  + 1,data=data)
m5170<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m5171<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m5172<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m5173<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m5174<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5175<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5176<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5177<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m5178<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5179<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5180<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5181<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m5182<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5183<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5184<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5185<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  +  +  + 1,data=data)
m5186<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m5187<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m5188<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m5189<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m5190<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m5191<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m5192<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m5193<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m5194<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m5195<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m5196<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m5197<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m5198<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m5199<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m5200<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m5201<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m5202<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m5203<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m5204<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m5205<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m5206<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5207<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5208<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5209<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m5210<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5211<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5212<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5213<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m5214<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5215<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5216<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5217<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m5218<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m5219<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m5220<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m5221<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m5222<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5223<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5224<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5225<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m5226<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5227<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5228<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5229<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m5230<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5231<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5232<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5233<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m5234<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m5235<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m5236<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m5237<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m5238<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5239<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5240<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5241<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m5242<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5243<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5244<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5245<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m5246<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5247<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5248<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5249<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  +  +  + 1,data=data)
m5250<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m5251<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m5252<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m5253<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m5254<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m5255<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m5256<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m5257<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m5258<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m5259<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m5260<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m5261<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m5262<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m5263<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m5264<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m5265<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m5266<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m5267<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m5268<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m5269<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m5270<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5271<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5272<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5273<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m5274<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5275<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5276<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5277<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m5278<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5279<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5280<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5281<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m5282<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m5283<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m5284<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m5285<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m5286<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5287<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5288<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5289<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m5290<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5291<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5292<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5293<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m5294<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5295<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5296<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5297<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m5298<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m5299<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m5300<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m5301<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m5302<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5303<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5304<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5305<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m5306<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5307<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5308<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5309<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m5310<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5311<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5312<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5313<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  +  +  + 1,data=data)
m5314<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m5315<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m5316<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m5317<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m5318<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m5319<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m5320<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m5321<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m5322<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m5323<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m5324<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m5325<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m5326<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m5327<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m5328<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m5329<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m5330<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m5331<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m5332<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m5333<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m5334<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5335<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5336<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5337<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m5338<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5339<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5340<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5341<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m5342<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5343<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5344<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5345<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m5346<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m5347<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m5348<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m5349<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m5350<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5351<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5352<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5353<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m5354<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5355<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5356<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5357<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m5358<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5359<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5360<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5361<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m5362<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m5363<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m5364<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m5365<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m5366<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5367<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5368<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5369<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m5370<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5371<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5372<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5373<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m5374<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5375<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5376<-glm.nb(issue.dem.ext2.det ~ + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5377<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  +  +  + 1,data=data)
m5378<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  +  + transition.win15 + 1,data=data)
m5379<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  +  + transition.win9 + 1,data=data)
m5380<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  +  + transition.win12 + 1,data=data)
m5381<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win4 +  + 1,data=data)
m5382<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m5383<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m5384<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m5385<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win2 +  + 1,data=data)
m5386<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m5387<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m5388<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m5389<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win3 +  + 1,data=data)
m5390<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m5391<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m5392<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m5393<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 +  +  + 1,data=data)
m5394<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m5395<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m5396<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m5397<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m5398<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5399<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5400<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5401<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m5402<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5403<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5404<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5405<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m5406<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5407<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5408<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5409<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 +  +  + 1,data=data)
m5410<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m5411<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m5412<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m5413<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m5414<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5415<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5416<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5417<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m5418<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5419<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5420<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5421<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m5422<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5423<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5424<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5425<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 +  +  + 1,data=data)
m5426<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m5427<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m5428<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m5429<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m5430<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5431<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5432<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5433<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m5434<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5435<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5436<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5437<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m5438<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5439<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5440<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5441<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  +  +  + 1,data=data)
m5442<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m5443<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m5444<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m5445<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m5446<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m5447<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m5448<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m5449<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m5450<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m5451<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m5452<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m5453<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m5454<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m5455<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m5456<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m5457<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m5458<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m5459<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m5460<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m5461<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m5462<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5463<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5464<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5465<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m5466<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5467<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5468<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5469<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m5470<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5471<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5472<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5473<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m5474<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m5475<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m5476<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m5477<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m5478<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5479<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5480<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5481<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m5482<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5483<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5484<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5485<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m5486<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5487<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5488<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5489<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m5490<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m5491<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m5492<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m5493<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m5494<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5495<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5496<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5497<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m5498<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5499<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5500<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5501<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m5502<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5503<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5504<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5505<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  +  +  + 1,data=data)
m5506<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m5507<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m5508<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m5509<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m5510<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m5511<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m5512<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m5513<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m5514<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m5515<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m5516<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m5517<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m5518<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m5519<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m5520<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m5521<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m5522<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m5523<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m5524<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m5525<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m5526<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5527<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5528<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5529<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m5530<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5531<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5532<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5533<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m5534<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5535<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5536<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5537<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m5538<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m5539<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m5540<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m5541<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m5542<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5543<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5544<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5545<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m5546<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5547<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5548<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5549<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m5550<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5551<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5552<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5553<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m5554<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m5555<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m5556<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m5557<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m5558<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5559<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5560<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5561<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m5562<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5563<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5564<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5565<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m5566<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5567<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5568<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5569<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  +  +  + 1,data=data)
m5570<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m5571<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m5572<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m5573<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m5574<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m5575<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m5576<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m5577<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m5578<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m5579<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m5580<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m5581<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m5582<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m5583<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m5584<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m5585<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m5586<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m5587<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m5588<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m5589<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m5590<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5591<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5592<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5593<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m5594<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5595<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5596<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5597<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m5598<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5599<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5600<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5601<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m5602<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m5603<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m5604<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m5605<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m5606<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5607<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5608<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5609<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m5610<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5611<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5612<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5613<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m5614<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5615<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5616<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5617<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m5618<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m5619<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m5620<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m5621<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m5622<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5623<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5624<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5625<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m5626<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5627<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5628<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5629<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m5630<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5631<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5632<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win4.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5633<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  +  +  + 1,data=data)
m5634<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  +  + transition.win15 + 1,data=data)
m5635<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  +  + transition.win9 + 1,data=data)
m5636<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  +  + transition.win12 + 1,data=data)
m5637<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win4 +  + 1,data=data)
m5638<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m5639<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m5640<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m5641<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win2 +  + 1,data=data)
m5642<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m5643<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m5644<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m5645<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win3 +  + 1,data=data)
m5646<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m5647<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m5648<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m5649<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 +  +  + 1,data=data)
m5650<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m5651<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m5652<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m5653<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m5654<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5655<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5656<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5657<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m5658<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5659<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5660<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5661<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m5662<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5663<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5664<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5665<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 +  +  + 1,data=data)
m5666<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m5667<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m5668<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m5669<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m5670<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5671<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5672<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5673<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m5674<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5675<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5676<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5677<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m5678<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5679<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5680<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5681<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 +  +  + 1,data=data)
m5682<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m5683<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m5684<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m5685<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m5686<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5687<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5688<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5689<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m5690<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5691<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5692<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5693<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m5694<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5695<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5696<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5697<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  +  +  + 1,data=data)
m5698<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m5699<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m5700<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m5701<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m5702<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m5703<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m5704<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m5705<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m5706<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m5707<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m5708<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m5709<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m5710<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m5711<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m5712<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m5713<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m5714<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m5715<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m5716<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m5717<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m5718<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5719<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5720<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5721<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m5722<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5723<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5724<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5725<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m5726<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5727<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5728<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5729<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m5730<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m5731<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m5732<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m5733<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m5734<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5735<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5736<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5737<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m5738<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5739<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5740<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5741<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m5742<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5743<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5744<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5745<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m5746<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m5747<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m5748<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m5749<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m5750<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5751<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5752<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5753<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m5754<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5755<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5756<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5757<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m5758<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5759<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5760<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5761<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  +  +  + 1,data=data)
m5762<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m5763<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m5764<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m5765<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m5766<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m5767<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m5768<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m5769<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m5770<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m5771<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m5772<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m5773<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m5774<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m5775<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m5776<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m5777<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m5778<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m5779<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m5780<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m5781<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m5782<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5783<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5784<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5785<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m5786<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5787<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5788<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5789<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m5790<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5791<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5792<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5793<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m5794<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m5795<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m5796<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m5797<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m5798<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5799<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5800<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5801<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m5802<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5803<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5804<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5805<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m5806<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5807<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5808<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5809<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m5810<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m5811<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m5812<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m5813<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m5814<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5815<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5816<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5817<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m5818<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5819<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5820<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5821<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m5822<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5823<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5824<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5825<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  +  +  + 1,data=data)
m5826<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m5827<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m5828<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m5829<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m5830<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m5831<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m5832<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m5833<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m5834<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m5835<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m5836<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m5837<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m5838<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m5839<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m5840<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m5841<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m5842<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m5843<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m5844<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m5845<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m5846<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5847<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5848<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5849<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m5850<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5851<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5852<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5853<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m5854<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5855<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5856<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5857<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m5858<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m5859<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m5860<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m5861<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m5862<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5863<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5864<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5865<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m5866<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5867<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5868<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5869<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m5870<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5871<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5872<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5873<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m5874<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m5875<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m5876<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m5877<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m5878<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5879<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5880<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5881<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m5882<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5883<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5884<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5885<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m5886<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5887<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5888<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win2.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5889<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  +  +  + 1,data=data)
m5890<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  +  + transition.win15 + 1,data=data)
m5891<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  +  + transition.win9 + 1,data=data)
m5892<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  +  + transition.win12 + 1,data=data)
m5893<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win4 +  + 1,data=data)
m5894<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m5895<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m5896<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m5897<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win2 +  + 1,data=data)
m5898<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m5899<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m5900<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m5901<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win3 +  + 1,data=data)
m5902<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m5903<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m5904<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m5905<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 +  +  + 1,data=data)
m5906<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 +  + transition.win15 + 1,data=data)
m5907<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 +  + transition.win9 + 1,data=data)
m5908<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 +  + transition.win12 + 1,data=data)
m5909<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win4 +  + 1,data=data)
m5910<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5911<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5912<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5913<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win2 +  + 1,data=data)
m5914<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5915<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5916<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5917<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win3 +  + 1,data=data)
m5918<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5919<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5920<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5921<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 +  +  + 1,data=data)
m5922<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 +  + transition.win15 + 1,data=data)
m5923<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 +  + transition.win9 + 1,data=data)
m5924<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 +  + transition.win12 + 1,data=data)
m5925<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win4 +  + 1,data=data)
m5926<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5927<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5928<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5929<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win2 +  + 1,data=data)
m5930<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5931<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5932<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5933<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win3 +  + 1,data=data)
m5934<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5935<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m5936<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m5937<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 +  +  + 1,data=data)
m5938<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 +  + transition.win15 + 1,data=data)
m5939<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 +  + transition.win9 + 1,data=data)
m5940<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 +  + transition.win12 + 1,data=data)
m5941<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win4 +  + 1,data=data)
m5942<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m5943<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m5944<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m5945<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win2 +  + 1,data=data)
m5946<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m5947<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m5948<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m5949<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win3 +  + 1,data=data)
m5950<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m5951<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m5952<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt +  + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m5953<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  +  +  + 1,data=data)
m5954<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m5955<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m5956<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m5957<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m5958<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m5959<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m5960<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m5961<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m5962<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m5963<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m5964<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m5965<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m5966<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m5967<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m5968<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m5969<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 +  +  + 1,data=data)
m5970<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win15 + 1,data=data)
m5971<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win9 + 1,data=data)
m5972<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 +  + transition.win12 + 1,data=data)
m5973<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 +  + 1,data=data)
m5974<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m5975<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m5976<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m5977<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 +  + 1,data=data)
m5978<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m5979<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m5980<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m5981<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 +  + 1,data=data)
m5982<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m5983<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m5984<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m5985<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 +  +  + 1,data=data)
m5986<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win15 + 1,data=data)
m5987<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win9 + 1,data=data)
m5988<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 +  + transition.win12 + 1,data=data)
m5989<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 +  + 1,data=data)
m5990<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m5991<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m5992<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m5993<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 +  + 1,data=data)
m5994<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m5995<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m5996<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m5997<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 +  + 1,data=data)
m5998<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m5999<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m6000<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m6001<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 +  +  + 1,data=data)
m6002<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win15 + 1,data=data)
m6003<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win9 + 1,data=data)
m6004<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 +  + transition.win12 + 1,data=data)
m6005<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 +  + 1,data=data)
m6006<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m6007<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m6008<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m6009<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 +  + 1,data=data)
m6010<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m6011<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m6012<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m6013<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 +  + 1,data=data)
m6014<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m6015<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m6016<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win4 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m6017<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  +  +  + 1,data=data)
m6018<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m6019<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m6020<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m6021<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m6022<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m6023<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m6024<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m6025<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m6026<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m6027<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m6028<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m6029<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m6030<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m6031<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m6032<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m6033<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 +  +  + 1,data=data)
m6034<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win15 + 1,data=data)
m6035<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win9 + 1,data=data)
m6036<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 +  + transition.win12 + 1,data=data)
m6037<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 +  + 1,data=data)
m6038<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m6039<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m6040<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m6041<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 +  + 1,data=data)
m6042<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m6043<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m6044<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m6045<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 +  + 1,data=data)
m6046<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m6047<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m6048<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m6049<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 +  +  + 1,data=data)
m6050<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win15 + 1,data=data)
m6051<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win9 + 1,data=data)
m6052<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 +  + transition.win12 + 1,data=data)
m6053<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 +  + 1,data=data)
m6054<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m6055<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m6056<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m6057<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 +  + 1,data=data)
m6058<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m6059<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m6060<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m6061<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 +  + 1,data=data)
m6062<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m6063<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m6064<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m6065<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 +  +  + 1,data=data)
m6066<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win15 + 1,data=data)
m6067<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win9 + 1,data=data)
m6068<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 +  + transition.win12 + 1,data=data)
m6069<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 +  + 1,data=data)
m6070<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m6071<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m6072<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m6073<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 +  + 1,data=data)
m6074<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m6075<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m6076<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m6077<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 +  + 1,data=data)
m6078<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m6079<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m6080<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win2 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)
m6081<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  +  +  + 1,data=data)
m6082<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m6083<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m6084<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m6085<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m6086<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m6087<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m6088<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m6089<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m6090<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m6091<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m6092<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m6093<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m6094<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m6095<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m6096<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m6097<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 +  +  + 1,data=data)
m6098<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win15 + 1,data=data)
m6099<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win9 + 1,data=data)
m6100<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 +  + transition.win12 + 1,data=data)
m6101<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 +  + 1,data=data)
m6102<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win15 + 1,data=data)
m6103<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win9 + 1,data=data)
m6104<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win4 + transition.win12 + 1,data=data)
m6105<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 +  + 1,data=data)
m6106<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win15 + 1,data=data)
m6107<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win9 + 1,data=data)
m6108<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win2 + transition.win12 + 1,data=data)
m6109<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 +  + 1,data=data)
m6110<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win15 + 1,data=data)
m6111<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win9 + 1,data=data)
m6112<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win4 + extmob.win3 + transition.win12 + 1,data=data)
m6113<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 +  +  + 1,data=data)
m6114<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win15 + 1,data=data)
m6115<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win9 + 1,data=data)
m6116<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 +  + transition.win12 + 1,data=data)
m6117<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 +  + 1,data=data)
m6118<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win15 + 1,data=data)
m6119<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win9 + 1,data=data)
m6120<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win4 + transition.win12 + 1,data=data)
m6121<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 +  + 1,data=data)
m6122<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win15 + 1,data=data)
m6123<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win9 + 1,data=data)
m6124<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win2 + transition.win12 + 1,data=data)
m6125<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 +  + 1,data=data)
m6126<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win15 + 1,data=data)
m6127<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win9 + 1,data=data)
m6128<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win2 + extmob.win3 + transition.win12 + 1,data=data)
m6129<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 +  +  + 1,data=data)
m6130<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win15 + 1,data=data)
m6131<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win9 + 1,data=data)
m6132<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 +  + transition.win12 + 1,data=data)
m6133<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 +  + 1,data=data)
m6134<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win15 + 1,data=data)
m6135<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win9 + 1,data=data)
m6136<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win4 + transition.win12 + 1,data=data)
m6137<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 +  + 1,data=data)
m6138<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win15 + 1,data=data)
m6139<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win9 + 1,data=data)
m6140<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win2 + transition.win12 + 1,data=data)
m6141<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 +  + 1,data=data)
m6142<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win15 + 1,data=data)
m6143<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win9 + 1,data=data)
m6144<-glm.nb(issue.dem.ext2.det ~t+t^2+t^3 + focal.gen.win3.alt + division.win3 + shock.win3 + extmob.win3 + transition.win12 + 1,data=data)

for (j in 1:6144) {
  
  try(eval(parse(text=paste("tlr.models$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4.alt',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2.alt',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3.alt',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$shock.win.coeff[",j,"]<-summary(m",j,")$coefficients['shock.win4',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.se[",j,"]<-summary(m",j,")$coefficients['shock.win4',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.z[",j,"]<-summary(m",j,")$coefficients['shock.win4',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.p[",j,"]<-summary(m",j,")$coefficients['shock.win4',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$shock.win.coeff[",j,"]<-summary(m",j,")$coefficients['shock.win2',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.se[",j,"]<-summary(m",j,")$coefficients['shock.win2',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.z[",j,"]<-summary(m",j,")$coefficients['shock.win2',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.p[",j,"]<-summary(m",j,")$coefficients['shock.win2',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models$shock.win.coeff[",j,"]<-summary(m",j,")$coefficients['shock.win3',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.se[",j,"]<-summary(m",j,")$coefficients['shock.win3',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.z[",j,"]<-summary(m",j,")$coefficients['shock.win3',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$shock.win.p[",j,"]<-summary(m",j,")$coefficients['shock.win3',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$extmob.win.coeff[",j,"]<-summary(m",j,")$coefficients['extmob.win4',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.se[",j,"]<-summary(m",j,")$coefficients['extmob.win4',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.z[",j,"]<-summary(m",j,")$coefficients['extmob.win4',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.p[",j,"]<-summary(m",j,")$coefficients['extmob.win4',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$extmob.win.coeff[",j,"]<-summary(m",j,")$coefficients['extmob.win2',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.se[",j,"]<-summary(m",j,")$coefficients['extmob.win2',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.z[",j,"]<-summary(m",j,")$coefficients['extmob.win2',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.p[",j,"]<-summary(m",j,")$coefficients['extmob.win2',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models$extmob.win.coeff[",j,"]<-summary(m",j,")$coefficients['extmob.win3',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.se[",j,"]<-summary(m",j,")$coefficients['extmob.win3',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.z[",j,"]<-summary(m",j,")$coefficients['extmob.win3',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$extmob.win.p[",j,"]<-summary(m",j,")$coefficients['extmob.win3',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$division.win.coeff[",j,"]<-summary(m",j,")$coefficients['division.win4',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.se[",j,"]<-summary(m",j,")$coefficients['division.win4',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.z[",j,"]<-summary(m",j,")$coefficients['division.win4',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.p[",j,"]<-summary(m",j,")$coefficients['division.win4',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$division.win.coeff[",j,"]<-summary(m",j,")$coefficients['division.win2',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.se[",j,"]<-summary(m",j,")$coefficients['division.win2',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.z[",j,"]<-summary(m",j,")$coefficients['division.win2',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.p[",j,"]<-summary(m",j,")$coefficients['division.win2',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models$division.win.coeff[",j,"]<-summary(m",j,")$coefficients['division.win3',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.se[",j,"]<-summary(m",j,")$coefficients['division.win3',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.z[",j,"]<-summary(m",j,")$coefficients['division.win3',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$division.win.p[",j,"]<-summary(m",j,")$coefficients['division.win3',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$transition.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.win15',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.se[",j,"]<-summary(m",j,")$coefficients['transition.win15',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.z[",j,"]<-summary(m",j,")$coefficients['transition.win15',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.p[",j,"]<-summary(m",j,")$coefficients['transition.win15',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models$transition.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.win9',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.se[",j,"]<-summary(m",j,")$coefficients['transition.win9',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.z[",j,"]<-summary(m",j,")$coefficients['transition.win9',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.p[",j,"]<-summary(m",j,")$coefficients['transition.win9',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models$transition.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.win12',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.se[",j,"]<-summary(m",j,")$coefficients['transition.win12',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.z[",j,"]<-summary(m",j,")$coefficients['transition.win12',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models$transition.win.p[",j,"]<-summary(m",j,")$coefficients['transition.win12',4]",sep=""))))      
  
  try(eval(parse(text=paste("tlr.models$aic[",j,"]<-summary(m",j,")$aic",sep=""))))      
}

write.csv(tlr.models,"tlr.models.output.csv")

tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen.win.coeff>0]<-tlr.models$focal.gen.win.p/2
tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen.win.coeff<0]<-1-(tlr.models$focal.gen.win.p/2)

pdf('fig3-robustness.pdf', width=10, height=5.5)  #Delete figure from replication file
par(mfcol=c(1,2))
plot(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win3" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win3" & tlr.models$dv=="issue.dem.ext1.det"], col="grey85", main="Democratic (dem.det)",xlim=c(0,.055),ylim=c(.6,1.8),pch=16,cex=.3,xlab="p-value",ylab="Coefficient Estimate of Focal Events (focal)")
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win4" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win4" & tlr.models$dv=="issue.dem.ext1.det"], col="firebrick2", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win2" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2" & tlr.models$dv=="issue.dem.ext1.det"], col="dodgerblue3", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win3.alt" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext1.det"], col="grey65", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win4.alt" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win4.alt" & tlr.models$dv=="issue.dem.ext1.det"], col="firebrick4", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext1.det"], col="dodgerblue4", pch=16, cex=.3)
abline(v=.1,lty=3,lwd=1)
abline(v=.05,lty=3,lwd=1)
abline(v=.01,lty=3,lwd=1)
points(0.00163,  0.8650, pch=17,col="grey40",lwd=2,cex=1.25)
points(1.09e-06,  1.35101, pch=17,col="grey40",lwd=2,cex=1.25)
points(1.09e-05,  1.098, pch=17,col="grey40",lwd=2,cex=1.25)
points(1.66e-06,  1.1134353, pch=1,col="black",lwd=1.5,cex=1.25)
legend("topright",c("Window = 4 Months","Window = 3 Months","Window = 2 Months","Window = 4 Months (focal excl)","Window = 3 Months (focal excl)","Window = 2 Months (focal excl)", "Estimate from Table 1", "Minimum AIC Estimate"),pch=c(16,16,16,16,16,16,17,1), col=c("firebrick2","grey85","dodgerblue3","firebrick4","grey65","dodgerblue4","grey40","black"), box.lwd=0, cex=.85, bty="n")
plot(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win3" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win3" & tlr.models$dv=="issue.dem.ext2.det"], col="grey85", main="Democratic (dem.det.ext)",xlim=c(0,.055),ylim=c(.3,.8),pch=16,cex=.3,xlab="p-value",ylab="Coefficient Estimate of Focal Events (focal)")
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win4" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win4" & tlr.models$dv=="issue.dem.ext2.det"], col="firebrick2", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win2" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2" & tlr.models$dv=="issue.dem.ext2.det"], col="dodgerblue3", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win3.alt" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext2.det"], col="grey65", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win4.alt" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win4.alt" & tlr.models$dv=="issue.dem.ext2.det"], col="firebrick4", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext2.det"], col="dodgerblue4", pch=16, cex=.3)
abline(v=.1,lty=3,lwd=1)
abline(v=.05,lty=3,lwd=1)
abline(v=.01,lty=3,lwd=1)
points(0.00625, 0.43619, pch=17,col="grey40",lwd=2,cex=1.25)
points(0.000217,  0.5950 , pch=17,col="grey40",lwd=2,cex=1.25)
points(0.000891,  4.763e-01, pch=17,col="grey40",lwd=2,cex=1.25)
points(0.000113753,  0.500248256, pch=1,col="black",lwd=1.5,cex=1.25)
legend("topright",c("Window = 4 Months","Window = 3 Months","Window = 2 Months","Window = 4 Months (focal excl)","Window = 3 Months (focal excl)","Window = 2 Months (focal excl)", "Estimate from Table 1", "Minimum AIC Estimate"),pch=c(16,16,16,16,16,16,17,1), col=c("firebrick2","grey85","dodgerblue3","firebrick4","grey65","dodgerblue4","grey40","black"), box.lwd=0, cex=.85, bty="n")
dev.off()

#Figure 3a and A3b: Predicting Democratic Dissident Detentions in China# 

predicted.values<-data.frame(data$t,data$t2,data$t3,data$extmob.win4,data$focal.gen.win4,data$division.win3)
colnames(predicted.values)<-c("t","t2","t3","extmob.win4","focal.gen.win4","division.win3")
predicted.values$issue.dem.ext1.det.predicted.m965 <- predict(m965, predicted.values, type = "response")

predicted.values.nofocal.gen <- predicted.values
predicted.values.nofocal.gen$focal.gen.win4<-0
predicted.values.nofocal.gen$issue.dem.ext1.det.predicted.m965 <- predict(m965, predicted.values.nofocal.gen, type = "response")

predicted.values.noextmob <- predicted.values
predicted.values.noextmob$extmob.win4<-0
predicted.values.noextmob$issue.dem.ext1.det.predicted.m965 <- predict(m965, predicted.values.noextmob, type = "response")

predicted.values.noextmob.nofocal.gen <- predicted.values
predicted.values.noextmob.nofocal.gen$extmob.win4<-0
predicted.values.noextmob.nofocal.gen$focal.gen.win4<-0
predicted.values.noextmob.nofocal.gen$issue.dem.ext1.det.predicted.m965 <- predict(m965, predicted.values.noextmob.nofocal.gen, type = "response")

predicted.issue.dem.ext1.det<-sum(predicted.values$issue.dem.ext1.det.predicted.m965)
predicted.nofocal.gen.issue.dem.ext1.det<-sum(predicted.values.nofocal.gen$issue.dem.ext1.det.predicted.m965)
predicted.noextmob.issue.dem.ext1.det<-sum(predicted.values.noextmob$issue.dem.ext1.det.predicted.m965)
predicted.noextmob.nofocal.gen.issue.dem.ext1.det<-sum(predicted.values.noextmob.nofocal.gen$issue.dem.ext1.det.predicted.m965)
true.issue.dem.ext1.det<-sum(data$issue.dem.ext1.det)

pdf('fig4a-fiteffect-demdetext1.pdf', width=10, height=7.5)
years<-c("1998","1999","2000","2001","2002","2003","2004","2005","2006","2007","2008","2009","2010","2011","2012","2013","2014","2015")
t<-c(1,13,25,37,49,61,73,85,97,109,121,133,145,157,169,181,193,205)
par(mfcol=c(1,1))
par(cex.axis=1.15)
par(cex.lab=1.15)
par(cex.main=1.15)
plot(data$t,data$issue.dem.ext1.det,type="l",xaxt="n", lty=1, lwd=1.5, col="grey40", main="Democratic Dissident Detentions (dem.det)", ylim=c(-.5,10),ylab="Count", xlab="")
axis(1, at=t, labels=years, las=2, cex=.6)
lines(predicted.values$t,predicted.values$issue.dem.ext1.det.predicted.m965,  lty=5, lwd=2, col="firebrick2")
#lines(predicted.values.noextmob.nofocal.gen$t,predicted.values.noextmob.nofocal.gen$issue.dem.ext1.det.predicted.m783,  lty=3, lwd=3.5, col="blue")
legend("topleft",c("Actual Detentions","Predicted Detentions"),lwd=c(1.5,2), lty = c(1,5), col=c("grey40","firebrick2"), box.lwd=0, cex=.85, bty="n")
points(18, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(22, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(59, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(63, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(78, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(118, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(128, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(138, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(142, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(156, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(155, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(179, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(183, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(198, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
text(18, -.65, "T", pch=17,lwd=4,cex=.85)
text(78, -.65, "T", pch=17,lwd=4,cex=.85)
text(138, -.65, "T", pch=17,lwd=4,cex=.85)
text(198, -.65, "T", pch=17,lwd=4,cex=.85)
points(.5, 9.1, col = "grey70", pch=17,lwd=4,cex=1.25)
text(16.5,9.1,"Focal Event", cex=.85)
text(.5,8.775,"T", cex=.85)
text(24.25,8.75,"Tiananmen Anniversary", cex=.85)
text(22, -.65, "F", pch=17,lwd=4,cex=.85)
text(142, -.65, "F", pch=17,lwd=4,cex=.85)
text(.5,8.475,"F", cex=.85)
text(27.5,8.45,"PRC Founding Anniversary", cex=.85)
text(59, -.65, "M", pch=17,lwd=4,cex=.85)
text(63, -.65, "M", pch=17,lwd=4,cex=.85)
text(118, -.65, "M", pch=17,lwd=4,cex=.85)
text(179, -.65, "M", pch=17,lwd=4,cex=.85)
text(183, -.65, "M", pch=17,lwd=4,cex=.85)
text(.5,8.175,"M", cex=.85)
text(30.50,8.15,"Key CCP/Government Meeting", cex=.85)
text(128, -.65, "1", pch=17,lwd=4,cex=.85)
text(.5,7.875,"1", cex=.85)
text(19.75,7.85,"Beijing Olympics", cex=.85)
text(156, -.65, "2", pch=17,lwd=4,cex=.85)
text(.5,7.5575,"2", cex=.85)
text(37,7.55,"Liu Xiaobo Awarded Nobel Peace Prize", cex=.85)
dev.off()

predicted.values<-data.frame(data$t,data$t2,data$t3,data$extmob.win3,data$focal.gen.win4,data$division.win4)
colnames(predicted.values)<-c("t","t2","t3","extmob.win3","focal.gen.win4","division.win4")
predicted.values$issue.dem.ext2.det.predicted.m2381 <- predict(m2381, predicted.values, type = "response")

predicted.values.nofocal.gen <- predicted.values
predicted.values.nofocal.gen$focal.gen.win4<-0
predicted.values.nofocal.gen$issue.dem.ext2.det.predicted.m2381 <- predict(m2381, predicted.values.nofocal.gen, type = "response")

predicted.values.noextmob <- predicted.values
predicted.values.noextmob$extmob.win3<-0
predicted.values.noextmob$issue.dem.ext2.det.predicted.m2381 <- predict(m2381, predicted.values.noextmob, type = "response")

predicted.values.noextmob.nofocal.gen <- predicted.values
predicted.values.noextmob.nofocal.gen$extmob.win3<-0
predicted.values.noextmob.nofocal.gen$focal.gen.win4<-0
predicted.values.noextmob.nofocal.gen$issue.dem.ext2.det.predicted.m2381 <- predict(m2381, predicted.values.noextmob.nofocal.gen, type = "response")

predicted.issue.dem.ext2.det<-sum(predicted.values$issue.dem.ext2.det.predicted.m2381)
predicted.nofocal.gen.issue.dem.ext2.det<-sum(predicted.values.nofocal.gen$issue.dem.ext2.det.predicted.m2381)
predicted.noextmob.issue.dem.ext2.det<-sum(predicted.values.noextmob$issue.dem.ext2.det.predicted.m2381)
predicted.noextmob.nofocal.gen.issue.dem.ext2.det<-sum(predicted.values.noextmob.nofocal.gen$issue.dem.ext2.det.predicted.m2381)
true.issue.dem.ext2.det<-sum(data$issue.dem.ext2.det)

pdf('fig4b-fiteffect-demdetext2.pdf', width=10, height=7.5)
years<-c("1998","1999","2000","2001","2002","2003","2004","2005","2006","2007","2008","2009","2010","2011","2012","2013","2014","2015")
t<-c(1,13,25,37,49,61,73,85,97,109,121,133,145,157,169,181,193,205)
par(mfcol=c(1,1))
par(cex.axis=1.15)
par(cex.lab=1.15)
par(cex.main=1.15)
plot(data$t,data$issue.dem.ext2.det,type="l",xaxt="n", lty=1, lwd=1.5, col="grey40", main="Democratic Dissident Detentions (dem.det.ext)", ylim=c(-.5,30),ylab="Count", xlab="")
axis(1, at=t, labels=years, las=2, cex=.6)
lines(predicted.values$t,predicted.values$issue.dem.ext2.det.predicted.m2381,  lty=5, lwd=2, col="firebrick2")
#lines(predicted.values.noextmob.nofocal.gen$t,predicted.values.noextmob.nofocal.gen$issue.dem.ext2.det.predicted.m2381,  lty=3, lwd=3.5, col="blue")
legend("topleft",c("Actual Detentions","Predicted Detentions"),lwd=c(1.5,2), lty = c(1,5), col=c("grey40","firebrick2","dodgerblue3"), box.lwd=0, cex=.85, bty="n")
points(18, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(22, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(59, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(63, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(78, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(118, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(128, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(138, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(142, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(156, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(155, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(179, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(183, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
points(198, -.35, col = "grey70", pch=17,lwd=4,cex=1.25)
text(18, -1, "T", pch=17,lwd=4,cex=.85)
text(78, -1, "T", pch=17,lwd=4,cex=.85)
text(138, -1, "T", pch=17,lwd=4,cex=.85)
text(198, -1, "T", pch=17,lwd=4,cex=.85)
points(.5, 27.2, col = "grey70", pch=17,lwd=4,cex=1.25)
text(16,27.2,"Focal Event", cex=.85)
text(.5,26.5,"T", cex=.85)
text(24.25,26.5,"Tiananmen Anniversary", cex=.85)
text(22, -1, "F", pch=17,lwd=4,cex=.85)
text(142, -1, "F", pch=17,lwd=4,cex=.85)
text(.5,25.8,"F", cex=.85)
text(27.5,25.8,"PRC Founding Anniversary", cex=.85)
text(59, -1, "M", pch=17,lwd=4,cex=.85)
text(63, -1, "M", pch=17,lwd=4,cex=.85)
text(118, -1, "M", pch=17,lwd=4,cex=.85)
text(179, -1, "M", pch=17,lwd=4,cex=.85)
text(183, -1, "M", pch=17,lwd=4,cex=.85)
text(.5,25.1,"M", cex=.85)
text(30.50,25.1,"Key CCP/Government Meeting", cex=.85)
text(128, -1, "1", pch=17,lwd=4,cex=.85)
text(.5,24.4,"1", cex=.85)
text(19.75,24.4,"Beijing Olympics", cex=.85)
text(156, -1, "2", pch=17,lwd=4,cex=.85)
text(.5,23.7,"2", cex=.85)
text(37,23.7,"Liu Xiaobo Awarded Nobel Peace Prize", cex=.85)
dev.off()

####ANALYSIS - TIBET DETENTIONS####

#Core Models#
c1<-glm.nb(issue.ethtib.det~focal.tib.win3, data=data)
c2<-glm.nb(issue.ethtib.det~focal.tib.win3 + extmob.win3+ transition.tib.win12, data=data)
c3<-glm.nb(issue.ethtib.det~focal.tib.win3 + extmob.win3+ transition.tib.win12 + t + t2 + t3, data=data)
c4<-glm.nb(issue.ethtib.det~focal.tib.win3 + focal.gen.win3 + extmob.win3  + transition.win12 + transition.tib.win12 + t + t2 + t3, data=data)

#Sensitivity Analysis / Identifying Model of Best Fit#

tlr.models.tib <- read.csv("tlr.models.tib.csv")

m1 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  +  +  + 1,data=data)
m2 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  +  + transition.win15 + 1,data=data)
m3 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  +  + transition.win9 + 1,data=data)
m4 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  +  + transition.win12 + 1,data=data)
m5 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win4 +  + 1,data=data)
m6 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m7 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m8 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m9 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win2 +  + 1,data=data)
m10 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m11 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m12 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m13 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win3 +  + 1,data=data)
m14 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m15 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m16 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m17 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 +  +  + 1,data=data)
m18 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 +  + transition.win15 + 1,data=data)
m19 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 +  + transition.win9 + 1,data=data)
m20 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 +  + transition.win12 + 1,data=data)
m21 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m22 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m23 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m24 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m25 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m26 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m27 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m28 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m29 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m30 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m31 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m32 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m33 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 +  +  + 1,data=data)
m34 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 +  + transition.win15 + 1,data=data)
m35 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 +  + transition.win9 + 1,data=data)
m36 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 +  + transition.win12 + 1,data=data)
m37 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m38 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m39 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m40 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m41 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m42 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m43 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m44 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m45 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m46 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m47 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m48 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m49 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 +  +  + 1,data=data)
m50 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 +  + transition.win15 + 1,data=data)
m51 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 +  + transition.win9 + 1,data=data)
m52 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 +  + transition.win12 + 1,data=data)
m53 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m54 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m55 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m56 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m57 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m58 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m59 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m60 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m61 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m62 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m63 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m64 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 +  + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m65 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  +  +  + 1,data=data)
m66 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  +  + transition.win15 + 1,data=data)
m67 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  +  + transition.win9 + 1,data=data)
m68 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  +  + transition.win12 + 1,data=data)
m69 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win4 +  + 1,data=data)
m70 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win4 + transition.win15 + 1,data=data)
m71 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win4 + transition.win9 + 1,data=data)
m72 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win4 + transition.win12 + 1,data=data)
m73 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win2 +  + 1,data=data)
m74 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win2 + transition.win15 + 1,data=data)
m75 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win2 + transition.win9 + 1,data=data)
m76 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win2 + transition.win12 + 1,data=data)
m77 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win3 +  + 1,data=data)
m78 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win3 + transition.win15 + 1,data=data)
m79 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win3 + transition.win9 + 1,data=data)
m80 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 +  + extmob.win3 + transition.win12 + 1,data=data)
m81 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 +  +  + 1,data=data)
m82 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m83 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m84 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m85 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m86 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m87 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m88 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m89 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m90 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m91 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m92 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m93 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m94 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m95 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m96 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m97 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 +  +  + 1,data=data)
m98 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m99 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m100 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m101 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m102 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m103 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m104 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m105 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m106 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m107 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m108 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m109 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m110 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m111 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m112 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m113 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 +  +  + 1,data=data)
m114 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m115 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m116 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m117 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m118 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m119 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m120 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m121 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m122 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m123 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m124 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m125 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m126 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m127 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m128 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m129 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  +  +  + 1,data=data)
m130 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  +  + transition.win15 + 1,data=data)
m131 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  +  + transition.win9 + 1,data=data)
m132 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  +  + transition.win12 + 1,data=data)
m133 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win4 +  + 1,data=data)
m134 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win4 + transition.win15 + 1,data=data)
m135 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win4 + transition.win9 + 1,data=data)
m136 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win4 + transition.win12 + 1,data=data)
m137 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win2 +  + 1,data=data)
m138 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win2 + transition.win15 + 1,data=data)
m139 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win2 + transition.win9 + 1,data=data)
m140 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win2 + transition.win12 + 1,data=data)
m141 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win3 +  + 1,data=data)
m142 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win3 + transition.win15 + 1,data=data)
m143 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win3 + transition.win9 + 1,data=data)
m144 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 +  + extmob.win3 + transition.win12 + 1,data=data)
m145 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 +  +  + 1,data=data)
m146 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m147 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m148 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m149 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m150 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m151 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m152 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m153 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m154 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m155 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m156 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m157 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m158 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m159 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m160 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m161 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 +  +  + 1,data=data)
m162 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m163 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m164 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m165 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m166 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m167 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m168 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m169 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m170 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m171 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m172 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m173 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m174 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m175 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m176 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m177 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 +  +  + 1,data=data)
m178 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m179 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m180 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m181 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m182 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m183 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m184 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m185 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m186 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m187 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m188 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m189 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m190 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m191 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m192 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m193 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  +  +  + 1,data=data)
m194 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  +  + transition.win15 + 1,data=data)
m195 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  +  + transition.win9 + 1,data=data)
m196 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  +  + transition.win12 + 1,data=data)
m197 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win4 +  + 1,data=data)
m198 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win4 + transition.win15 + 1,data=data)
m199 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win4 + transition.win9 + 1,data=data)
m200 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win4 + transition.win12 + 1,data=data)
m201 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 +  + 1,data=data)
m202 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 + transition.win15 + 1,data=data)
m203 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 + transition.win9 + 1,data=data)
m204 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 + transition.win12 + 1,data=data)
m205 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win3 +  + 1,data=data)
m206 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win3 + transition.win15 + 1,data=data)
m207 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win3 + transition.win9 + 1,data=data)
m208 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 +  + extmob.win3 + transition.win12 + 1,data=data)
m209 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 +  +  + 1,data=data)
m210 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m211 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m212 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m213 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m214 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m215 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m216 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m217 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m218 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m219 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m220 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m221 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m222 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m223 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m224 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m225 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 +  +  + 1,data=data)
m226 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m227 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m228 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m229 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m230 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m231 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m232 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m233 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m234 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m235 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m236 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m237 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m238 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m239 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m240 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m241 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 +  +  + 1,data=data)
m242 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m243 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m244 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m245 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m246 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m247 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m248 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m249 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m250 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m251 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m252 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m253 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m254 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m255 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m256 <-glm.nb(issue.ethtib.det ~ + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m257 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  +  +  + 1,data=data)
m258 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  +  + transition.win15 + 1,data=data)
m259 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  +  + transition.win9 + 1,data=data)
m260 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  +  + transition.win12 + 1,data=data)
m261 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win4 +  + 1,data=data)
m262 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m263 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m264 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m265 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win2 +  + 1,data=data)
m266 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m267 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m268 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m269 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win3 +  + 1,data=data)
m270 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m271 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m272 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m273 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 +  +  + 1,data=data)
m274 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 +  + transition.win15 + 1,data=data)
m275 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 +  + transition.win9 + 1,data=data)
m276 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 +  + transition.win12 + 1,data=data)
m277 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m278 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m279 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m280 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m281 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m282 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m283 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m284 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m285 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m286 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m287 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m288 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m289 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 +  +  + 1,data=data)
m290 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 +  + transition.win15 + 1,data=data)
m291 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 +  + transition.win9 + 1,data=data)
m292 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 +  + transition.win12 + 1,data=data)
m293 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m294 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m295 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m296 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m297 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m298 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m299 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m300 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m301 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m302 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m303 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m304 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m305 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 +  +  + 1,data=data)
m306 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 +  + transition.win15 + 1,data=data)
m307 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 +  + transition.win9 + 1,data=data)
m308 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 +  + transition.win12 + 1,data=data)
m309 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m310 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m311 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m312 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m313 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m314 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m315 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m316 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m317 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m318 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m319 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m320 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 +  + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m321 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  +  +  + 1,data=data)
m322 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  +  + transition.win15 + 1,data=data)
m323 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  +  + transition.win9 + 1,data=data)
m324 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  +  + transition.win12 + 1,data=data)
m325 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win4 +  + 1,data=data)
m326 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win4 + transition.win15 + 1,data=data)
m327 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win4 + transition.win9 + 1,data=data)
m328 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win4 + transition.win12 + 1,data=data)
m329 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win2 +  + 1,data=data)
m330 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win2 + transition.win15 + 1,data=data)
m331 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win2 + transition.win9 + 1,data=data)
m332 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win2 + transition.win12 + 1,data=data)
m333 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win3 +  + 1,data=data)
m334 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win3 + transition.win15 + 1,data=data)
m335 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win3 + transition.win9 + 1,data=data)
m336 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 +  + extmob.win3 + transition.win12 + 1,data=data)
m337 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 +  +  + 1,data=data)
m338 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m339 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m340 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m341 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m342 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m343 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m344 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m345 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m346 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m347 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m348 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m349 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m350 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m351 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m352 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m353 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 +  +  + 1,data=data)
m354 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m355 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m356 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m357 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m358 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m359 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m360 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m361 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m362 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m363 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m364 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m365 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m366 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m367 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m368 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m369 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 +  +  + 1,data=data)
m370 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m371 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m372 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m373 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m374 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m375 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m376 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m377 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m378 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m379 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m380 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m381 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m382 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m383 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m384 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m385 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  +  +  + 1,data=data)
m386 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  +  + transition.win15 + 1,data=data)
m387 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  +  + transition.win9 + 1,data=data)
m388 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  +  + transition.win12 + 1,data=data)
m389 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win4 +  + 1,data=data)
m390 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win4 + transition.win15 + 1,data=data)
m391 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win4 + transition.win9 + 1,data=data)
m392 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win4 + transition.win12 + 1,data=data)
m393 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win2 +  + 1,data=data)
m394 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win2 + transition.win15 + 1,data=data)
m395 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win2 + transition.win9 + 1,data=data)
m396 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win2 + transition.win12 + 1,data=data)
m397 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win3 +  + 1,data=data)
m398 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win3 + transition.win15 + 1,data=data)
m399 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win3 + transition.win9 + 1,data=data)
m400 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 +  + extmob.win3 + transition.win12 + 1,data=data)
m401 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 +  +  + 1,data=data)
m402 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m403 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m404 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m405 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m406 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m407 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m408 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m409 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m410 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m411 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m412 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m413 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m414 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m415 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m416 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m417 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 +  +  + 1,data=data)
m418 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m419 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m420 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m421 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m422 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m423 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m424 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m425 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m426 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m427 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m428 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m429 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m430 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m431 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m432 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m433 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 +  +  + 1,data=data)
m434 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m435 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m436 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m437 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m438 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m439 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m440 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m441 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m442 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m443 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m444 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m445 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m446 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m447 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m448 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m449 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  +  +  + 1,data=data)
m450 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  +  + transition.win15 + 1,data=data)
m451 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  +  + transition.win9 + 1,data=data)
m452 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  +  + transition.win12 + 1,data=data)
m453 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win4 +  + 1,data=data)
m454 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win4 + transition.win15 + 1,data=data)
m455 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win4 + transition.win9 + 1,data=data)
m456 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win4 + transition.win12 + 1,data=data)
m457 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win2 +  + 1,data=data)
m458 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win2 + transition.win15 + 1,data=data)
m459 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win2 + transition.win9 + 1,data=data)
m460 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win2 + transition.win12 + 1,data=data)
m461 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win3 +  + 1,data=data)
m462 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win3 + transition.win15 + 1,data=data)
m463 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win3 + transition.win9 + 1,data=data)
m464 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 +  + extmob.win3 + transition.win12 + 1,data=data)
m465 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 +  +  + 1,data=data)
m466 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m467 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m468 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m469 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m470 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m471 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m472 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m473 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m474 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m475 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m476 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m477 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m478 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m479 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m480 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m481 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 +  +  + 1,data=data)
m482 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m483 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m484 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m485 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m486 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m487 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m488 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m489 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m490 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m491 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m492 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m493 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m494 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m495 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m496 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m497 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 +  +  + 1,data=data)
m498 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m499 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m500 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m501 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m502 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m503 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m504 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m505 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m506 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m507 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m508 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m509 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m510 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m511 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m512 <-glm.nb(issue.ethtib.det ~ + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m513 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  +  +  + 1,data=data)
m514 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  +  + transition.win15 + 1,data=data)
m515 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  +  + transition.win9 + 1,data=data)
m516 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  +  + transition.win12 + 1,data=data)
m517 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win4 +  + 1,data=data)
m518 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m519 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m520 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m521 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win2 +  + 1,data=data)
m522 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m523 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m524 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m525 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win3 +  + 1,data=data)
m526 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m527 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m528 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m529 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 +  +  + 1,data=data)
m530 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 +  + transition.win15 + 1,data=data)
m531 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 +  + transition.win9 + 1,data=data)
m532 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 +  + transition.win12 + 1,data=data)
m533 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m534 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m535 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m536 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m537 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m538 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m539 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m540 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m541 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m542 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m543 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m544 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m545 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 +  +  + 1,data=data)
m546 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 +  + transition.win15 + 1,data=data)
m547 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 +  + transition.win9 + 1,data=data)
m548 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 +  + transition.win12 + 1,data=data)
m549 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m550 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m551 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m552 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m553 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m554 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m555 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m556 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m557 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m558 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m559 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m560 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m561 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 +  +  + 1,data=data)
m562 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 +  + transition.win15 + 1,data=data)
m563 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 +  + transition.win9 + 1,data=data)
m564 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 +  + transition.win12 + 1,data=data)
m565 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m566 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m567 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m568 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m569 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m570 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m571 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m572 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m573 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m574 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m575 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m576 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 +  + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m577 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  +  +  + 1,data=data)
m578 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  +  + transition.win15 + 1,data=data)
m579 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  +  + transition.win9 + 1,data=data)
m580 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  +  + transition.win12 + 1,data=data)
m581 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win4 +  + 1,data=data)
m582 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win4 + transition.win15 + 1,data=data)
m583 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win4 + transition.win9 + 1,data=data)
m584 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win4 + transition.win12 + 1,data=data)
m585 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win2 +  + 1,data=data)
m586 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win2 + transition.win15 + 1,data=data)
m587 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win2 + transition.win9 + 1,data=data)
m588 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win2 + transition.win12 + 1,data=data)
m589 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win3 +  + 1,data=data)
m590 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win3 + transition.win15 + 1,data=data)
m591 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win3 + transition.win9 + 1,data=data)
m592 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 +  + extmob.win3 + transition.win12 + 1,data=data)
m593 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 +  +  + 1,data=data)
m594 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m595 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m596 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m597 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m598 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m599 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m600 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m601 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m602 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m603 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m604 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m605 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m606 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m607 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m608 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m609 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 +  +  + 1,data=data)
m610 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m611 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m612 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m613 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m614 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m615 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m616 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m617 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m618 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m619 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m620 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m621 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m622 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m623 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m624 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m625 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 +  +  + 1,data=data)
m626 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m627 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m628 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m629 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m630 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m631 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m632 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m633 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m634 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m635 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m636 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m637 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m638 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m639 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m640 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m641 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  +  +  + 1,data=data)
m642 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  +  + transition.win15 + 1,data=data)
m643 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  +  + transition.win9 + 1,data=data)
m644 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  +  + transition.win12 + 1,data=data)
m645 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win4 +  + 1,data=data)
m646 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win4 + transition.win15 + 1,data=data)
m647 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win4 + transition.win9 + 1,data=data)
m648 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win4 + transition.win12 + 1,data=data)
m649 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win2 +  + 1,data=data)
m650 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win2 + transition.win15 + 1,data=data)
m651 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win2 + transition.win9 + 1,data=data)
m652 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win2 + transition.win12 + 1,data=data)
m653 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win3 +  + 1,data=data)
m654 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win3 + transition.win15 + 1,data=data)
m655 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win3 + transition.win9 + 1,data=data)
m656 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 +  + extmob.win3 + transition.win12 + 1,data=data)
m657 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 +  +  + 1,data=data)
m658 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m659 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m660 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m661 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m662 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m663 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m664 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m665 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m666 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m667 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m668 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m669 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m670 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m671 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m672 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m673 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 +  +  + 1,data=data)
m674 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m675 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m676 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m677 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m678 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m679 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m680 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m681 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m682 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m683 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m684 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m685 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m686 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m687 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m688 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m689 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 +  +  + 1,data=data)
m690 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m691 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m692 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m693 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m694 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m695 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m696 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m697 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m698 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m699 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m700 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m701 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m702 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m703 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m704 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m705 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  +  +  + 1,data=data)
m706 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  +  + transition.win15 + 1,data=data)
m707 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  +  + transition.win9 + 1,data=data)
m708 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  +  + transition.win12 + 1,data=data)
m709 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win4 +  + 1,data=data)
m710 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win4 + transition.win15 + 1,data=data)
m711 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win4 + transition.win9 + 1,data=data)
m712 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win4 + transition.win12 + 1,data=data)
m713 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win2 +  + 1,data=data)
m714 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win2 + transition.win15 + 1,data=data)
m715 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win2 + transition.win9 + 1,data=data)
m716 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win2 + transition.win12 + 1,data=data)
m717 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win3 +  + 1,data=data)
m718 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win3 + transition.win15 + 1,data=data)
m719 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win3 + transition.win9 + 1,data=data)
m720 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 +  + extmob.win3 + transition.win12 + 1,data=data)
m721 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 +  +  + 1,data=data)
m722 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m723 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m724 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m725 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m726 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m727 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m728 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m729 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m730 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m731 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m732 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m733 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m734 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m735 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m736 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m737 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 +  +  + 1,data=data)
m738 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m739 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m740 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m741 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m742 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m743 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m744 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m745 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m746 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m747 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m748 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m749 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m750 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m751 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m752 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m753 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 +  +  + 1,data=data)
m754 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m755 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m756 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m757 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m758 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m759 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m760 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m761 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m762 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m763 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m764 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m765 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m766 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m767 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m768 <-glm.nb(issue.ethtib.det ~ + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m769 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  +  +  + 1,data=data)
m770 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  +  + transition.win15 + 1,data=data)
m771 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  +  + transition.win9 + 1,data=data)
m772 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  +  + transition.win12 + 1,data=data)
m773 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win4 +  + 1,data=data)
m774 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m775 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m776 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m777 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win2 +  + 1,data=data)
m778 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m779 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m780 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m781 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win3 +  + 1,data=data)
m782 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m783 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m784 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m785 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 +  +  + 1,data=data)
m786 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 +  + transition.win15 + 1,data=data)
m787 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 +  + transition.win9 + 1,data=data)
m788 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 +  + transition.win12 + 1,data=data)
m789 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m790 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m791 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m792 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m793 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m794 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m795 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m796 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m797 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m798 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m799 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m800 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m801 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 +  +  + 1,data=data)
m802 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 +  + transition.win15 + 1,data=data)
m803 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 +  + transition.win9 + 1,data=data)
m804 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 +  + transition.win12 + 1,data=data)
m805 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m806 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m807 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m808 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m809 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m810 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m811 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m812 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m813 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m814 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m815 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m816 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m817 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 +  +  + 1,data=data)
m818 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 +  + transition.win15 + 1,data=data)
m819 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 +  + transition.win9 + 1,data=data)
m820 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 +  + transition.win12 + 1,data=data)
m821 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m822 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m823 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m824 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m825 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m826 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m827 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m828 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m829 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m830 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m831 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m832 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 +  + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m833 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  +  +  + 1,data=data)
m834 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  +  + transition.win15 + 1,data=data)
m835 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  +  + transition.win9 + 1,data=data)
m836 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  +  + transition.win12 + 1,data=data)
m837 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win4 +  + 1,data=data)
m838 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win4 + transition.win15 + 1,data=data)
m839 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win4 + transition.win9 + 1,data=data)
m840 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win4 + transition.win12 + 1,data=data)
m841 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win2 +  + 1,data=data)
m842 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win2 + transition.win15 + 1,data=data)
m843 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win2 + transition.win9 + 1,data=data)
m844 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win2 + transition.win12 + 1,data=data)
m845 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win3 +  + 1,data=data)
m846 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win3 + transition.win15 + 1,data=data)
m847 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win3 + transition.win9 + 1,data=data)
m848 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 +  + extmob.win3 + transition.win12 + 1,data=data)
m849 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 +  +  + 1,data=data)
m850 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m851 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m852 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m853 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m854 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m855 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m856 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m857 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m858 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m859 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m860 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m861 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m862 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m863 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m864 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m865 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 +  +  + 1,data=data)
m866 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m867 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m868 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m869 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m870 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m871 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m872 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m873 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m874 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m875 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m876 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m877 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m878 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m879 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m880 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m881 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 +  +  + 1,data=data)
m882 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m883 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m884 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m885 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m886 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m887 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m888 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m889 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m890 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m891 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m892 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m893 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m894 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m895 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m896 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m897 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  +  +  + 1,data=data)
m898 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  +  + transition.win15 + 1,data=data)
m899 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  +  + transition.win9 + 1,data=data)
m900 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  +  + transition.win12 + 1,data=data)
m901 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win4 +  + 1,data=data)
m902 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win4 + transition.win15 + 1,data=data)
m903 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win4 + transition.win9 + 1,data=data)
m904 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win4 + transition.win12 + 1,data=data)
m905 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win2 +  + 1,data=data)
m906 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win2 + transition.win15 + 1,data=data)
m907 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win2 + transition.win9 + 1,data=data)
m908 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win2 + transition.win12 + 1,data=data)
m909 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win3 +  + 1,data=data)
m910 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win3 + transition.win15 + 1,data=data)
m911 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win3 + transition.win9 + 1,data=data)
m912 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 +  + extmob.win3 + transition.win12 + 1,data=data)
m913 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 +  +  + 1,data=data)
m914 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m915 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m916 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m917 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m918 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m919 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m920 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m921 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m922 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m923 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m924 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m925 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m926 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m927 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m928 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m929 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 +  +  + 1,data=data)
m930 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m931 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m932 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m933 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m934 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m935 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m936 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m937 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m938 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m939 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m940 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m941 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m942 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m943 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m944 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m945 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 +  +  + 1,data=data)
m946 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m947 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m948 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m949 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m950 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m951 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m952 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m953 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m954 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m955 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m956 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m957 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m958 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m959 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m960 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m961 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  +  +  + 1,data=data)
m962 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  +  + transition.win15 + 1,data=data)
m963 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  +  + transition.win9 + 1,data=data)
m964 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  +  + transition.win12 + 1,data=data)
m965 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win4 +  + 1,data=data)
m966 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win4 + transition.win15 + 1,data=data)
m967 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win4 + transition.win9 + 1,data=data)
m968 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win4 + transition.win12 + 1,data=data)
m969 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 +  + 1,data=data)
m970 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 + transition.win15 + 1,data=data)
m971 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 + transition.win9 + 1,data=data)
m972 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 + transition.win12 + 1,data=data)
m973 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win3 +  + 1,data=data)
m974 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win3 + transition.win15 + 1,data=data)
m975 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win3 + transition.win9 + 1,data=data)
m976 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win3 + transition.win12 + 1,data=data)
m977 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 +  +  + 1,data=data)
m978 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m979 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m980 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m981 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m982 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m983 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m984 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m985 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m986 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m987 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m988 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m989 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m990 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m991 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m992 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m993 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 +  +  + 1,data=data)
m994 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m995 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m996 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m997 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m998 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m999 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1000 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1001 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1002 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1003 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1004 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1005 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1006 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1007 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1008 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1009 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 +  +  + 1,data=data)
m1010 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1011 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1012 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1013 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1014 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1015 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1016 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1017 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1018 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1019 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1020 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1021 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1022 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1023 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1024 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1025 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  +  +  + 1,data=data)
m1026 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  +  + transition.win15 + 1,data=data)
m1027 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  +  + transition.win9 + 1,data=data)
m1028 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  +  + transition.win12 + 1,data=data)
m1029 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win4 +  + 1,data=data)
m1030 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m1031 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m1032 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m1033 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win2 +  + 1,data=data)
m1034 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m1035 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m1036 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m1037 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win3 +  + 1,data=data)
m1038 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m1039 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m1040 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m1041 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 +  +  + 1,data=data)
m1042 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 +  + transition.win15 + 1,data=data)
m1043 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 +  + transition.win9 + 1,data=data)
m1044 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 +  + transition.win12 + 1,data=data)
m1045 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m1046 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1047 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1048 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1049 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m1050 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1051 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1052 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1053 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m1054 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1055 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1056 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1057 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 +  +  + 1,data=data)
m1058 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 +  + transition.win15 + 1,data=data)
m1059 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 +  + transition.win9 + 1,data=data)
m1060 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 +  + transition.win12 + 1,data=data)
m1061 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m1062 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1063 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1064 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1065 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1066 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1067 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1068 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1069 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1070 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1071 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1072 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1073 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 +  +  + 1,data=data)
m1074 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1075 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1076 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1077 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1078 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1079 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1080 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1081 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1082 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1083 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1084 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1085 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1086 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1087 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1088 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 +  + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1089 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  +  +  + 1,data=data)
m1090 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  +  + transition.win15 + 1,data=data)
m1091 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  +  + transition.win9 + 1,data=data)
m1092 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  +  + transition.win12 + 1,data=data)
m1093 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win4 +  + 1,data=data)
m1094 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win4 + transition.win15 + 1,data=data)
m1095 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win4 + transition.win9 + 1,data=data)
m1096 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win4 + transition.win12 + 1,data=data)
m1097 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win2 +  + 1,data=data)
m1098 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win2 + transition.win15 + 1,data=data)
m1099 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win2 + transition.win9 + 1,data=data)
m1100 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win2 + transition.win12 + 1,data=data)
m1101 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win3 +  + 1,data=data)
m1102 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win3 + transition.win15 + 1,data=data)
m1103 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win3 + transition.win9 + 1,data=data)
m1104 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 +  + extmob.win3 + transition.win12 + 1,data=data)
m1105 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 +  +  + 1,data=data)
m1106 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m1107 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m1108 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m1109 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m1110 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1111 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1112 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1113 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m1114 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1115 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1116 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1117 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m1118 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1119 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1120 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1121 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 +  +  + 1,data=data)
m1122 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m1123 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m1124 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m1125 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m1126 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1127 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1128 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1129 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1130 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1131 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1132 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1133 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1134 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1135 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1136 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1137 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 +  +  + 1,data=data)
m1138 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1139 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1140 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1141 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1142 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1143 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1144 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1145 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1146 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1147 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1148 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1149 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1150 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1151 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1152 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1153 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  +  +  + 1,data=data)
m1154 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  +  + transition.win15 + 1,data=data)
m1155 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  +  + transition.win9 + 1,data=data)
m1156 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  +  + transition.win12 + 1,data=data)
m1157 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win4 +  + 1,data=data)
m1158 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win4 + transition.win15 + 1,data=data)
m1159 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win4 + transition.win9 + 1,data=data)
m1160 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win4 + transition.win12 + 1,data=data)
m1161 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win2 +  + 1,data=data)
m1162 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win2 + transition.win15 + 1,data=data)
m1163 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win2 + transition.win9 + 1,data=data)
m1164 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win2 + transition.win12 + 1,data=data)
m1165 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win3 +  + 1,data=data)
m1166 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win3 + transition.win15 + 1,data=data)
m1167 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win3 + transition.win9 + 1,data=data)
m1168 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 +  + extmob.win3 + transition.win12 + 1,data=data)
m1169 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 +  +  + 1,data=data)
m1170 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m1171 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m1172 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m1173 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m1174 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1175 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1176 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1177 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m1178 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1179 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1180 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1181 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m1182 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1183 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1184 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1185 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 +  +  + 1,data=data)
m1186 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m1187 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m1188 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m1189 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m1190 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1191 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1192 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1193 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1194 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1195 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1196 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1197 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1198 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1199 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1200 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1201 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 +  +  + 1,data=data)
m1202 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1203 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1204 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1205 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1206 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1207 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1208 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1209 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1210 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1211 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1212 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1213 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1214 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1215 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1216 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1217 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  +  +  + 1,data=data)
m1218 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  +  + transition.win15 + 1,data=data)
m1219 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  +  + transition.win9 + 1,data=data)
m1220 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  +  + transition.win12 + 1,data=data)
m1221 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win4 +  + 1,data=data)
m1222 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win4 + transition.win15 + 1,data=data)
m1223 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win4 + transition.win9 + 1,data=data)
m1224 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win4 + transition.win12 + 1,data=data)
m1225 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win2 +  + 1,data=data)
m1226 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win2 + transition.win15 + 1,data=data)
m1227 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win2 + transition.win9 + 1,data=data)
m1228 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win2 + transition.win12 + 1,data=data)
m1229 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win3 +  + 1,data=data)
m1230 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win3 + transition.win15 + 1,data=data)
m1231 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win3 + transition.win9 + 1,data=data)
m1232 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 +  + extmob.win3 + transition.win12 + 1,data=data)
m1233 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 +  +  + 1,data=data)
m1234 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m1235 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m1236 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m1237 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m1238 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1239 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1240 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1241 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m1242 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1243 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1244 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1245 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m1246 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1247 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1248 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1249 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 +  +  + 1,data=data)
m1250 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m1251 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m1252 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m1253 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m1254 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1255 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1256 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1257 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1258 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1259 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1260 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1261 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1262 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1263 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1264 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1265 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 +  +  + 1,data=data)
m1266 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1267 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1268 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1269 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1270 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1271 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1272 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1273 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1274 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1275 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1276 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1277 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1278 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1279 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1280 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1281 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  +  +  + 1,data=data)
m1282 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  +  + transition.win15 + 1,data=data)
m1283 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  +  + transition.win9 + 1,data=data)
m1284 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  +  + transition.win12 + 1,data=data)
m1285 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win4 +  + 1,data=data)
m1286 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win4 + transition.win15 + 1,data=data)
m1287 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win4 + transition.win9 + 1,data=data)
m1288 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win4 + transition.win12 + 1,data=data)
m1289 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win2 +  + 1,data=data)
m1290 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win2 + transition.win15 + 1,data=data)
m1291 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win2 + transition.win9 + 1,data=data)
m1292 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win2 + transition.win12 + 1,data=data)
m1293 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win3 +  + 1,data=data)
m1294 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win3 + transition.win15 + 1,data=data)
m1295 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win3 + transition.win9 + 1,data=data)
m1296 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  +  + extmob.win3 + transition.win12 + 1,data=data)
m1297 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 +  +  + 1,data=data)
m1298 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 +  + transition.win15 + 1,data=data)
m1299 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 +  + transition.win9 + 1,data=data)
m1300 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 +  + transition.win12 + 1,data=data)
m1301 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m1302 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1303 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1304 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1305 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m1306 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1307 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1308 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1309 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m1310 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1311 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1312 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1313 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 +  +  + 1,data=data)
m1314 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 +  + transition.win15 + 1,data=data)
m1315 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 +  + transition.win9 + 1,data=data)
m1316 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 +  + transition.win12 + 1,data=data)
m1317 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m1318 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1319 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1320 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1321 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1322 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1323 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1324 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1325 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1326 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1327 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1328 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1329 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 +  +  + 1,data=data)
m1330 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1331 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1332 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1333 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1334 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1335 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1336 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1337 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1338 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1339 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1340 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1341 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1342 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1343 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1344 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 +  + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1345 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  +  +  + 1,data=data)
m1346 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  +  + transition.win15 + 1,data=data)
m1347 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  +  + transition.win9 + 1,data=data)
m1348 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  +  + transition.win12 + 1,data=data)
m1349 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win4 +  + 1,data=data)
m1350 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win4 + transition.win15 + 1,data=data)
m1351 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win4 + transition.win9 + 1,data=data)
m1352 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win4 + transition.win12 + 1,data=data)
m1353 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win2 +  + 1,data=data)
m1354 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win2 + transition.win15 + 1,data=data)
m1355 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win2 + transition.win9 + 1,data=data)
m1356 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win2 + transition.win12 + 1,data=data)
m1357 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win3 +  + 1,data=data)
m1358 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win3 + transition.win15 + 1,data=data)
m1359 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win3 + transition.win9 + 1,data=data)
m1360 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 +  + extmob.win3 + transition.win12 + 1,data=data)
m1361 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 +  +  + 1,data=data)
m1362 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m1363 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m1364 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m1365 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m1366 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1367 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1368 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1369 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m1370 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1371 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1372 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1373 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m1374 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1375 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1376 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1377 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 +  +  + 1,data=data)
m1378 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m1379 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m1380 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m1381 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m1382 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1383 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1384 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1385 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1386 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1387 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1388 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1389 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1390 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1391 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1392 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1393 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 +  +  + 1,data=data)
m1394 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1395 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1396 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1397 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1398 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1399 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1400 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1401 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1402 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1403 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1404 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1405 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1406 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1407 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1408 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win15 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1409 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  +  +  + 1,data=data)
m1410 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  +  + transition.win15 + 1,data=data)
m1411 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  +  + transition.win9 + 1,data=data)
m1412 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  +  + transition.win12 + 1,data=data)
m1413 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win4 +  + 1,data=data)
m1414 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win4 + transition.win15 + 1,data=data)
m1415 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win4 + transition.win9 + 1,data=data)
m1416 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win4 + transition.win12 + 1,data=data)
m1417 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win2 +  + 1,data=data)
m1418 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win2 + transition.win15 + 1,data=data)
m1419 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win2 + transition.win9 + 1,data=data)
m1420 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win2 + transition.win12 + 1,data=data)
m1421 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win3 +  + 1,data=data)
m1422 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win3 + transition.win15 + 1,data=data)
m1423 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win3 + transition.win9 + 1,data=data)
m1424 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 +  + extmob.win3 + transition.win12 + 1,data=data)
m1425 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 +  +  + 1,data=data)
m1426 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m1427 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m1428 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m1429 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m1430 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1431 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1432 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1433 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m1434 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1435 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1436 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1437 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m1438 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1439 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1440 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1441 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 +  +  + 1,data=data)
m1442 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m1443 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m1444 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m1445 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m1446 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1447 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1448 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1449 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1450 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1451 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1452 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1453 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1454 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1455 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1456 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1457 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 +  +  + 1,data=data)
m1458 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1459 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1460 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1461 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1462 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1463 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1464 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1465 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1466 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1467 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1468 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1469 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1470 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1471 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1472 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win9 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1473 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  +  +  + 1,data=data)
m1474 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  +  + transition.win15 + 1,data=data)
m1475 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  +  + transition.win9 + 1,data=data)
m1476 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  +  + transition.win12 + 1,data=data)
m1477 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win4 +  + 1,data=data)
m1478 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win4 + transition.win15 + 1,data=data)
m1479 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win4 + transition.win9 + 1,data=data)
m1480 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win4 + transition.win12 + 1,data=data)
m1481 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win2 +  + 1,data=data)
m1482 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win2 + transition.win15 + 1,data=data)
m1483 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win2 + transition.win9 + 1,data=data)
m1484 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win2 + transition.win12 + 1,data=data)
m1485 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win3 +  + 1,data=data)
m1486 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win3 + transition.win15 + 1,data=data)
m1487 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win3 + transition.win9 + 1,data=data)
m1488 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 +  + extmob.win3 + transition.win12 + 1,data=data)
m1489 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 +  +  + 1,data=data)
m1490 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 +  + transition.win15 + 1,data=data)
m1491 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 +  + transition.win9 + 1,data=data)
m1492 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 +  + transition.win12 + 1,data=data)
m1493 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win4 +  + 1,data=data)
m1494 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win15 + 1,data=data)
m1495 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win9 + 1,data=data)
m1496 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win4 + transition.win12 + 1,data=data)
m1497 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win2 +  + 1,data=data)
m1498 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win15 + 1,data=data)
m1499 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win9 + 1,data=data)
m1500 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win2 + transition.win12 + 1,data=data)
m1501 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win3 +  + 1,data=data)
m1502 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win15 + 1,data=data)
m1503 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win9 + 1,data=data)
m1504 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win4 + extmob.win3 + transition.win12 + 1,data=data)
m1505 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 +  +  + 1,data=data)
m1506 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 +  + transition.win15 + 1,data=data)
m1507 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 +  + transition.win9 + 1,data=data)
m1508 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 +  + transition.win12 + 1,data=data)
m1509 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win4 +  + 1,data=data)
m1510 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win15 + 1,data=data)
m1511 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win9 + 1,data=data)
m1512 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win4 + transition.win12 + 1,data=data)
m1513 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win2 +  + 1,data=data)
m1514 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win15 + 1,data=data)
m1515 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win9 + 1,data=data)
m1516 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win2 + transition.win12 + 1,data=data)
m1517 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win3 +  + 1,data=data)
m1518 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win15 + 1,data=data)
m1519 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win9 + 1,data=data)
m1520 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win2 + extmob.win3 + transition.win12 + 1,data=data)
m1521 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 +  +  + 1,data=data)
m1522 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 +  + transition.win15 + 1,data=data)
m1523 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 +  + transition.win9 + 1,data=data)
m1524 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 +  + transition.win12 + 1,data=data)
m1525 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win4 +  + 1,data=data)
m1526 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win15 + 1,data=data)
m1527 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win9 + 1,data=data)
m1528 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win4 + transition.win12 + 1,data=data)
m1529 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win2 +  + 1,data=data)
m1530 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win15 + 1,data=data)
m1531 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win9 + 1,data=data)
m1532 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win2 + transition.win12 + 1,data=data)
m1533 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win3 +  + 1,data=data)
m1534 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win15 + 1,data=data)
m1535 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win9 + 1,data=data)
m1536 <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3 + transition.tib.win12 + focal.gen.win3 + extmob.win3 + transition.win12 + 1,data=data)
m1537<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  +  +  + 1,data=data)
m1538<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  +  + transition.win15 + 1,data=data)
m1539<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  +  + transition.win9 + 1,data=data)
m1540<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  +  + transition.win12 + 1,data=data)
m1541<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win4 +  + 1,data=data)
m1542<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m1543<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m1544<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m1545<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win2 +  + 1,data=data)
m1546<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m1547<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m1548<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m1549<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win3 +  + 1,data=data)
m1550<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m1551<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m1552<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m1553<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt +  +  + 1,data=data)
m1554<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m1555<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m1556<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m1557<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m1558<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m1559<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m1560<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m1561<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m1562<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m1563<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m1564<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m1565<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m1566<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m1567<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m1568<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m1569<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt +  +  + 1,data=data)
m1570<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m1571<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m1572<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m1573<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m1574<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m1575<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m1576<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m1577<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m1578<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m1579<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m1580<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m1581<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m1582<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m1583<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m1584<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m1585<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt +  +  + 1,data=data)
m1586<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m1587<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m1588<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m1589<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m1590<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m1591<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m1592<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m1593<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m1594<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m1595<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m1596<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m1597<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m1598<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m1599<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m1600<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m1601<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  +  +  + 1,data=data)
m1602<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m1603<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m1604<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m1605<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m1606<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m1607<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m1608<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m1609<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m1610<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m1611<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m1612<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m1613<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m1614<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m1615<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m1616<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m1617<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt +  +  + 1,data=data)
m1618<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m1619<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m1620<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m1621<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m1622<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m1623<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m1624<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m1625<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m1626<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m1627<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m1628<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m1629<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m1630<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m1631<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m1632<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m1633<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt +  +  + 1,data=data)
m1634<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m1635<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m1636<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m1637<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m1638<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m1639<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m1640<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m1641<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m1642<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m1643<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m1644<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m1645<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m1646<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m1647<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m1648<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m1649<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt +  +  + 1,data=data)
m1650<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m1651<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m1652<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m1653<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m1654<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m1655<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m1656<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m1657<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m1658<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m1659<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m1660<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m1661<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m1662<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m1663<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m1664<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m1665<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  +  +  + 1,data=data)
m1666<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m1667<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m1668<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m1669<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m1670<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m1671<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m1672<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m1673<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m1674<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m1675<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m1676<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m1677<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m1678<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m1679<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m1680<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m1681<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt +  +  + 1,data=data)
m1682<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m1683<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m1684<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m1685<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m1686<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m1687<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m1688<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m1689<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m1690<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m1691<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m1692<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m1693<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m1694<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m1695<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m1696<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m1697<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt +  +  + 1,data=data)
m1698<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m1699<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m1700<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m1701<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m1702<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m1703<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m1704<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m1705<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m1706<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m1707<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m1708<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m1709<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m1710<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m1711<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m1712<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m1713<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt +  +  + 1,data=data)
m1714<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m1715<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m1716<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m1717<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m1718<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m1719<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m1720<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m1721<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m1722<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m1723<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m1724<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m1725<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m1726<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m1727<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m1728<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m1729<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  +  +  + 1,data=data)
m1730<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m1731<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m1732<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m1733<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m1734<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m1735<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m1736<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m1737<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m1738<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m1739<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m1740<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m1741<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m1742<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m1743<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m1744<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m1745<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt +  +  + 1,data=data)
m1746<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m1747<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m1748<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m1749<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m1750<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m1751<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m1752<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m1753<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m1754<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m1755<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m1756<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m1757<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m1758<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m1759<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m1760<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m1761<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt +  +  + 1,data=data)
m1762<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m1763<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m1764<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m1765<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m1766<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m1767<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m1768<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m1769<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m1770<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m1771<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m1772<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m1773<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m1774<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m1775<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m1776<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m1777<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt +  +  + 1,data=data)
m1778<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m1779<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m1780<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m1781<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m1782<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m1783<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m1784<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m1785<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m1786<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m1787<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m1788<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m1789<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m1790<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m1791<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m1792<-glm.nb(issue.ethtib.det ~ + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m1793<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  +  +  + 1,data=data)
m1794<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  +  + transition.win15 + 1,data=data)
m1795<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  +  + transition.win9 + 1,data=data)
m1796<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  +  + transition.win12 + 1,data=data)
m1797<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win4 +  + 1,data=data)
m1798<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m1799<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m1800<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m1801<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win2 +  + 1,data=data)
m1802<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m1803<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m1804<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m1805<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win3 +  + 1,data=data)
m1806<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m1807<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m1808<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m1809<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt +  +  + 1,data=data)
m1810<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m1811<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m1812<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m1813<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m1814<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m1815<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m1816<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m1817<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m1818<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m1819<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m1820<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m1821<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m1822<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m1823<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m1824<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m1825<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt +  +  + 1,data=data)
m1826<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m1827<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m1828<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m1829<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m1830<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m1831<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m1832<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m1833<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m1834<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m1835<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m1836<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m1837<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m1838<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m1839<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m1840<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m1841<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt +  +  + 1,data=data)
m1842<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m1843<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m1844<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m1845<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m1846<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m1847<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m1848<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m1849<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m1850<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m1851<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m1852<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m1853<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m1854<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m1855<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m1856<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m1857<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  +  +  + 1,data=data)
m1858<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m1859<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m1860<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m1861<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m1862<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m1863<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m1864<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m1865<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m1866<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m1867<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m1868<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m1869<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m1870<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m1871<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m1872<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m1873<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt +  +  + 1,data=data)
m1874<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m1875<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m1876<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m1877<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m1878<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m1879<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m1880<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m1881<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m1882<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m1883<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m1884<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m1885<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m1886<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m1887<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m1888<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m1889<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt +  +  + 1,data=data)
m1890<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m1891<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m1892<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m1893<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m1894<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m1895<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m1896<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m1897<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m1898<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m1899<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m1900<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m1901<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m1902<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m1903<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m1904<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m1905<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt +  +  + 1,data=data)
m1906<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m1907<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m1908<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m1909<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m1910<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m1911<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m1912<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m1913<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m1914<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m1915<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m1916<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m1917<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m1918<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m1919<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m1920<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m1921<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  +  +  + 1,data=data)
m1922<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m1923<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m1924<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m1925<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m1926<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m1927<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m1928<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m1929<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m1930<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m1931<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m1932<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m1933<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m1934<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m1935<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m1936<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m1937<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt +  +  + 1,data=data)
m1938<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m1939<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m1940<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m1941<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m1942<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m1943<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m1944<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m1945<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m1946<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m1947<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m1948<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m1949<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m1950<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m1951<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m1952<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m1953<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt +  +  + 1,data=data)
m1954<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m1955<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m1956<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m1957<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m1958<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m1959<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m1960<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m1961<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m1962<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m1963<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m1964<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m1965<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m1966<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m1967<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m1968<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m1969<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt +  +  + 1,data=data)
m1970<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m1971<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m1972<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m1973<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m1974<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m1975<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m1976<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m1977<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m1978<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m1979<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m1980<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m1981<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m1982<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m1983<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m1984<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m1985<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  +  +  + 1,data=data)
m1986<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m1987<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m1988<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m1989<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m1990<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m1991<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m1992<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m1993<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m1994<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m1995<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m1996<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m1997<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m1998<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m1999<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m2000<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m2001<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt +  +  + 1,data=data)
m2002<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2003<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2004<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2005<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2006<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2007<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2008<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2009<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2010<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2011<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2012<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2013<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2014<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2015<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2016<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2017<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt +  +  + 1,data=data)
m2018<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2019<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2020<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2021<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2022<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2023<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2024<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2025<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2026<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2027<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2028<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2029<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2030<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2031<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2032<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2033<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt +  +  + 1,data=data)
m2034<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2035<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2036<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2037<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2038<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2039<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2040<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2041<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2042<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2043<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2044<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2045<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2046<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2047<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2048<-glm.nb(issue.ethtib.det ~ + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2049<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  +  +  + 1,data=data)
m2050<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  +  + transition.win15 + 1,data=data)
m2051<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  +  + transition.win9 + 1,data=data)
m2052<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  +  + transition.win12 + 1,data=data)
m2053<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win4 +  + 1,data=data)
m2054<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m2055<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m2056<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m2057<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win2 +  + 1,data=data)
m2058<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m2059<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m2060<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m2061<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win3 +  + 1,data=data)
m2062<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m2063<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m2064<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m2065<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt +  +  + 1,data=data)
m2066<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2067<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2068<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2069<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2070<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2071<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2072<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2073<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2074<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2075<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2076<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2077<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2078<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2079<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2080<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2081<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt +  +  + 1,data=data)
m2082<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2083<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2084<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2085<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2086<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2087<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2088<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2089<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2090<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2091<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2092<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2093<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2094<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2095<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2096<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2097<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt +  +  + 1,data=data)
m2098<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2099<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2100<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2101<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2102<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2103<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2104<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2105<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2106<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2107<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2108<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2109<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2110<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2111<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2112<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2113<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  +  +  + 1,data=data)
m2114<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m2115<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m2116<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m2117<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m2118<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m2119<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m2120<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m2121<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m2122<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m2123<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m2124<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m2125<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m2126<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m2127<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m2128<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m2129<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt +  +  + 1,data=data)
m2130<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2131<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2132<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2133<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2134<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2135<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2136<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2137<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2138<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2139<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2140<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2141<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2142<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2143<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2144<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2145<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt +  +  + 1,data=data)
m2146<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2147<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2148<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2149<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2150<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2151<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2152<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2153<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2154<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2155<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2156<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2157<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2158<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2159<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2160<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2161<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt +  +  + 1,data=data)
m2162<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2163<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2164<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2165<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2166<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2167<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2168<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2169<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2170<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2171<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2172<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2173<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2174<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2175<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2176<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2177<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  +  +  + 1,data=data)
m2178<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m2179<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m2180<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m2181<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m2182<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m2183<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m2184<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m2185<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m2186<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m2187<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m2188<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m2189<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m2190<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m2191<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m2192<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m2193<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt +  +  + 1,data=data)
m2194<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2195<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2196<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2197<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2198<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2199<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2200<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2201<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2202<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2203<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2204<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2205<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2206<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2207<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2208<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2209<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt +  +  + 1,data=data)
m2210<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2211<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2212<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2213<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2214<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2215<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2216<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2217<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2218<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2219<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2220<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2221<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2222<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2223<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2224<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2225<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt +  +  + 1,data=data)
m2226<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2227<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2228<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2229<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2230<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2231<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2232<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2233<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2234<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2235<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2236<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2237<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2238<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2239<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2240<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2241<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  +  +  + 1,data=data)
m2242<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m2243<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m2244<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m2245<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m2246<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m2247<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m2248<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m2249<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m2250<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m2251<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m2252<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m2253<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m2254<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m2255<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m2256<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m2257<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt +  +  + 1,data=data)
m2258<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2259<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2260<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2261<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2262<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2263<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2264<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2265<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2266<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2267<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2268<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2269<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2270<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2271<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2272<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2273<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt +  +  + 1,data=data)
m2274<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2275<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2276<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2277<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2278<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2279<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2280<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2281<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2282<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2283<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2284<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2285<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2286<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2287<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2288<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2289<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt +  +  + 1,data=data)
m2290<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2291<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2292<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2293<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2294<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2295<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2296<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2297<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2298<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2299<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2300<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2301<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2302<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2303<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2304<-glm.nb(issue.ethtib.det ~ + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2305<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  +  +  + 1,data=data)
m2306<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  +  + transition.win15 + 1,data=data)
m2307<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  +  + transition.win9 + 1,data=data)
m2308<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  +  + transition.win12 + 1,data=data)
m2309<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win4 +  + 1,data=data)
m2310<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m2311<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m2312<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m2313<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win2 +  + 1,data=data)
m2314<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m2315<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m2316<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m2317<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win3 +  + 1,data=data)
m2318<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m2319<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m2320<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m2321<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt +  +  + 1,data=data)
m2322<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2323<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2324<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2325<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2326<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2327<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2328<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2329<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2330<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2331<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2332<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2333<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2334<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2335<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2336<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2337<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt +  +  + 1,data=data)
m2338<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2339<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2340<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2341<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2342<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2343<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2344<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2345<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2346<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2347<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2348<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2349<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2350<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2351<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2352<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2353<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt +  +  + 1,data=data)
m2354<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2355<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2356<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2357<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2358<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2359<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2360<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2361<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2362<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2363<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2364<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2365<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2366<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2367<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2368<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2369<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  +  +  + 1,data=data)
m2370<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m2371<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m2372<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m2373<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m2374<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m2375<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m2376<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m2377<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m2378<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m2379<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m2380<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m2381<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m2382<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m2383<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m2384<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m2385<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt +  +  + 1,data=data)
m2386<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2387<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2388<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2389<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2390<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2391<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2392<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2393<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2394<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2395<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2396<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2397<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2398<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2399<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2400<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2401<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt +  +  + 1,data=data)
m2402<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2403<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2404<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2405<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2406<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2407<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2408<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2409<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2410<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2411<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2412<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2413<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2414<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2415<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2416<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2417<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt +  +  + 1,data=data)
m2418<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2419<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2420<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2421<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2422<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2423<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2424<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2425<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2426<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2427<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2428<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2429<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2430<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2431<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2432<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2433<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  +  +  + 1,data=data)
m2434<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m2435<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m2436<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m2437<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m2438<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m2439<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m2440<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m2441<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m2442<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m2443<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m2444<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m2445<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m2446<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m2447<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m2448<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m2449<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt +  +  + 1,data=data)
m2450<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2451<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2452<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2453<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2454<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2455<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2456<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2457<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2458<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2459<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2460<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2461<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2462<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2463<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2464<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2465<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt +  +  + 1,data=data)
m2466<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2467<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2468<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2469<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2470<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2471<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2472<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2473<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2474<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2475<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2476<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2477<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2478<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2479<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2480<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2481<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt +  +  + 1,data=data)
m2482<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2483<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2484<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2485<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2486<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2487<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2488<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2489<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2490<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2491<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2492<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2493<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2494<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2495<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2496<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2497<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  +  +  + 1,data=data)
m2498<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m2499<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m2500<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m2501<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m2502<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m2503<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m2504<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m2505<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m2506<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m2507<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m2508<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m2509<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m2510<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m2511<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m2512<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m2513<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt +  +  + 1,data=data)
m2514<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2515<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2516<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2517<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2518<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2519<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2520<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2521<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2522<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2523<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2524<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2525<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2526<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2527<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2528<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2529<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt +  +  + 1,data=data)
m2530<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2531<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2532<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2533<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2534<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2535<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2536<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2537<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2538<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2539<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2540<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2541<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2542<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2543<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2544<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2545<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt +  +  + 1,data=data)
m2546<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2547<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2548<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2549<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2550<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2551<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2552<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2553<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2554<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2555<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2556<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2557<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2558<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2559<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2560<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2561<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  +  +  + 1,data=data)
m2562<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  +  + transition.win15 + 1,data=data)
m2563<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  +  + transition.win9 + 1,data=data)
m2564<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  +  + transition.win12 + 1,data=data)
m2565<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win4 +  + 1,data=data)
m2566<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m2567<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m2568<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m2569<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win2 +  + 1,data=data)
m2570<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m2571<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m2572<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m2573<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win3 +  + 1,data=data)
m2574<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m2575<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m2576<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m2577<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt +  +  + 1,data=data)
m2578<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2579<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2580<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2581<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2582<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2583<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2584<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2585<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2586<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2587<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2588<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2589<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2590<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2591<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2592<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2593<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt +  +  + 1,data=data)
m2594<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2595<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2596<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2597<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2598<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2599<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2600<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2601<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2602<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2603<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2604<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2605<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2606<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2607<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2608<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2609<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt +  +  + 1,data=data)
m2610<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2611<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2612<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2613<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2614<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2615<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2616<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2617<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2618<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2619<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2620<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2621<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2622<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2623<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2624<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2625<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  +  +  + 1,data=data)
m2626<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m2627<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m2628<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m2629<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m2630<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m2631<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m2632<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m2633<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m2634<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m2635<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m2636<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m2637<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m2638<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m2639<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m2640<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m2641<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt +  +  + 1,data=data)
m2642<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2643<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2644<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2645<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2646<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2647<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2648<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2649<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2650<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2651<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2652<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2653<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2654<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2655<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2656<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2657<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt +  +  + 1,data=data)
m2658<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2659<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2660<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2661<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2662<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2663<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2664<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2665<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2666<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2667<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2668<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2669<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2670<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2671<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2672<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2673<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt +  +  + 1,data=data)
m2674<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2675<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2676<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2677<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2678<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2679<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2680<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2681<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2682<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2683<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2684<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2685<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2686<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2687<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2688<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2689<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  +  +  + 1,data=data)
m2690<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m2691<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m2692<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m2693<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m2694<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m2695<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m2696<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m2697<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m2698<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m2699<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m2700<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m2701<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m2702<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m2703<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m2704<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m2705<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt +  +  + 1,data=data)
m2706<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2707<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2708<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2709<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2710<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2711<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2712<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2713<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2714<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2715<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2716<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2717<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2718<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2719<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2720<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2721<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt +  +  + 1,data=data)
m2722<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2723<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2724<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2725<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2726<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2727<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2728<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2729<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2730<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2731<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2732<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2733<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2734<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2735<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2736<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2737<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt +  +  + 1,data=data)
m2738<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2739<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2740<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2741<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2742<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2743<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2744<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2745<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2746<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2747<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2748<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2749<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2750<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2751<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2752<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2753<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  +  +  + 1,data=data)
m2754<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m2755<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m2756<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m2757<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m2758<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m2759<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m2760<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m2761<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m2762<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m2763<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m2764<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m2765<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m2766<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m2767<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m2768<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m2769<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt +  +  + 1,data=data)
m2770<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2771<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2772<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2773<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2774<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2775<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2776<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2777<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2778<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2779<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2780<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2781<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2782<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2783<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2784<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2785<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt +  +  + 1,data=data)
m2786<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2787<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2788<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2789<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2790<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2791<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2792<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2793<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2794<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2795<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2796<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2797<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2798<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2799<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2800<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2801<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt +  +  + 1,data=data)
m2802<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2803<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2804<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2805<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2806<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2807<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2808<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2809<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2810<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2811<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2812<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2813<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2814<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2815<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2816<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win2.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2817<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  +  +  + 1,data=data)
m2818<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  +  + transition.win15 + 1,data=data)
m2819<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  +  + transition.win9 + 1,data=data)
m2820<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  +  + transition.win12 + 1,data=data)
m2821<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win4 +  + 1,data=data)
m2822<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win4 + transition.win15 + 1,data=data)
m2823<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win4 + transition.win9 + 1,data=data)
m2824<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win4 + transition.win12 + 1,data=data)
m2825<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win2 +  + 1,data=data)
m2826<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win2 + transition.win15 + 1,data=data)
m2827<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win2 + transition.win9 + 1,data=data)
m2828<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win2 + transition.win12 + 1,data=data)
m2829<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win3 +  + 1,data=data)
m2830<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win3 + transition.win15 + 1,data=data)
m2831<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win3 + transition.win9 + 1,data=data)
m2832<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  +  + extmob.win3 + transition.win12 + 1,data=data)
m2833<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt +  +  + 1,data=data)
m2834<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2835<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2836<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2837<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2838<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2839<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2840<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2841<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2842<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2843<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2844<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2845<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2846<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2847<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2848<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2849<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt +  +  + 1,data=data)
m2850<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2851<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2852<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2853<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2854<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2855<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2856<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2857<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2858<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2859<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2860<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2861<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2862<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2863<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2864<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2865<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt +  +  + 1,data=data)
m2866<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2867<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2868<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2869<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2870<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2871<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2872<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2873<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2874<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2875<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2876<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2877<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2878<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2879<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2880<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt +  + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2881<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  +  +  + 1,data=data)
m2882<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  +  + transition.win15 + 1,data=data)
m2883<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  +  + transition.win9 + 1,data=data)
m2884<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  +  + transition.win12 + 1,data=data)
m2885<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win4 +  + 1,data=data)
m2886<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win4 + transition.win15 + 1,data=data)
m2887<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win4 + transition.win9 + 1,data=data)
m2888<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win4 + transition.win12 + 1,data=data)
m2889<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win2 +  + 1,data=data)
m2890<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win2 + transition.win15 + 1,data=data)
m2891<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win2 + transition.win9 + 1,data=data)
m2892<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win2 + transition.win12 + 1,data=data)
m2893<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win3 +  + 1,data=data)
m2894<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win3 + transition.win15 + 1,data=data)
m2895<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win3 + transition.win9 + 1,data=data)
m2896<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 +  + extmob.win3 + transition.win12 + 1,data=data)
m2897<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt +  +  + 1,data=data)
m2898<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2899<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2900<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2901<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2902<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2903<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2904<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2905<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2906<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2907<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2908<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2909<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2910<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2911<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2912<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2913<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt +  +  + 1,data=data)
m2914<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2915<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2916<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2917<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2918<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2919<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2920<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2921<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2922<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2923<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2924<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2925<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2926<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2927<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2928<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2929<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt +  +  + 1,data=data)
m2930<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2931<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2932<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2933<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2934<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2935<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m2936<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m2937<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m2938<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m2939<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m2940<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m2941<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m2942<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m2943<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m2944<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win4 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m2945<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  +  +  + 1,data=data)
m2946<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  +  + transition.win15 + 1,data=data)
m2947<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  +  + transition.win9 + 1,data=data)
m2948<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  +  + transition.win12 + 1,data=data)
m2949<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win4 +  + 1,data=data)
m2950<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win4 + transition.win15 + 1,data=data)
m2951<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win4 + transition.win9 + 1,data=data)
m2952<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win4 + transition.win12 + 1,data=data)
m2953<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win2 +  + 1,data=data)
m2954<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win2 + transition.win15 + 1,data=data)
m2955<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win2 + transition.win9 + 1,data=data)
m2956<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win2 + transition.win12 + 1,data=data)
m2957<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win3 +  + 1,data=data)
m2958<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win3 + transition.win15 + 1,data=data)
m2959<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win3 + transition.win9 + 1,data=data)
m2960<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 +  + extmob.win3 + transition.win12 + 1,data=data)
m2961<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt +  +  + 1,data=data)
m2962<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m2963<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m2964<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m2965<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m2966<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m2967<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m2968<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m2969<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m2970<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m2971<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m2972<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m2973<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m2974<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m2975<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m2976<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m2977<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt +  +  + 1,data=data)
m2978<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m2979<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m2980<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m2981<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m2982<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m2983<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m2984<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m2985<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m2986<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m2987<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m2988<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m2989<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m2990<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m2991<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m2992<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m2993<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt +  +  + 1,data=data)
m2994<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m2995<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m2996<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m2997<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m2998<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m2999<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m3000<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m3001<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m3002<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m3003<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m3004<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m3005<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m3006<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m3007<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m3008<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win2 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)
m3009<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  +  +  + 1,data=data)
m3010<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  +  + transition.win15 + 1,data=data)
m3011<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  +  + transition.win9 + 1,data=data)
m3012<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  +  + transition.win12 + 1,data=data)
m3013<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win4 +  + 1,data=data)
m3014<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win4 + transition.win15 + 1,data=data)
m3015<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win4 + transition.win9 + 1,data=data)
m3016<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win4 + transition.win12 + 1,data=data)
m3017<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win2 +  + 1,data=data)
m3018<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win2 + transition.win15 + 1,data=data)
m3019<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win2 + transition.win9 + 1,data=data)
m3020<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win2 + transition.win12 + 1,data=data)
m3021<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win3 +  + 1,data=data)
m3022<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win3 + transition.win15 + 1,data=data)
m3023<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win3 + transition.win9 + 1,data=data)
m3024<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 +  + extmob.win3 + transition.win12 + 1,data=data)
m3025<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt +  +  + 1,data=data)
m3026<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt +  + transition.win15 + 1,data=data)
m3027<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt +  + transition.win9 + 1,data=data)
m3028<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt +  + transition.win12 + 1,data=data)
m3029<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win4 +  + 1,data=data)
m3030<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win15 + 1,data=data)
m3031<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win9 + 1,data=data)
m3032<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win4 + transition.win12 + 1,data=data)
m3033<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win2 +  + 1,data=data)
m3034<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win15 + 1,data=data)
m3035<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win9 + 1,data=data)
m3036<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win2 + transition.win12 + 1,data=data)
m3037<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win3 +  + 1,data=data)
m3038<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win15 + 1,data=data)
m3039<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win9 + 1,data=data)
m3040<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win4.alt + extmob.win3 + transition.win12 + 1,data=data)
m3041<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt +  +  + 1,data=data)
m3042<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt +  + transition.win15 + 1,data=data)
m3043<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt +  + transition.win9 + 1,data=data)
m3044<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt +  + transition.win12 + 1,data=data)
m3045<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win4 +  + 1,data=data)
m3046<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win15 + 1,data=data)
m3047<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win9 + 1,data=data)
m3048<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win4 + transition.win12 + 1,data=data)
m3049<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win2 +  + 1,data=data)
m3050<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win15 + 1,data=data)
m3051<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win9 + 1,data=data)
m3052<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win2 + transition.win12 + 1,data=data)
m3053<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win3 +  + 1,data=data)
m3054<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win15 + 1,data=data)
m3055<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win9 + 1,data=data)
m3056<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win2.alt + extmob.win3 + transition.win12 + 1,data=data)
m3057<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt +  +  + 1,data=data)
m3058<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt +  + transition.win15 + 1,data=data)
m3059<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt +  + transition.win9 + 1,data=data)
m3060<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt +  + transition.win12 + 1,data=data)
m3061<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win4 +  + 1,data=data)
m3062<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win15 + 1,data=data)
m3063<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win9 + 1,data=data)
m3064<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win4 + transition.win12 + 1,data=data)
m3065<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win2 +  + 1,data=data)
m3066<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win15 + 1,data=data)
m3067<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win9 + 1,data=data)
m3068<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win2 + transition.win12 + 1,data=data)
m3069<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win3 +  + 1,data=data)
m3070<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win15 + 1,data=data)
m3071<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win9 + 1,data=data)
m3072<-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win3.alt + division.win3 + focal.gen.win3.alt + extmob.win3 + transition.win12 + 1,data=data)

for (j in 1:3072) {
  
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.tib.win4',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.se[",j,"]<-summary(m",j,")$coefficients['focal.tib.win4',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.z[",j,"]<-summary(m",j,")$coefficients['focal.tib.win4',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.p[",j,"]<-summary(m",j,")$coefficients['focal.tib.win4',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.tib.win2',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.se[",j,"]<-summary(m",j,")$coefficients['focal.tib.win2',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.z[",j,"]<-summary(m",j,")$coefficients['focal.tib.win2',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.p[",j,"]<-summary(m",j,")$coefficients['focal.tib.win2',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.tib.win3',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.se[",j,"]<-summary(m",j,")$coefficients['focal.tib.win3',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.z[",j,"]<-summary(m",j,")$coefficients['focal.tib.win3',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.p[",j,"]<-summary(m",j,")$coefficients['focal.tib.win3',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.tib.win4.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.se[",j,"]<-summary(m",j,")$coefficients['focal.tib.win4.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.z[",j,"]<-summary(m",j,")$coefficients['focal.tib.win4.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.p[",j,"]<-summary(m",j,")$coefficients['focal.tib.win4.alt',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.tib.win2.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.se[",j,"]<-summary(m",j,")$coefficients['focal.tib.win2.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.z[",j,"]<-summary(m",j,")$coefficients['focal.tib.win2.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.p[",j,"]<-summary(m",j,")$coefficients['focal.tib.win2.alt',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.tib.win3.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.se[",j,"]<-summary(m",j,")$coefficients['focal.tib.win3.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.z[",j,"]<-summary(m",j,")$coefficients['focal.tib.win3.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.tib.win.p[",j,"]<-summary(m",j,")$coefficients['focal.tib.win3.alt',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients[' focal.gen.win4',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients[' focal.gen.win4',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients[' focal.gen.win4',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win4.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients[' focal.gen.win4.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients[' focal.gen.win4.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients[' focal.gen.win4.alt',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win2.alt',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.coeff[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3.alt',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.se[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3.alt',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.z[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3.alt',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$focal.gen.win.p[",j,"]<-summary(m",j,")$coefficients['focal.gen.win3.alt',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.coeff[",j,"]<-summary(m",j,")$coefficients['extmob.win4',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.se[",j,"]<-summary(m",j,")$coefficients['extmob.win4',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.z[",j,"]<-summary(m",j,")$coefficients['extmob.win4',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.p[",j,"]<-summary(m",j,")$coefficients['extmob.win4',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.coeff[",j,"]<-summary(m",j,")$coefficients['extmob.win2',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.se[",j,"]<-summary(m",j,")$coefficients['extmob.win2',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.z[",j,"]<-summary(m",j,")$coefficients['extmob.win2',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.p[",j,"]<-summary(m",j,")$coefficients['extmob.win2',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.coeff[",j,"]<-summary(m",j,")$coefficients['extmob.win3',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.se[",j,"]<-summary(m",j,")$coefficients['extmob.win3',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.z[",j,"]<-summary(m",j,")$coefficients['extmob.win3',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$extmob.win.p[",j,"]<-summary(m",j,")$coefficients['extmob.win3',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.tib.win9',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.se[",j,"]<-summary(m",j,")$coefficients['transition.tib.win9',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.z[",j,"]<-summary(m",j,")$coefficients['transition.tib.win9',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.p[",j,"]<-summary(m",j,")$coefficients['transition.tib.win9',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.tib.win12',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.se[",j,"]<-summary(m",j,")$coefficients['transition.tib.win12',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.z[",j,"]<-summary(m",j,")$coefficients['transition.tib.win12',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.p[",j,"]<-summary(m",j,")$coefficients['transition.tib.win12',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.tib.win15',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.se[",j,"]<-summary(m",j,")$coefficients['transition.tib.win15',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.z[",j,"]<-summary(m",j,")$coefficients['transition.tib.win15',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.tib.win.p[",j,"]<-summary(m",j,")$coefficients['transition.tib.win15',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$transition.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.win15',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.se[",j,"]<-summary(m",j,")$coefficients['transition.win15',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.z[",j,"]<-summary(m",j,")$coefficients['transition.win15',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.p[",j,"]<-summary(m",j,")$coefficients['transition.win15',4]",sep=""))))    
  
  try(eval(parse(text=paste("tlr.models.tib$transition.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.win9',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.se[",j,"]<-summary(m",j,")$coefficients['transition.win9',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.z[",j,"]<-summary(m",j,")$coefficients['transition.win9',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.p[",j,"]<-summary(m",j,")$coefficients['transition.win9',4]",sep=""))))   
  
  try(eval(parse(text=paste("tlr.models.tib$transition.win.coeff[",j,"]<-summary(m",j,")$coefficients['transition.win12',1]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.se[",j,"]<-summary(m",j,")$coefficients['transition.win12',2]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.z[",j,"]<-summary(m",j,")$coefficients['transition.win12',3]",sep=""))))
  try(eval(parse(text=paste("tlr.models.tib$transition.win.p[",j,"]<-summary(m",j,")$coefficients['transition.win12',4]",sep=""))))      
  
  try(eval(parse(text=paste("tlr.models.tib$aic[",j,"]<-summary(m",j,")$aic",sep=""))))      
}

write.csv(tlr.models.tib,"tlr.models.tib.output.csv")

#Interpretation and Predicted Values#

predicted.values<-data.frame(data$t,data$t2,data$t3,data$focal.tib.win4,data$transition.tib.win12,data$extmob.win2,data$transition.win15)
colnames(predicted.values)<-c("t","t2","t3","focal.tib.win4","transition.tib.win12","extmob.win2","transition.win15")
predicted.values$issue.ethtib.det.predicted.m970 <- predict(m970, predicted.values, type = "response")

predicted.values.nofocal.tib <- predicted.values
predicted.values.nofocal.tib$focal.tib.win4<-0
predicted.values.nofocal.tib$issue.ethtib.det.predicted.m970 <- predict(m970, predicted.values.nofocal.tib, type = "response")

predicted.values<-data.frame(data$t,data$t2,data$t3,data$focal.tib.win4,data$transition.tib.win12,data$extmob.win2,data$transition.win15)
colnames(predicted.values)<-c("t","t2","t3","focal.tib.win4","transition.tib.win12","extmob.win2","transition.win15")
predicted.values$issue.ethtib.det.predicted.m970 <- predict(m970, predicted.values, type = "response")

predicted.values.int<-data.frame(data$t,data$t2,data$t3,data$focal.tib.win4,data$transition.tib.win12,data$extmob.win2,data$transition.win15,data$uprising.tib)
colnames(predicted.values.int)<-c("t","t2","t3","focal.tib.win4","transition.tib.win12","extmob.win2","transition.win15","uprising.tib")
m970int <-glm.nb(issue.ethtib.det ~t+t^2+t^3 + focal.tib.win4 + transition.tib.win12 +  + extmob.win2 + transition.win15 + uprising.tib + uprising.tib*focal.tib.win4 + 1,data=data)
predicted.values.int$issue.ethtib.det.predicted.m970int <- predict(m970int, predicted.values.int, type = "response")

predicted.values.int.nofocal.tib <- predicted.values.int
predicted.values.int.nofocal.tib$focal.tib.win4<-0
predicted.values.int.nofocal.tib$issue.ethtib.det.predicted.m970int <- predict(m970int, predicted.values.int.nofocal.tib, type = "response")

predicted.issue.ethtib.det<-sum(predicted.values$issue.ethtib.det.predicted.m970)
predicted.int.issue.ethtib.det<-sum(predicted.values.int$issue.ethtib.det.predicted.m970int)
predicted.nofocal.tib.issue.ethtib.det<-sum(predicted.values.nofocal.tib$issue.ethtib.det.predicted.m970)
predicted.int.nofocal.tib.issue.ethtib.det<-sum(predicted.values.int.nofocal.tib$issue.ethtib.det.predicted.m970int)
true.issue.ethtib.det<-sum(data$issue.ethtib.det)

pdf('fig3-fiteffect-ethtibdet.pdf', width=10, height=7.5)
years<-c("1998","1999","2000","2001","2002","2003","2004","2005","2006","2007","2008","2009","2010","2011","2012","2013","2014","2015")
t<-c(1,13,25,37,49,61,73,85,97,109,121,133,145,157,169,181,193,205)
par(mfcol=c(1,1))
par(cex.axis=1.15)
par(cex.lab=1.15)
par(cex.main=1.15)
plot(data$t,data$issue.ethtib.det,type="l",xaxt="n", lty=1, lwd=1.5, col="grey40", main="Tibetan Dissident Detentions (ethtib.det)", ylim=c(-3,125),ylab="Count", xlab="")
axis(1, at=t, labels=years, las=2, cex=.6)
lines(predicted.values$t,predicted.values$issue.ethtib.det.predicted.m970,  lty=5, lwd=2, col="firebrick2")
lines(predicted.values.int$t,predicted.values.int$issue.ethtib.det.predicted.m970int,  lty=2, lwd=2, col="dodgerblue4")
legend("topleft",c("Actual Detentions","Predicted Detentions","Predicted Detentions: Interacted Model"),lwd=c(1.5,2,2), lty = c(1,5,2), col=c("grey40","firebrick2","dodgerblue4"), box.lwd=0, cex=.85, bty="n")
points(15, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #D
points(41, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #S
points(75, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #D
points(101, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #S
points(123, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #D
points(135, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #D
points(159, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #D
points(161, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #S
points(195, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) #D
text(15, -4.5, "D", pch=17,lwd=4,cex=.85)
text(41, -4.5, "S", pch=17,lwd=4,cex=.85)
text(75, -4.5, "D", pch=17,lwd=4,cex=.85)
text(101, -4.5, "S", pch=17,lwd=4,cex=.85)
text(123, -4.5, "D", pch=17,lwd=4,cex=.85)
text(135, -4.5, "D", pch=17,lwd=4,cex=.85)
text(159, -4.5, "D", pch=17,lwd=4,cex=.85)
text(161, -4.5, "S", pch=17,lwd=4,cex=.85)
text(195, -4.5, "D", pch=17,lwd=4,cex=.85)
text(.5,113,"D", cex=.85)
text(.5,109,"S", cex=.85)
text(30.5,113,"Anniversary of Dalai Lama Exile", cex=.85)
text(34.25,109,"Anniversary of Seventeen Point Plan", cex=.85)
points(128, -1.5, col = "grey70", pch=17,lwd=4,cex=1.25) 
text(128, -4.5, "1", pch=17,lwd=4,cex=.85)
text(.5,105,"1", cex=.85)
text(19.25,105,"Beijing Olympics", cex=.85)
dev.off()

#Sensitivity Analysis Figure#

tlr.models<-read.csv("tlr.models.output.csv")
tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen.win.coeff>0]<-tlr.models$focal.gen.win.p/2
tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen.win.coeff<0]<-1-(tlr.models$focal.gen.win.p/2)

tlr.models.tib<-read.csv("tlr.models.tib.output.csv")
tlr.models.tib$focal.tib.win.p.onesided[tlr.models.tib$focal.tib.win.coeff>0]<-tlr.models.tib$focal.tib.win.p/2
tlr.models.tib$focal.tib.win.p.onesided[tlr.models.tib$focal.tib.win.coeff<0]<-1-(tlr.models.tib$focal.tib.win.p/2)

pdf('fig3-robustness.pdf', width=10, height=3.75)
par(mfcol=c(1,3))
plot(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win3" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win3" & tlr.models$dv=="issue.dem.ext1.det"], col="grey85", main="Democratic (dem.det)",xlim=c(0,.055),ylim=c(.6,1.8),pch=16,cex=.3,xlab="p-value",ylab="Coefficient Estimate of Focal Events (focal)")
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win4" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win4" & tlr.models$dv=="issue.dem.ext1.det"], col="firebrick2", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win2" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2" & tlr.models$dv=="issue.dem.ext1.det"], col="dodgerblue3", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win3.alt" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext1.det"], col="grey65", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win4.alt" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win4.alt" & tlr.models$dv=="issue.dem.ext1.det"], col="firebrick4", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext1.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext1.det"], col="dodgerblue4", pch=16, cex=.3)
abline(v=.1,lty=3,lwd=1)
abline(v=.05,lty=3,lwd=1)
abline(v=.01,lty=3,lwd=1)
points(0.014,  0.736, pch=17,col="grey40",lwd=2,cex=1.25)
points(7.07e-05,  1.169, pch=17,col="grey40",lwd=2,cex=1.25)
points(0.000476,  0.913, pch=17,col="grey40",lwd=2,cex=1.25)
points(0.0000487504175423563,  .9797, pch=1,col="black",lwd=1.5,cex=1.25)
legend("topright",c("Window = 4 Months","Window = 3 Months","Window = 2 Months","Window = 4 Months (focal excl)","Window = 3 Months (focal excl)","Window = 2 Months (focal excl)", "Estimate from Table 1", "Minimum AIC Estimate"),pch=c(16,16,16,16,16,16,17,1), col=c("firebrick2","grey85","dodgerblue3","firebrick4","grey65","dodgerblue4","grey40","black"), box.lwd=0, cex=.85, bty="n")
plot(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win3" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win3" & tlr.models$dv=="issue.dem.ext2.det"], col="grey85", main="Democratic (dem.det.ext)",xlim=c(0,.055),ylim=c(.3,.8),pch=16,cex=.3,xlab="p-value",ylab="Coefficient Estimate of Focal Events (focal)")
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win4" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win4" & tlr.models$dv=="issue.dem.ext2.det"], col="firebrick2", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win2" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2" & tlr.models$dv=="issue.dem.ext2.det"], col="dodgerblue3", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win3.alt" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext2.det"], col="grey65", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win4.alt" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win4.alt" & tlr.models$dv=="issue.dem.ext2.det"], col="firebrick4", pch=16, cex=.3)
points(tlr.models$focal.gen.win.p.onesided[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext2.det"],tlr.models$focal.gen.win.coeff[tlr.models$focal.gen=="focal.gen.win2.alt" & tlr.models$dv=="issue.dem.ext2.det"], col="dodgerblue4", pch=16, cex=.3)
abline(v=.1,lty=3,lwd=1)
abline(v=.05,lty=3,lwd=1)
abline(v=.01,lty=3,lwd=1)
points(0.00864, 0.420, pch=17,col="grey40",lwd=2,cex=1.25)
points(0.000337,  0.577 , pch=17,col="grey40",lwd=2,cex=1.25)
points(0.000874,  0.476, pch=17,col="grey40",lwd=2,cex=1.25)
points(0.0000475898353745889,  0.521000831, pch=1,col="black",lwd=1.5,cex=1.25)
legend("topright",c("Window = 4 Months","Window = 3 Months","Window = 2 Months","Window = 4 Months (focal excl)","Window = 3 Months (focal excl)","Window = 2 Months (focal excl)", "Estimate from Table 1", "Minimum AIC Estimate"),pch=c(16,16,16,16,16,16,17,1), col=c("firebrick2","grey85","dodgerblue3","firebrick4","grey65","dodgerblue4","grey40","black"), box.lwd=0, cex=.85, bty="n")
plot(tlr.models.tib$focal.tib.win.p.onesided[tlr.models.tib$focal.tib=="focal.tib.win3" & tlr.models.tib$dv=="issue.ethtib.det"],tlr.models.tib$focal.tib.win.coeff[tlr.models.tib$focal.tib=="focal.tib.win3" & tlr.models.tib$dv=="issue.ethtib.det"], col="grey85", main="Tibet (ethtib.det)",xlim=c(0,.11),ylim=c(.5,1.5),pch=16,cex=.3,xlab="p-value",ylab="Coefficient Estimate of Focal Events (focal.tib)")
points(tlr.models.tib$focal.tib.win.p.onesided[tlr.models.tib$focal.tib=="focal.tib.win4" & tlr.models.tib$dv=="issue.ethtib.det"],tlr.models.tib$focal.tib.win.coeff[tlr.models.tib$focal.tib=="focal.tib.win4" & tlr.models.tib$dv=="issue.ethtib.det"], col="firebrick2", pch=16, cex=.3)
points(tlr.models.tib$focal.tib.win.p.onesided[tlr.models.tib$focal.tib=="focal.tib.win2" & tlr.models.tib$dv=="issue.ethtib.det"],tlr.models.tib$focal.tib.win.coeff[tlr.models.tib$focal.tib=="focal.tib.win2" & tlr.models.tib$dv=="issue.ethtib.det"], col="dodgerblue3", pch=16, cex=.3)
points(tlr.models.tib$focal.tib.win.p.onesided[tlr.models.tib$focal.tib=="focal.tib.win3.alt" & tlr.models.tib$dv=="issue.ethtib.det"],tlr.models.tib$focal.tib.win.coeff[tlr.models.tib$focal.tib=="focal.tib.win3.alt" & tlr.models.tib$dv=="issue.ethtib.det"], col="grey65", pch=16, cex=.3)
points(tlr.models.tib$focal.tib.win.p.onesided[tlr.models.tib$focal.tib=="focal.tib.win4.alt" & tlr.models.tib$dv=="issue.ethtib.det"],tlr.models.tib$focal.tib.win.coeff[tlr.models.tib$focal.tib=="focal.tib.win4.alt" & tlr.models.tib$dv=="issue.ethtib.det"], col="firebrick4", pch=16, cex=.3)
points(tlr.models.tib$focal.tib.win.p.onesided[tlr.models.tib$focal.tib=="focal.tib.win2.alt" & tlr.models.tib$dv=="issue.ethtib.det"],tlr.models.tib$focal.tib.win.coeff[tlr.models.tib$focal.tib=="focal.tib.win2.alt" & tlr.models.tib$dv=="issue.ethtib.det"], col="dodgerblue4", pch=16, cex=.3)
abline(v=.1,lty=3,lwd=1)
abline(v=.05,lty=3,lwd=1)
abline(v=.01,lty=3,lwd=1)
points(0.005315797,  0.700563915, pch=1,col="black",lwd=1.5,cex=1.25)
legend("topright",c("Window = 4 Months","Window = 3 Months","Window = 2 Months","Window = 4 Months (focal excl)","Window = 3 Months (focal excl)","Window = 2 Months (focal excl)", "Estimate from Table 1", "Minimum AIC Estimate"),pch=c(16,16,16,16,16,16,17,1), col=c("firebrick2","grey85","dodgerblue3","firebrick4","grey65","dodgerblue4","grey40","black"), box.lwd=0, cex=.85, bty="n")
dev.off()

####SEVERITY/PROCESS ANALYSIS####

data.month<-read.csv("monthly.data.v12-19-17.csv")
cecc<-read.csv("cecc.raw.csv")

#Variable Creation and Merges#

cecc$year<- substr(cecc$date.of.detention, 1, 4)
cecc$month<- substr(cecc$date.of.detention, 6, 7)
cecc$month<- as.numeric(cecc$month)
cecc$day<- substr(cecc$date.of.detention, 9, 10)
cecc <- within(cecc, month.label<-paste(year, "m", month, sep=""))

cecc$issue.dem<-0
cecc$issue.dem[grepl("dem", cecc$issue.category)==TRUE]<-1
cecc$issue.dem<-as.numeric(cecc$issue.dem)
sum(cecc$issue.dem)

cecc$issue.dem.ext1<-0
cecc$issue.dem.ext1[grepl("dem", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext1[grepl("6489", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext1<-as.numeric(cecc$issue.dem.ext1)
sum(cecc$issue.dem.ext1)

cecc$issue.dem.ext2<-0
cecc$issue.dem.ext2[grepl("dem", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("6489", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("spch", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("civil", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("info", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("assoc", cecc$issue.category)==TRUE]<-1
cecc$issue.dem.ext2[grepl("Uyghur", cecc$ethnic.group)==TRUE]<-0
cecc$issue.dem.ext2[grepl("Tibetan", cecc$ethnic.group)==TRUE]<-0
cecc$issue.dem.ext2[grepl("FG", cecc$issue.category)==TRUE]<-0
cecc$issue.dem.ext2<-as.numeric(cecc$issue.dem.ext2)
sum(cecc$issue.dem.ext2)

cecc$issue.ethtib<-0
cecc$issue.ethtib[grepl("Tibetan", cecc$ethnic.group)==TRUE]<-1
cecc$issue.ethtib<-as.numeric(cecc$issue.ethtib)
sum(cecc$issue.ethtib)

data.diss<-subset(cecc, cecc$month!="mm" & cecc$year>1997 & cecc$year<2015)

data.diss$female<-NA
data.diss$female[grepl("F", data.diss$sex)==TRUE]<-1
data.diss$female[grepl("M", data.diss$sex)==TRUE]<-0
data.diss$female<-as.numeric(data.diss$female)

data.diss$religion.buddhist<-0
data.diss$religion.buddhist[grepl("uddhist", data.diss$religion)==TRUE]<-1
data.diss$religion.christian<-0
data.diss$religion.christian[grepl("hurch", data.diss$religion)==TRUE]<-1
data.diss$religion.christian[grepl("rotestant", data.diss$religion)==TRUE]<-1
data.diss$religion.falungong<-0
data.diss$religion.falungong[grepl("alun", data.diss$religion)==TRUE]<-1
data.diss$religion.muslim<-0
data.diss$religion.muslim[grepl("uslim", data.diss$religion)==TRUE]<-1

data.diss$prior<-0
data.diss$prior[grepl("previous", data.diss$short.summary)==TRUE]<-1

data.diss$occupation.farmer<-0
data.diss$occupation.farmer[grepl("armer", data.diss$occupation)==TRUE]<-1
data.diss$occupation.teacher<-0
data.diss$occupation.teacher[grepl("teacher", data.diss$occupation)==TRUE]<-1
data.diss$occupation.teacher[grepl("professor", data.diss$occupation)==TRUE]<-1
data.diss$occupation.student<-0
data.diss$occupation.student[grepl("student", data.diss$occupation)==TRUE]<-1
data.diss$occupation.worker<-0
data.diss$occupation.worker[grepl("worker", data.diss$occupation)==TRUE]<-1
data.diss$occupation.worker[grepl("staff", data.diss$occupation)==TRUE]<-1
data.diss$occupation.worker[grepl("factory", data.diss$occupation)==TRUE]<-1
data.diss$occupation.legal<-0
data.diss$occupation.legal[grepl("lawyer", data.diss$occupation)==TRUE]<-1
data.diss$occupation.legal[grepl("legal", data.diss$occupation)==TRUE]<-1
data.diss$occupation.journalist<-0
data.diss$occupation.journalist[grepl("ournalist", data.diss$occupation)==TRUE]<-1
data.diss$occupation.journalist[grepl("editor", data.diss$occupation)==TRUE]<-1
data.diss$occupation.journalist[grepl("writer", data.diss$occupation)==TRUE]<-1
data.diss$occupation.journalist[grepl("publish", data.diss$occupation)==TRUE]<-1
data.diss$occupation.journalist[grepl("artist", data.diss$occupation)==TRUE]<-1
data.diss$occupation.religious<-0
data.diss$occupation.religious[grepl("pastor", data.diss$occupation)==TRUE]<-1
data.diss$occupation.religious[grepl("priest", data.diss$occupation)==TRUE]<-1
data.diss$occupation.religious[grepl("monk", data.diss$occupation)==TRUE]<-1

data.diss$det.date<-data.diss$date.of.detention
data.diss$det.year<-as.numeric(substr(data.diss$date.of.detention, 1, 4))
data.diss$det.month<-as.numeric(substr(data.diss$date.of.detention, 6, 7))
data.diss$det.day<-as.numeric(substr(data.diss$date.of.detention, 9, 10))
data.diss <- within(data.diss, det.month.label<-paste(det.year, "m", det.month, sep=""))
data.diss$det.date.num<-(365*(data.diss$det.year-1))+(30*(data.diss$det.month-1))+data.diss$det.day

data.diss$rel.date<-data.diss$actual.date.released
data.diss$rel.year<-as.numeric(substr(data.diss$actual.date.released, 1, 4))
data.diss$rel.month<-as.numeric(substr(data.diss$actual.date.released, 6, 7))
data.diss$rel.day<-as.numeric(substr(data.diss$actual.date.released, 9, 10))
data.diss <- within(data.diss, rel.month.label<-paste(rel.year, "m", rel.month, sep=""))
data.diss$rel.date.num<-(365*(data.diss$rel.year-1))+(30*(data.diss$rel.month-1))+data.diss$rel.day

data.diss$arrest.date<-data.diss$formal.arrest.date
data.diss$arrest.year<-substr(data.diss$formal.arrest.date, 1, 4)
data.diss$arrest.month<-substr(data.diss$formal.arrest.date, 6, 7)
data.diss$arrest.day<-substr(data.diss$formal.arrest.date, 9, 10)
data.diss <- within(data.diss, arrest.month.label<-paste(arrest.year, "m", arrest.month, sep=""))

data.diss$trial.date<-data.diss$trial.date
data.diss$trial.year<-substr(data.diss$trial.date, 1, 4)
data.diss$trial.month<-substr(data.diss$trial.date, 6, 7)
data.diss$trial.day<-substr(data.diss$trial.date, 9, 10)
data.diss <- within(data.diss, trial.month.label<-paste(trial.year, "m", trial.month, sep=""))

data.diss$sentence.date<-data.diss$sentence.date
data.diss$sentence.year<-substr(data.diss$sentence.date, 1, 4)
data.diss$sentence.month<-substr(data.diss$sentence.date, 6, 7)
data.diss$sentence.day<-substr(data.diss$sentence.date, 9, 10)
data.diss <- within(data.diss, sentence.month.label<-paste(sentence.year, "m", sentence.month, sep=""))

data.diss$sentenceend.date<-data.diss$sent..ends.per.PRC
data.diss$sentenceend.year<-substr(data.diss$sent..ends.per.PRC, 1, 4)
data.diss$sentenceend.month<-substr(data.diss$sent..ends.per.PRC, 6, 7)
data.diss$sentenceend.day<-substr(data.diss$sent..ends.per.PRC, 9, 10)
data.diss <- within(data.diss, sentenceend.month.label<-paste(sentenceend.year, "m", sentenceend.month, sep=""))

data.diss$appeal.date<-data.diss$appeal.date
data.diss$appeal.year<-substr(data.diss$appeal.date, 1, 4)
data.diss$appeal.month<-substr(data.diss$appeal.date, 6, 7)
data.diss$appeal.day<-substr(data.diss$appeal.date, 9, 10)
data.diss <- within(data.diss, appeal.month.label<-paste(appeal.year, "m", appeal.month, sep=""))

data.diss$appealrul.date<-data.diss$appeal.ruling.date
data.diss$appealrul.year<-substr(data.diss$appeal.ruling.date, 1, 4)
data.diss$appealrul.month<-substr(data.diss$appeal.ruling.date, 6, 7)
data.diss$appealrul.day<-substr(data.diss$appeal.ruling.date, 9, 10)
data.diss <- within(data.diss, appealrul.month.label<-paste(appealrul.year, "m", appealrul.month, sep=""))

data.diss$det.prov <- data.diss$province.where.imprisoned..or.detained
data.diss$det.pref <- data.diss$prefecture.where.imprisoned..or.detained
data.diss$det.county <- data.diss$county.where.imprisoned..or.detained

data.diss$proc.chg<-0
data.diss$proc.chg[grepl("chg", data.diss$legal.process)==TRUE]<-1
data.diss$proc.admin<-0
data.diss$proc.admin[grepl("admin", data.diss$legal.process)==TRUE]<-1
data.diss$proc.psb<-0
data.diss$proc.psb[grepl("PSB", data.diss$legal.process)==TRUE]<-1
data.diss$proc.rtl<-0
data.diss$proc.rtl[grepl("RTL", data.diss$legal.process)==TRUE]<-1
data.diss$proc.dec<-0
data.diss$proc.dec[grepl("DEC", data.diss$detention.status)==TRUE]<-1
data.diss$proc.tort<-0
data.diss$proc.tort[grepl("tort", data.diss$short.summary)==TRUE]<-1
data.diss$proc.tort[grepl("beat", data.diss$short.summary)==TRUE]<-1
data.diss$proc.tort[grepl("nitial record", data.diss$short.summary)==TRUE]<-NA

data.diss$days.served<- data.diss$rel.date.num-data.diss$det.date.num
data.diss$days.served[grepl("DET", data.diss$detention.status)==TRUE]<- 735137-data.diss$det.date.num

data.diss$det.short<-NA
data.diss$det.short[(data.diss$current..or.last..sentence..or.time.served...days<32)==TRUE]<-1
data.diss$det.short[grepl("DET", data.diss$detention.status)==TRUE &(data.diss$det.year<2014)==TRUE]<-0
data.diss$det.short[(data.diss$days.served<32)==TRUE]<-1
data.diss$det.short[(data.diss$days.served>32)==TRUE]<-0
data.diss$det.short[(data.diss$current..or.last..sentence..or.time.served...years>.01)==TRUE]<-0
data.diss$det.short[(data.diss$current..or.last..sentence..or.time.served...months>1)==TRUE]<-0
data.diss$det.short[(data.diss$current..or.last..sentence..or.time.served...days>31)==TRUE]<-0
data.diss$det.short[grepl("HOUSE", data.diss$detention.status)==TRUE]<-1
data.diss$det.short[grepl("chg", data.diss$legal.process)==TRUE]<-0

data.diss<-merge(data.diss,data.month,by.x="month.label",by.y="month.label",all=TRUE)
data.diss<-subset(data.diss, is.na(data.diss$CECC.record.number)==FALSE)
data.diss.issue.dem.ext1<-subset(data.diss, (data.diss$issue.dem.ext1==1)==TRUE)
data.diss.issue.dem.ext2<-subset(data.diss, (data.diss$issue.dem.ext2==1)==TRUE)
write.csv(data.diss.issue.dem.ext2,"data.diss.issue.dem.ext2.csv")

m1a.proc.chg <- zelig(proc.chg ~ focal.gen.win3, data=data.diss.issue.dem.ext2, model="logit")  
summary(m1a.proc.chg)
m1b.proc.chg <- zelig(proc.chg ~ focal.gen.win3, data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m1b.proc.chg)
m1a.det.short <- zelig(det.short ~ focal.gen.win3, data=data.diss.issue.dem.ext2, model="logit")  
summary(m1a.det.short)
m1b.det.short <- zelig(det.short ~ focal.gen.win3, data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m1b.det.short)

m2a.proc.chg <- zelig(proc.chg ~ focal.gen.win3 + as.factor(det.prov), data=data.diss.issue.dem.ext2, model="logit")  
summary(m2a.proc.chg)
m2b.proc.chg <- zelig(proc.chg ~ focal.gen.win3 + as.factor(det.prov), data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m2b.proc.chg)
m2a.det.short <- zelig(det.short ~ focal.gen.win3 + as.factor(det.prov) , data=data.diss.issue.dem.ext2, model="logit")  
summary(m2a.det.short)
m2b.det.short <- zelig(det.short ~ focal.gen.win3 + as.factor(det.prov), data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m2b.det.short)

m3a.proc.chg <- zelig(proc.chg ~ focal.gen.win3 + as.factor(det.prov) + religion.buddhist + religion.christian + religion.muslim + religion.falungong + occupation.farmer + occupation.teacher + occupation.student + occupation.worker + occupation.legal + occupation.journalist + occupation.religious, data=data.diss.issue.dem.ext2, model="logit")  
summary(m3a.proc.chg)
m3b.proc.chg <- zelig(proc.chg ~ focal.gen.win3 + as.factor(det.prov) + religion.buddhist + religion.christian + religion.muslim + religion.falungong + occupation.farmer + occupation.teacher + occupation.student + occupation.worker + occupation.legal + occupation.journalist + occupation.religious, data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m3b.proc.chg)
m3a.det.short <- zelig(det.short ~ focal.gen.win3 + as.factor(det.prov) + religion.buddhist + religion.christian + religion.muslim + religion.falungong + occupation.farmer + occupation.teacher + occupation.student + occupation.worker + occupation.legal + occupation.journalist + occupation.religious , data=data.diss.issue.dem.ext2, model="logit")  
summary(m3a.det.short)
m3b.det.short <- zelig(det.short ~ focal.gen.win3 + as.factor(det.prov) + religion.buddhist + religion.christian + religion.muslim + religion.falungong + occupation.farmer + occupation.teacher + occupation.student + occupation.worker + occupation.legal + occupation.journalist + occupation.religious, data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m3b.det.short)

m1a.proc.chg.alt <- zelig(proc.chg ~ focal.gen.win3.alt, data=data.diss.issue.dem.ext2, model="logit")  
summary(m1a.proc.chg.alt)
m1b.proc.chg.alt <- zelig(proc.chg ~ focal.gen.win3.alt, data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m1b.proc.chg.alt)
m1a.det.short.alt <- zelig(det.short ~ focal.gen.win3.alt, data=data.diss.issue.dem.ext2, model="logit")  
summary(m1a.det.short.alt)
m1b.det.short.alt <- zelig(det.short ~ focal.gen.win3.alt, data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m1b.det.short.alt)

m2a.proc.chg.alt <- zelig(proc.chg ~ focal.gen.win3.alt + as.factor(det.prov), data=data.diss.issue.dem.ext2, model="logit")  
summary(m2a.proc.chg.alt)
m2b.proc.chg.alt <- zelig(proc.chg ~ focal.gen.win3.alt + as.factor(det.prov), data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m2b.proc.chg.alt)
m2a.det.short.alt <- zelig(det.short ~ focal.gen.win3.alt + as.factor(det.prov) , data=data.diss.issue.dem.ext2, model="logit")  
summary(m2a.det.short.alt)
m2b.det.short.alt <- zelig(det.short ~ focal.gen.win3.alt + as.factor(det.prov), data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m2b.det.short.alt)

m3a.proc.chg.alt <- zelig(proc.chg ~ focal.gen.win3.alt + as.factor(det.prov) + religion.buddhist + religion.christian + religion.muslim + religion.falungong + occupation.farmer + occupation.teacher + occupation.student + occupation.worker + occupation.legal + occupation.journalist + occupation.religious, data=data.diss.issue.dem.ext2, model="logit")  
summary(m3a.proc.chg.alt)
m3b.proc.chg.alt <- zelig(proc.chg ~ focal.gen.win3.alt + as.factor(det.prov) + religion.buddhist + religion.christian + religion.muslim + religion.falungong + occupation.farmer + occupation.teacher + occupation.student + occupation.worker + occupation.legal + occupation.journalist + occupation.religious, data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m3b.proc.chg.alt)
m3a.det.short.alt <- zelig(det.short ~ focal.gen.win3.alt + as.factor(det.prov) + religion.buddhist + religion.christian + religion.muslim + religion.falungong + occupation.farmer + occupation.teacher + occupation.student + occupation.worker + occupation.legal + occupation.journalist + occupation.religious , data=data.diss.issue.dem.ext2, model="logit")  
summary(m3a.det.short.alt)
m3b.det.short.alt <- zelig(det.short ~ focal.gen.win3.alt + as.factor(det.prov) + religion.buddhist + religion.christian + religion.muslim + religion.falungong + occupation.farmer + occupation.teacher + occupation.student + occupation.worker + occupation.legal + occupation.journalist + occupation.religious, data=data.diss.issue.dem.ext2, robust=TRUE, model="ls")  
summary(m3b.det.short.alt) 


####DATA RECONCILIATION####

chrd<-subset(chrd, chrd$validation==1)

chrd$female<-0
chrd$female[grepl("female", chrd$gender)==TRUE]<-1

chrd$year<-substr(chrd$det.date, 1, 4)
chrd$month<-substr(chrd$det.date, 6, 7)
chrd$month<-as.numeric(chrd$month)
chrd$day<-substr(chrd$det.date, 9, 10)
chrd$day<-as.numeric(chrd$day)
chrd<-within(chrd, month.label<-paste(year, "m", month, sep=""))

chrd$det.type.missing[chrd$det.type==""] <- 1
chrd$det.type.crim<-0
chrd$det.type.crim[grepl("Criminal", chrd$det.type)==TRUE]<-1
chrd$det.type.crim[chrd$det.type.missing==1]<-NA
chrd$det.type.adm<-0
chrd$det.type.adm[grepl("Administrative", chrd$det.type)==TRUE]<-1
chrd$det.type.adm[chrd$det.type.missing==1]<-NA
chrd$det.type.other<-1
chrd$det.type.other[grepl("Criminal", chrd$det.type)==TRUE]<-0
chrd$det.type.other[grepl("Administrative", chrd$det.type)==TRUE]<-0
chrd$det.type.other[chrd$det.type.missing==1]<-NA

chrd$det.place.missing[chrd$det.place==""] <- 1
chrd$det.place.detcen<-0
chrd$det.place.detcen[grepl("Detention", chrd$det.place)==TRUE]<-1
chrd$det.place.detcen[chrd$det.place.missing==1]<-NA
chrd$det.place.blackjail<-0
chrd$det.place.blackjail[grepl("lack", chrd$det.place)==TRUE]<-1
chrd$det.place.blackjail[chrd$det.place.missing==1]<-NA
chrd$det.place.psychiatric<-0
chrd$det.place.psychiatric[grepl("sychiatric", chrd$det.place)==TRUE]<-1
chrd$det.place.psychiatric[chrd$det.place.missing==1]<-NA
chrd$det.place.home<-0
chrd$det.place.home[grepl("ome", chrd$det.place)==TRUE]<-1
chrd$det.place.home[chrd$det.place.missing==1]<-NA
chrd$det.place.motel<-0
chrd$det.place.motel[grepl("otel", chrd$det.place)==TRUE]<-1
chrd$det.place.motel[chrd$det.place.missing==1]<-NA
chrd$det.place.guest<-0
chrd$det.place.guest[grepl("uesthouse", chrd$det.place)==TRUE]<-1
chrd$det.place.guest[chrd$det.place.missing==1]<-NA
chrd$det.place.prison<-0
chrd$det.place.prison[grepl("Prison", chrd$det.place)==TRUE]<-1
chrd$det.place.prison[chrd$det.place.missing==1]<-NA
chrd$det.place.drug<-0
chrd$det.place.drug[grepl("Drug", chrd$det.place)==TRUE]<-1
chrd$det.place.drug[chrd$det.place.missing==1]<-NA
chrd$det.place.other<-1
chrd$det.place.other[grepl("Detention", chrd$det.place)==TRUE]<-0
chrd$det.place.other[chrd$det.place.missing==1]<-NA

chrd$det.place.informal<-0
chrd$det.place.informal[grepl("lack", chrd$det.place)==TRUE]<-1
chrd$det.place.informal[grepl("sychiatric", chrd$det.place)==TRUE]<-1
chrd$det.place.informal[grepl("ome", chrd$det.place)==TRUE]<-1
chrd$det.place.informal[grepl("otel", chrd$det.place)==TRUE]<-1
chrd$det.place.informal[grepl("uesthouse", chrd$det.place)==TRUE]<-1
chrd$det.place.informal[grepl("rison", chrd$det.place)==TRUE]<-1
chrd$det.place.informal[grepl("rug", chrd$det.place)==TRUE]<-1
chrd$det.place.informal[chrd$det.place.missing==1]<-NA
sum(chrd$det.place.informal, na.rm=TRUE)

chrd$pun.days<-NA
chrd$pun.days[grepl("1 month", chrd$pun.length)==TRUE]<-30
chrd$pun.days[grepl("2 month", chrd$pun.length)==TRUE]<-60
chrd$pun.days[grepl("3 month", chrd$pun.length)==TRUE]<-90
chrd$pun.days[grepl("4 month", chrd$pun.length)==TRUE]<-120
chrd$pun.days[grepl("5 month", chrd$pun.length)==TRUE]<-150
chrd$pun.days[grepl("6 month", chrd$pun.length)==TRUE]<-180
chrd$pun.days[grepl("7 month", chrd$pun.length)==TRUE]<-210
chrd$pun.days[grepl("8 month", chrd$pun.length)==TRUE]<-240
chrd$pun.days[grepl("9 month", chrd$pun.length)==TRUE]<-270
chrd$pun.days[grepl("10 month", chrd$pun.length)==TRUE]<-300
chrd$pun.days[grepl("11 month", chrd$pun.length)==TRUE]<-330
chrd$pun.days[grepl("12 month", chrd$pun.length)==TRUE]<-360
chrd$pun.days[grepl("13 month", chrd$pun.length)==TRUE]<-390
chrd$pun.days[grepl("14 month", chrd$pun.length)==TRUE]<-420
chrd$pun.days[grepl("15 month", chrd$pun.length)==TRUE]<-450
chrd$pun.days[grepl("16 month", chrd$pun.length)==TRUE]<-480
chrd$pun.days[grepl("17 month", chrd$pun.length)==TRUE]<-510
chrd$pun.days[grepl("18 month", chrd$pun.length)==TRUE]<-540
chrd$pun.days[grepl("19 month", chrd$pun.length)==TRUE]<-570
chrd$pun.days[grepl("20 month", chrd$pun.length)==TRUE]<-600
chrd$pun.days[grepl("21 month", chrd$pun.length)==TRUE]<-630
chrd$pun.days[grepl("22 month", chrd$pun.length)==TRUE]<-660
chrd$pun.days[grepl("23 month", chrd$pun.length)==TRUE]<-690
chrd$pun.days[grepl("24 month", chrd$pun.length)==TRUE]<-730
chrd$pun.days[grepl("34 month", chrd$pun.length)==TRUE]<-1020

chrd$pun.days[grepl("1 year", chrd$pun.length)==TRUE]<-365
chrd$pun.days[grepl("1.5 years", chrd$pun.length)==TRUE]<-540
chrd$pun.days[grepl("2 year", chrd$pun.length)==TRUE]<-730
chrd$pun.days[grepl("3 year", chrd$pun.length)==TRUE]<-1095
chrd$pun.days[grepl("3.5 year", chrd$pun.length)==TRUE]<-1095
chrd$pun.days[grepl("10 year", chrd$pun.length)==TRUE]<-3650
chrd$pun.days[grepl("10.5 year", chrd$pun.length)==TRUE]<-3650

chrd$pun.days[grepl("1 days", chrd$pun.length)==TRUE]<-1
chrd$pun.days[grepl("2 days", chrd$pun.length)==TRUE]<-2
chrd$pun.days[grepl("3 days", chrd$pun.length)==TRUE]<-3
chrd$pun.days[grepl("4 days", chrd$pun.length)==TRUE]<-4
chrd$pun.days[grepl("5 days", chrd$pun.length)==TRUE]<-5
chrd$pun.days[grepl("6 days", chrd$pun.length)==TRUE]<-6
chrd$pun.days[grepl("7 days", chrd$pun.length)==TRUE]<-7
chrd$pun.days[grepl("8 days", chrd$pun.length)==TRUE]<-8
chrd$pun.days[grepl("9 days", chrd$pun.length)==TRUE]<-9
chrd$pun.days[grepl("10 days", chrd$pun.length)==TRUE]<-10
chrd$pun.days[grepl("11 days", chrd$pun.length)==TRUE]<-11
chrd$pun.days[grepl("12 days", chrd$pun.length)==TRUE]<-12
chrd$pun.days[grepl("13 days", chrd$pun.length)==TRUE]<-13
chrd$pun.days[grepl("14 days", chrd$pun.length)==TRUE]<-14
chrd$pun.days[grepl("15 days", chrd$pun.length)==TRUE]<-15
chrd$pun.days[grepl("16 days", chrd$pun.length)==TRUE]<-16
chrd$pun.days[grepl("17 days", chrd$pun.length)==TRUE]<-17
chrd$pun.days[grepl("18 days", chrd$pun.length)==TRUE]<-18
chrd$pun.days[grepl("19 days", chrd$pun.length)==TRUE]<-19
chrd$pun.days[grepl("20 days", chrd$pun.length)==TRUE]<-20
chrd$pun.days[grepl("21 days", chrd$pun.length)==TRUE]<-21
chrd$pun.days[grepl("22 days", chrd$pun.length)==TRUE]<-22
chrd$pun.days[grepl("23 days", chrd$pun.length)==TRUE]<-23
chrd$pun.days[grepl("24 days", chrd$pun.length)==TRUE]<-24
chrd$pun.days[grepl("25 days", chrd$pun.length)==TRUE]<-25
chrd$pun.days[grepl("26 days", chrd$pun.length)==TRUE]<-26
chrd$pun.days[grepl("27 days", chrd$pun.length)==TRUE]<-27
chrd$pun.days[grepl("28 days", chrd$pun.length)==TRUE]<-28
chrd$pun.days[grepl("29 days", chrd$pun.length)==TRUE]<-29
chrd$pun.days[grepl("30 days", chrd$pun.length)==TRUE]<-30
chrd$pun.days[grepl("31 days", chrd$pun.length)==TRUE]<-31
chrd$pun.days[grepl("32 days", chrd$pun.length)==TRUE]<-32
chrd$pun.days[grepl("33 days", chrd$pun.length)==TRUE]<-33
chrd$pun.days[grepl("34 days", chrd$pun.length)==TRUE]<-34
chrd$pun.days[grepl("35 days", chrd$pun.length)==TRUE]<-35
chrd$pun.days[grepl("36 days", chrd$pun.length)==TRUE]<-36
chrd$pun.days[grepl("37 days", chrd$pun.length)==TRUE]<-37
chrd$pun.days[grepl("45 days", chrd$pun.length)==TRUE]<-45
chrd$pun.days.missing[chrd$pun.length==""] <- 1
chrd$pun.days[chrd$pun.days.missing==1]<-NA

chrd$pun.long<-0
chrd$pun.long[chrd$pun.days>29]<-1

chrd$crime.missing[chrd$crime==""] <- 1
chrd$crime.cult<-0
chrd$crime.cult[grepl("cult", chrd$crime)==TRUE]<-1
chrd$crime.cult[chrd$crime.missing==1]<-NA
chrd$crime.petition<-0
chrd$crime.petition[grepl("Petition", chrd$crime)==TRUE]<-1
chrd$crime.petition[grepl("official", chrd$crime)==TRUE]<-1
chrd$crime.petition[chrd$crime.missing==1]<-NA
chrd$crime.subversion<-0
chrd$crime.subversion[grepl("ubver", chrd$crime)==TRUE]<-1
chrd$crime.subversion[chrd$crime.missing==1]<-NA
chrd$crime.order<-0
chrd$crime.order[grepl("rder", chrd$crime)==TRUE]<-1
chrd$crime.order[grepl("ssembly", chrd$crime)==TRUE]<-1
chrd$crime.order[chrd$crime.missing==1]<-NA
chrd$crime.other<-1
chrd$crime.other[grepl("cult", chrd$crime)==TRUE]<-0
chrd$crime.other[grepl("Petition", chrd$crime)==TRUE]<-0
chrd$crime.other[grepl("official", chrd$crime)==TRUE]<-0
chrd$crime.other[grepl("ubver", chrd$crime)==TRUE]<-0
chrd$crime.other[grepl("rder", chrd$crime)==TRUE]<-0
chrd$crime.other[grepl("ssembly", chrd$crime)==TRUE]<-0
chrd$crime.other[chrd$crime.missing==1]<-NA

chrd$focal.gen.win1<-0
chrd$focal.gen.win1[chrd$month==6]<-1
chrd$focal.gen.win2<-0
chrd$focal.gen.win2[chrd$month==5]<-1
chrd$focal.gen.win2[chrd$month==6]<-1
chrd$focal.gen.win3<-0
chrd$focal.gen.win3[chrd$month==4]<-1
chrd$focal.gen.win3[chrd$month==5]<-1
chrd$focal.gen.win3[chrd$month==6]<-1

chrd$focal.gen.win1<-0
chrd$focal.gen.win1[chrd$month==6]<-1
chrd$focal.gen.win2<-0
chrd$focal.gen.win2[chrd$month==5]<-1
chrd$focal.gen.win2[chrd$month==6]<-1
chrd$focal.gen.win3<-0
chrd$focal.gen.win3[chrd$month==4]<-1
chrd$focal.gen.win3[chrd$month==5]<-1
chrd$focal.gen.win3[chrd$month==6]<-1

chrd$extmob.win1<-0
chrd$extmob.win1[chrd$month==9]<-1
chrd$extmob.win1[chrd$month==10]<-1
chrd$extmob.win2<-0
chrd$extmob.win2[chrd$month==9]<-1
chrd$extmob.win2[chrd$month==10]<-1
chrd$extmob.win2[chrd$month==11]<-1

chrd$issue.dem<-0 
chrd$issue.dem[grepl("dem", chrd$issue.category)==TRUE]<-1
chrd$issue.dem[is.na(chrd$issue.category)==TRUE]<-NA
chrd$issue.dem<-as.numeric(chrd$issue.dem)
sum(chrd$issue.dem)

chrd$issue.dem.ext1<-0
chrd$issue.dem.ext1[grepl("dem", chrd$issue.category)==TRUE]<-1
chrd$issue.dem.ext1[grepl("6489", chrd$issue.category)==TRUE]<-1
chrd$issue.dem.ext1[is.na(chrd$issue.category)==TRUE]<-NA
chrd$issue.dem.ext1<-as.numeric(chrd$issue.dem.ext1)
sum(chrd$issue.dem.ext1)

chrd$issue.dem.ext2<-0
chrd$issue.dem.ext2[grepl("dem", chrd$issue.category)==TRUE]<-1
chrd$issue.dem.ext2[grepl("6489", chrd$issue.category)==TRUE]<-1
chrd$issue.dem.ext2[grepl("spch", chrd$issue.category)==TRUE]<-1
chrd$issue.dem.ext2[grepl("civil", chrd$issue.category)==TRUE]<-1
chrd$issue.dem.ext2[grepl("info", chrd$issue.category)==TRUE]<-1
chrd$issue.dem.ext2[grepl("assoc", chrd$issue.category)==TRUE]<-1
chrd$issue.dem.ext2[grepl("FG", chrd$issue.category)==TRUE]<-0
chrd$issue.dem.ext2[is.na(chrd$issue.category)==TRUE]<-NA
chrd$issue.dem.ext2<-as.numeric(chrd$issue.dem.ext2)

chrd$issue.ethrel<-0
chrd$issue.ethrel[grepl("eth", chrd$issue.category)==TRUE]<-1
chrd$issue.ethrel[grepl("rel", chrd$issue.category)==TRUE]<-1
chrd$issue.ethrel[grepl("FG", chrd$issue.category)==TRUE]<-1
chrd$issue.ethrel[is.na(chrd$issue.category)==TRUE]<-NA
chrd$issue.ethrel<-as.numeric(chrd$issue.ethrel)
sum(chrd$issue.ethrel)

chrd$issue.propcomlab<-0
chrd$issue.propcomlab[grepl("prop", chrd$issue.category)==TRUE]<-1
chrd$issue.propcomlab[grepl("com", chrd$issue.category)==TRUE]<-1
chrd$issue.propcomlab[grepl("lab", chrd$issue.category)==TRUE]<-1
chrd$issue.propcomlab[is.na(chrd$issue.category)==TRUE]<-NA
chrd$issue.propcomlab<-as.numeric(chrd$issue.propcomlab)
sum(chrd$issue.propcomlab)

colnames(chrd.month.dem.ext1)<-c("month.label","issue.dem.ext1.det")

chrd.dem.ext2<-subset(chrd, chrd$issue.dem.ext2==1)
chrd.month.dem.ext2<-data.frame(ftable(chrd.dem.ext2$month.label))
colnames(chrd.month.dem.ext2)<-c("month.label","issue.dem.ext2.det")
chrd.month.dem.ext2$t<-c(193,202,203,204,194,195,196,197,198,199,200,201)
chrd.month.dem.ext2 <- chrd.month.dem.ext2[order(chrd.month.dem.ext2$t),] 
chrd.dem.ext1<-subset(chrd, chrd$issue.dem.ext1==1)
chrd.month.dem.ext1<-data.frame(ftable(chrd.dem.ext1$month.label))
colnames(chrd.month.dem.ext1)<-c("month.label","issue.dem.ext1.det")
chrd.month<-merge(chrd.month.dem.ext2,chrd.month.dem.ext1,by.x="month.label",all=TRUE)
chrd.month$issue.dem.ext1.det[is.na(chrd.month$issue.dem.ext1.det)==TRUE]<-0
chrd.month <- chrd.month[order(chrd.month$t),] 

z1 <- zelig(cecc ~ det.type.crim  + det.place.informal + issue.dem.ext2 + issue.ethrel + issue.propcomlab, data=chrd, model="logit")  
summary(z1) 
z2 <- zelig(cecc ~ det.type.crim  + det.place.informal + issue.dem.ext2 + issue.ethrel + issue.propcomlab + female + act.petition + act.protest, data=chrd, model="logit")  
summary(z2)     
z3 <- zelig(cecc ~ female + det.type.crim  + det.place.informal + issue.dem.ext2 + issue.ethrel + issue.propcomlab + act.petition + act.protest + focal.gen.win2, data=chrd, model="logit")  
summary(z3)    

stargazer(z1, z2, z3, title="Data Validation - Inclusion in CECC", align=TRUE)

x3.base <- setx(z3, female=0, det.type.crim=0,det.place.informal=0,issue.dem.ext2=0,issue.ethrel=0,issue.propcomlab=0, act.petition=0, act.protest=0, focal.gen.win2=0)

x3.female <- setx(z3, female=1, det.type.crim=0,det.place.informal=0,issue.dem.ext2=0,issue.ethrel=0,issue.propcomlab=0, act.petition=0, act.protest=0, focal.gen.win2=0)
s3.female <- sim(z3, x = x3.base, x1=x3.female)
summary(s3.female)

x3.det.type.crim <- setx(z3, female=0, det.type.crim=1,det.place.informal=0,issue.dem.ext2=0,issue.ethrel=0,issue.propcomlab=0, act.petition=0, act.protest=0, focal.gen.win2=0)
s3.det.type.crim <- sim(z3, x = x3.base, x1=x3.det.type.crim)
summary(s3.det.type.crim)

x3.det.place.informal <- setx(z3, female=0, det.type.crim=0,det.place.informal=1,issue.dem.ext2=0,issue.ethrel=0,issue.propcomlab=0, act.petition=0, act.protest=0, focal.gen.win2=0)
s3.det.place.informal <- sim(z3, x = x3.base, x1=x3.det.place.informal)
summary(s3.det.place.informal)

x3.issue.dem.ext2 <- setx(z3, female=0, det.type.crim=0,det.place.informal=0,issue.dem.ext2=1,issue.ethrel=0,issue.propcomlab=0, act.petition=0, act.protest=0, focal.gen.win2=0)
s3.issue.dem.ext2 <- sim(z3, x = x3.base, x1=x3.issue.dem.ext2)
summary(s3.issue.dem.ext2)

x3.issue.ethrel <- setx(z3, female=0, det.type.crim=0,det.place.informal=0,issue.dem.ext2=0,issue.ethrel=1,issue.propcomlab=0, act.petition=0, act.protest=0, focal.gen.win2=0)
s3.issue.ethrel <- sim(z3, x = x3.base, x1=x3.issue.ethrel)
summary(s3.issue.ethrel)

x3.issue.propcomlab <- setx(z3, female=0, det.type.crim=0,det.place.informal=0,issue.dem.ext2=0,issue.ethrel=0,issue.propcomlab=1, act.petition=0, act.protest=0, focal.gen.win2=0)
s3.issue.propcomlab <- sim(z3, x = x3.base, x1=x3.issue.propcomlab)
summary(s3.issue.propcomlab)

x3.act.petition <- setx(z3, female=0, det.type.crim=0,det.place.informal=0,issue.dem.ext2=0,issue.ethrel=0,issue.propcomlab=0, act.petition=1, act.protest=0, focal.gen.win2=0)
s3.act.petition <- sim(z3, x = x3.base, x1=x3.act.petition)
summary(s3.act.petition)

x3.act.protest <- setx(z3, female=0, det.type.crim=0,det.place.informal=0,issue.dem.ext2=0,issue.ethrel=0,issue.propcomlab=0, act.petition=0, act.protest=1, focal.gen.win2=0)
s3.act.protest <- sim(z3, x = x3.base, x1=x3.act.protest)
summary(s3.act.protest)

x3.focal.gen.win2 <- setx(z3, female=0, det.type.crim=0,det.place.informal=0,issue.dem.ext2=0,issue.ethrel=0,issue.propcomlab=0, act.petition=0, act.protest=0, focal.gen.win2=1)
s3.focal.gen.win2 <- sim(z3, x = x3.base, x1=x3.focal.gen.win2)
summary(s3.focal.gen.win2)

chrd.month$issue.dem.ext1.det.adj<-chrd.month$issue.dem.ext1.det*2.934
chrd.month$issue.dem.ext2.det.adj<-chrd.month$issue.dem.ext2.det*2.934

pdf('figa5a-validation.pdf', width=5, height=5.5)
months<-c("Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec")
t<-c(193,194,195,196,197,198,199,200,201,202,203,204)
par(mfcol=c(1,1))
par(cex.axis=1.15)
par(cex.lab=1.15)
par(cex.main=1.15)
plot(data$t,data$issue.dem.ext1.det,type="l",xaxt="n", lty=1, lwd=1.5, col="grey40", main="Democratic Dissident Detentions (dem.det)", ylim=c(-3,65),ylab="Count", xlab="", xlim=c(193,204))
axis(1, at=t, labels=months, las=2, cex=.6)
lines(chrd.month$t,chrd.month$issue.dem.ext1.det.adj,  lty=5, lwd=2, col="red")
legend("topleft",c("Detentions - CECC","Estimated. Detentions - CHRD"),lwd=c(1.5,2), lty = c(1,5), col=c("grey40","red"), box.lwd=0, cex=.85, bty="n")
points(198, -.01, col = "grey70", pch=17,lwd=4,cex=1.25)
text(198, -2.5, "T", pch=17,lwd=4,cex=.85)
points(193.25, 57, col = "grey70", pch=17,lwd=4,cex=1.25)
text(195.3,57,"Focal Event", cex=.85)
text(193.25,54,"T", cex=.85)
text(196.5,54,"Tiananmen Anniversary", cex=.85)
dev.off()

pdf('figa5b-validation.pdf', width=5, height=5.5)
months<-c("Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec")
t<-c(193,194,195,196,197,198,199,200,201,202,203,204)
par(mfcol=c(1,1))
par(cex.axis=1.15)
par(cex.lab=1.15)
par(cex.main=1.15)
plot(data$t,data$issue.dem.ext2.det,type="l",xaxt="n", lty=1, lwd=1.5, col="grey40", main="Democratic Dissident Detentions (dem.det.ext)", ylim=c(-3,75),ylab="Count", xlab="", xlim=c(193,204))
axis(1, at=t, labels=months, las=2, cex=.6)
lines(chrd.month$t,chrd.month$issue.dem.ext2.det.adj,  lty=5, lwd=2, col="red")
legend("topleft",c("Detentions - CECC","Detentions - CHRD"),lwd=c(1.5,2), lty = c(1,5), col=c("grey40","red"), box.lwd=0, cex=.85, bty="n")
points(198, -.01, col = "grey70", pch=17,lwd=4,cex=1.25)
text(198, -2.5, "T", pch=17,lwd=4,cex=.85)
points(193.25,66.65, col = "grey70", pch=17,lwd=4,cex=1.25)
text(195.3,66.65,"Focal Event", cex=.85)
text(193.25,62.65,"T", cex=.85)
text(196.5,62.65,"Tiananmen Anniversary", cex=.85)
dev.off()
